
#ifdef cl_khr_fp64
#pragma OPENCL EXTENSION cl_khr_fp64 : enable
#elif defined(cl_amd_fp64)
#pragma OPENCL EXTENSION cl_amd_fp64 : enable
#endif
// we always want this
#pragma OPENCL EXTENSION cl_khr_byte_addressable_store : enable

// Emit some utility macros

#define UINT32_MIN UINT_MIN
#define UINT64_MIN ULONG_MIN
#define INT32_MIN INT_MIN
#define INT64_MIN LONG_MIN
#define UINT32_MAX UINT_MAX
#define UINT64_MAX ULONG_MAX
#define INT32_MAX INT_MAX
#define INT64_MAX LONG_MAX

#define TRUNC_SAT_U(ut, ft, max, smax, x) \
  ((((x) != (x)))        ? 0      \
   : ((!((x) > (ft)-1))) ? 0      \
   : ((!((x) < (max))))  ? smax   \
                                 : (ut)(x))

#define TRUNC_SAT_S(ut, st, ft, min, smin, minop, max, smax, x) \
  ((((x) != (x)))         ? 0                           \
   : ((!((x)minop(min)))) ? smin                        \
   : ((!((x) < (max))))   ? smax                        \
                                  : (ut)(st)(x))

#define I32_TRUNC_SAT_U_F32(x) TRUNC_SAT_U(uint, float, 4294967296.f, UINT32_MAX, x)
#define I64_TRUNC_SAT_U_F32(x) TRUNC_SAT_U(ulong, float, (float)UINT64_MAX, UINT64_MAX, x)
#define I32_TRUNC_SAT_U_F64(x) TRUNC_SAT_U(uint, double, 4294967296., UINT32_MAX,  x)
#define I64_TRUNC_SAT_U_F64(x) TRUNC_SAT_U(ulong, double, (double)UINT64_MAX, UINT64_MAX, x)

#define I32_TRUNC_SAT_S_F32(x) TRUNC_SAT_S(uint, int, float, (float)INT32_MIN, INT32_MIN, >=, 2147483648.f, INT32_MAX, x)
#define I64_TRUNC_SAT_S_F32(x) TRUNC_SAT_S(ulong, long, float, (float)INT64_MIN, INT64_MIN, >=, (float)INT64_MAX, INT64_MAX, x)
#define I32_TRUNC_SAT_S_F64(x) TRUNC_SAT_S(uint, int, double, -2147483649., INT32_MIN, >, 2147483648., INT32_MAX, x)
#define I64_TRUNC_SAT_S_F64(x) TRUNC_SAT_S(ulong, long, double, (double)INT64_MIN, INT64_MIN, >=, (double)INT64_MAX, INT64_MAX, x)

#define FMIN(x, y)                                \
   (((x) != (x)) ? NAN                            \
  : ((y) != (y)) ? NAN                            \
  : ((x) == 0 && (y) == 0) ? (signbit(x) ? x : y) \
  : (x < y) ? x : y)

#define FMAX(x, y)                                \
   (((x) != (x)) ? NAN                            \
  : ((y) != (y)) ? NAN                            \
  : ((x) == 0 && (y) == 0) ? (signbit(x) ? y : x) \
  : (x > y) ? x : y)

#define ROTL(x, y, mask) \
  (((x) << ((y) & (mask))) | ((x) >> (((mask) - (y) + 1) & (mask))))
#define ROTR(x, y, mask) \
  (((x) >> ((y) & (mask))) | ((x) << (((mask) - (y) + 1) & (mask))))

#define I32_ROTL(x, y) ROTL(x, y, 31)
#define I64_ROTL(x, y) ROTL(x, y, 63)
#define I32_ROTR(x, y) ROTR(x, y, 31)
#define I64_ROTR(x, y) ROTR(x, y, 63)

#define IS_ALIGNED_POW2(addr, align) \
    !(addr & (align-1))

#define GET_POW2_OFFSET(addr, align) \
    (addr & (align-1))

ulong get_clock() {
    ulong timestamp;
    asm volatile("mov.u64 %0, %%globaltimer;" : "=l"(timestamp));
    return timestamp;
}

inline void * ___private_memcpy_nonmmu(void *dest, void *src, size_t len) {
	char *d = dest;
	char *s = src;
	while (len--)
	  *d++ = *s++;
	return dest;
}

inline void fast_write_u8(ulong addr, ulong mem_start, uchar value, uint warp_id) {
	*((global uchar*)addr) = value;
}

inline void write_u8(ulong addr, ulong mem_start, uchar value, uint warp_id, uint read_idx) {
	*((global uchar*)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start)) = value;

}

void write_u16(ulong addr, ulong mem_start, ushort value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);

}

inline void write_u16_aligned(ulong addr, ulong mem_start, ushort value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);

}

inline void write_u16_aligned_checked(ulong addr, ulong mem_start, ushort value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);

}

void write_u32(ulong addr, ulong mem_start, uint value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);

}

inline void write_u32_aligned(ulong addr, ulong mem_start, uint value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);

}

inline void write_u32_aligned_checked(ulong addr, ulong mem_start, uint value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);

}

void write_u64(ulong addr, ulong mem_start, ulong value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, (value >> 32) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, (value >> 40) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, (value >> 48) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, (value >> 56) & 0xFF, warp_id);

}

inline void write_u64_aligned(ulong addr, ulong mem_start, ulong value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, (value >> 32) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, (value >> 40) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, (value >> 48) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, (value >> 56) & 0xFF, warp_id);

}

inline void write_u64_aligned_checked(ulong addr, ulong mem_start, ulong value, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	fast_write_u8(addr, mem_start, value & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, (value >> 8) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, (value >> 16) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, (value >> 24) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, (value >> 32) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, (value >> 40) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, (value >> 48) & 0xFF, warp_id);
	fast_write_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, (value >> 56) & 0xFF, warp_id);

}

inline uchar fast_read_u8(ulong addr, ulong mem_start, uint warp_id) {
	return *((global uchar*)addr);
}

inline uchar read_u8(ulong addr, ulong mem_start, uint warp_id, uint read_idx) {
	return *((global uchar*)((addr-mem_start)*NUM_THREADS + warp_id + mem_start));
}

ushort read_u16(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ushort temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8(addr, mem_start, warp_id);
	return temp;
}
inline ushort read_u16_aligned(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ushort temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8(addr, mem_start, warp_id);
	return temp;
}
inline ushort read_u16_aligned_checked(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ushort temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8(addr, mem_start, warp_id);
	return temp;
}
uint read_u32(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	uchar4 temp = (uchar4)(0);
	temp.s3 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*3)), mem_start, warp_id);
	temp.s2 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*2)), mem_start, warp_id);
	temp.s1 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS)), mem_start, warp_id);
	temp.s0 = fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return as_uint(temp);
}
inline uint read_u32_aligned(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	uchar4 temp = (uchar4)(0);
	temp.s3 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*3)), mem_start, warp_id);
	temp.s2 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*2)), mem_start, warp_id);
	temp.s1 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS)), mem_start, warp_id);
	temp.s0 = fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return as_uint(temp);
}
inline uint read_u32_aligned_checked(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	uchar4 temp = (uchar4)(0);
	temp.s3 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*3)), mem_start, warp_id);
	temp.s2 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS*2)), mem_start, warp_id);
	temp.s1 = fast_read_u8((ulong)(((ulong)addr)+(NUM_THREADS)), mem_start, warp_id);
	temp.s0 = fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return as_uint(temp);
}
ulong read_u64(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ulong temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return temp;
}

inline ulong read_u64_aligned(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ulong temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return temp;
}

inline ulong read_u64_aligned_checked(ulong addr, ulong mem_start, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	addr = (ulong)((ulong)((addr-mem_start)*(NUM_THREADS) + warp_id + mem_start));
	ulong temp = 0;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*7), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*6), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*5), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*4), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*3), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS*2), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)+NUM_THREADS), mem_start, warp_id);
	temp = temp << 8;
	temp += fast_read_u8((ulong)(((ulong)addr)), mem_start, warp_id);
	return temp;
}

void ___private_memcpy(ulong src, ulong mem_start_src, ulong dst, ulong mem_start_dst, ulong buf_len_bytes, uint warp_id, uint read_idx) {
	for (uint idx = 0; idx < buf_len_bytes; idx++) {
	write_u8((ulong)(dst+idx), (ulong)(mem_start_dst), read_u8((ulong)(src+idx), (ulong)(mem_start_src), warp_id, read_idx), warp_id, read_idx);
	}

}

void ___private_bulk_memfill(ulong dst, ulong mem_start_dst, uchar value, ulong heap_base, ulong buf_len_bytes, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
		uint counter = 0;
	ulong fillval = 0;
	fillval += (ulong)value;
	fillval += (ulong)value << 8;
	fillval += (ulong)value << 16;
	fillval += (ulong)value << 24;
	fillval += (ulong)value << 32;
	fillval += (ulong)value << 40;
	fillval += (ulong)value << 48;
	fillval += (ulong)value << 56;
		if (buf_len_bytes >= 128 && IS_ALIGNED_POW2((ulong)dst, 4)) {
			for (; counter < (buf_len_bytes-GET_POW2_OFFSET(buf_len_bytes, 128)); counter+=128) {
				#pragma unroll(8)
			for (uint unroll = 0; unroll < 128; unroll+=16) {
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll), (ulong)(mem_start_dst), fillval, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+4), (ulong)(mem_start_dst), fillval, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+8), (ulong)(mem_start_dst), fillval, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+12), (ulong)(mem_start_dst), fillval, warp_id, read_idx, thread_idx, scratch_space);
				}
			}
		}
		for (; counter < buf_len_bytes; counter++) {
			write_u8((ulong)(mem_start_dst+dst+counter), (ulong)(mem_start_dst), value, warp_id, read_idx);
		}

}

void ___private_bulk_memcpy(ulong src, ulong mem_start_src, ulong dst, ulong mem_start_dst, ulong heap_base, ulong buf_len_bytes, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	if (dst < src) {
		uint counter = 0;
		if (buf_len_bytes >= 128 && IS_ALIGNED_POW2((ulong)src, 4) && IS_ALIGNED_POW2((ulong)dst, 4)) {
			for (; counter < (buf_len_bytes-GET_POW2_OFFSET(buf_len_bytes, 128)); counter+=128) {
				#pragma unroll(8)
			for (uint unroll = 0; unroll < 128; unroll+=16) {
					uint value1 = read_u32_aligned((ulong)(mem_start_src+src+counter+unroll), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value2 = read_u32_aligned((ulong)(mem_start_src+src+counter+unroll+4), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value3 = read_u32_aligned((ulong)(mem_start_src+src+counter+unroll+8), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value4 = read_u32_aligned((ulong)(mem_start_src+src+counter+unroll+12), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll), (ulong)(mem_start_dst), value1, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+4), (ulong)(mem_start_dst), value2, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+8), (ulong)(mem_start_dst), value3, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+counter+unroll+12), (ulong)(mem_start_dst), value4, warp_id, read_idx, thread_idx, scratch_space);
				}
			}
		}
		for (; counter < buf_len_bytes; counter++) {
			write_u8((ulong)(mem_start_dst+dst+counter), (ulong)(mem_start_dst), read_u8((ulong)(mem_start_src+src+counter), (ulong)(mem_start_src), warp_id, read_idx), warp_id, read_idx);
		}
	} else if (src < dst) {
		if (buf_len_bytes >= 128) {
			for (; buf_len_bytes >= 128; buf_len_bytes -= 128) {
				#pragma unroll(8)
				for (uint unroll = 0; unroll < 128; unroll+=16) {
					uint value1 = read_u32_aligned((ulong)(mem_start_src+src+buf_len_bytes-unroll-4), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value2 = read_u32_aligned((ulong)(mem_start_src+src+buf_len_bytes-unroll-8), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value3 = read_u32_aligned((ulong)(mem_start_src+src+buf_len_bytes-unroll-12), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					uint value4 = read_u32_aligned((ulong)(mem_start_src+src+buf_len_bytes-unroll-16), (ulong)(mem_start_src), warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+buf_len_bytes-unroll-4), (ulong)(mem_start_dst), value1, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+buf_len_bytes-unroll-8), (ulong)(mem_start_dst), value2, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+buf_len_bytes-unroll-12), (ulong)(mem_start_dst), value3, warp_id, read_idx, thread_idx, scratch_space);
					write_u32_aligned((ulong)(mem_start_dst+dst+buf_len_bytes-unroll-16), (ulong)(mem_start_dst), value4, warp_id, read_idx, thread_idx, scratch_space);
				}
			}
		}
		while (buf_len_bytes--) {
			write_u8((ulong)(mem_start_dst+dst+buf_len_bytes), (ulong)(mem_start_dst), read_u8((ulong)(mem_start_src+src+buf_len_bytes), (ulong)(mem_start_src), warp_id, read_idx), warp_id, read_idx);
		}
	}

}

void ___private_memcpy_gpu2cpu(ulong src, ulong mem_start_src, ulong dst, ulong mem_start_dst, ulong buf_len_bytes, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	global char *dst_tmp = (global char*)(dst);
	ulong addr = (ulong)((global uchar*)(((src)-(ulong)(mem_start_src))*(NUM_THREADS) + warp_id + (ulong)mem_start_src));
	for (uint idx = 0; idx < buf_len_bytes; idx++) {
		*dst_tmp++ = fast_read_u8((ulong)(addr+idx*NUM_THREADS), (ulong)(mem_start_src), warp_id);
	}

}

void ___private_memcpy_cpu2gpu(ulong src, ulong mem_start_src, ulong dst, ulong mem_start_dst, ulong buf_len_bytes, uint warp_id, uint read_idx, uint thread_idx, local ulong2 *scratch_space) {
	global ulong *src_tmp = (global ulong*)(src);
	ulong counter = 0;
	if (buf_len_bytes > 8 && IS_ALIGNED_POW2((ulong)dst, 8) && IS_ALIGNED_POW2((ulong)src, 8)) {
		for (; counter < (buf_len_bytes-GET_POW2_OFFSET(buf_len_bytes, 8)); counter+=8) {
		write_u64_aligned((ulong)(dst+counter), (ulong)(mem_start_dst), *src_tmp++, warp_id, read_idx, thread_idx, scratch_space);
		}
	}
	global uchar *src_tmp_remaining = (global uchar*)(src_tmp);
	for (; counter < buf_len_bytes; counter++) {
	write_u8((ulong)(dst+counter), (ulong)(mem_start_dst), *src_tmp_remaining++, warp_id, read_idx);
	}

}

void fd_write_helper(global uint *stack_u32, global uint* heap_u32, global uint *hypercall_buffer, global ulong *sp, uint warp_idx, uint thread_idx, uint read_idx, local uchar *scratch_space, uint fd_write_buf_len, uint iovec_count, uint iovec, uint fd, uint hcall_size) {
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))) = fd;
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+4)) = iovec;
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+8)) = iovec_count;
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+12)) = fd_write_buf_len;
	uint iovec_offset = iovec;
	uint iovec_loop_ctr = iovec_count;
	uint iovec_hypercall_offset = 16;
	uint buf_ptr = 0;
	uint buf_len = 0;
	uint next_buffer_start = iovec_loop_ctr*8;
	for(uint idx = 0; idx < iovec_loop_ctr; idx ++) {
	buf_ptr = read_u32((ulong)(((global char*)heap_u32)+iovec_offset), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space);
	buf_len = read_u32((ulong)(((global char*)heap_u32)+iovec_offset+4), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space);


    if (((global char*)hypercall_buffer+(hcall_size*warp_idx) + next_buffer_start + 16 + buf_len) > (global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+hcall_size)) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+iovec_hypercall_offset)) = next_buffer_start;
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+iovec_hypercall_offset+4)) = buf_len;
	___private_memcpy_gpu2cpu((ulong)((global char *)heap_u32+buf_ptr), (ulong)(heap_u32), (ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+next_buffer_start+16)), (ulong)(hypercall_buffer), (ulong)(buf_len), warp_idx, read_idx, thread_idx, scratch_space);
	next_buffer_start += buf_len;
	iovec_offset += 8;
	iovec_hypercall_offset += 8;
	}
}

#include "fastcalls.cl"
__kernel void data_init(__global uint *stack_u32_global, __global uint *heap_u32_global, __global uint *globals_buffer_global, __global uint *curr_mem_global, __global uint *max_mem_global, __global uchar *is_calling_global, __global ulong *sfp_global, __global uchar* data_segment_global) {
	ulong warp_idx = get_global_id(0) / 1;
	ulong thread_idx = get_local_id(0);
	ulong read_idx = thread_idx % 1;
	printf("stack_u32: %p\n", stack_u32_global);
	printf("heap_u32: %p\n", heap_u32_global);
	curr_mem_global[get_global_id(0)] = 17;
	is_calling_global[get_global_id(0)] = 1;
	max_mem_global[get_global_id(0)] = 48;
	global ulong *sfp = (global ulong *)sfp_global+(get_global_id(0));
	*sfp = 0;
	local ulong2 scratch_space[0];
	global uint *heap_u32 = (global uint*)(heap_u32_global);
	global uint *stack_u32 = (global uint*)(stack_u32_global);
	global uint *globals_buffer = (global uint*)(globals_buffer_global);
	global uchar *data_segment = (global uchar*)(data_segment_global);
	for (uint idx = 0; idx < (VMM_STACK_SIZE_BYTES / 4); idx++) {
		write_u32_aligned((ulong)((global uint*)stack_u32+idx), (ulong)(stack_u32), 0, warp_idx, read_idx, thread_idx, scratch_space);
	}
	for (uint idx = 0; idx < (VMM_HEAP_SIZE_BYTES / 4); idx++) {
		write_u32_aligned((ulong)((global uint*)heap_u32+idx), (ulong)(heap_u32), 0, warp_idx, read_idx, thread_idx, scratch_space);
	}
	for(uint idx = 0; idx < 1062088; idx++) {
		write_u8((ulong)((global char*)heap_u32 + 0 + idx), (ulong)(heap_u32), data_segment[idx], warp_idx, read_idx);
	}
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), 1048576, warp_idx, read_idx, thread_idx, scratch_space);
}


__attribute__((always_inline)) void __func_func_strncmp(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l3 = 0;
	uint p2 = 0;
	uint l5 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func_strncmp_b0;
	}
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_strncmp_b0:
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strncmp_b1;
	}
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
__func_func_strncmp_l0_loop:
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_strncmp_b2;
	}
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_strncmp_b1;

__func_func_strncmp_b2:
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func_strncmp_b3;
	}
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_strncmp_b1;

__func_func_strncmp_b3:
	i32_0 = l4;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_strncmp_b4;
	}
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_strncmp_b1;

__func_func_strncmp_b4:
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	if (i32_0 != 0) {
	goto __func_func_strncmp_l0_loop;
	}
	/* END (loop: __func_func_strncmp_l0) */

__func_func_strncmp_b1:
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (int)(i32_0) - (int)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_strlen(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint l1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p0;
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b1;
	}
	i32_0 = p0;
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b0;
	}
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b1;
	}
	i32_0 = l1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b0;
	}
	i32_0 = p0;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b1;
	}
	i32_0 = l1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b0;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b1;
	}
	i32_0 = l1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_b0;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;

__func_func_strlen_b1:
	i32_0 = l1;
	i32_1 = -5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
__func_func_strlen_l0_loop:
	i32_0 = l1;
	i32_1 = 5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l2;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strlen_l0_loop;
	}
	/* END (loop: __func_func_strlen_l0) */
__func_func_strlen_l1_loop:
	i32_0 = l1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
	goto __func_func_strlen_l1_loop;
	}
	/* END (loop: __func_func_strlen_l1) */

__func_func_strlen_b0:
	i32_0 = l1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_strerror_r(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = p0;
	i32_0 = __func_func_strerror_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = __func_func_strlen_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_strerror_r_b1;
	}
	i32_0 = 68;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strerror_r_b0;
	}
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = p2;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	i32_0 = __func_func_memcpy_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 68;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_strerror_r_b1:
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l3;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_0 = __func_func_memcpy_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_strerror_r_b0:
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_strerror(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint l1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062708+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
	goto __func_func_strerror_b0;
	}
	i32_0 = 1062684;
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 0;
	i32_1 = 1062684;
	write_u32_aligned((ulong)((global char*)heap_u32+1062708+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_strerror_b0:
	i32_0 = 0;
	i32_1 = p0;
	i32_2 = p0;
	i32_3 = 76;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1061920;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	i32_1 = 1060366;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = __func_func___lctrans_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___lctrans(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = __func_func_hfunc207_dummy__fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_hfunc207_dummy_(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_strdup(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p0;
	i32_0 = __func_func_strlen_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_strdup_b0;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = l1;
	i32_0 = __func_func_memcpy_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func_strdup_b0:
	i32_0 = l2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_strcpy(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = __func_func___stpcpy_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___stpcpy(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_1 = p0;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b2;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l2 = i32_0;
	local_cache[4] = 1;
	goto __func_func___stpcpy_b1;

__func_func___stpcpy_b2:
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b3;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l2 = i32_1;
	local_cache[4] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b4;
	}
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___stpcpy_b4:
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b5;
	}
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func___stpcpy_b3;

__func_func___stpcpy_b5:
	i32_0 = l2;
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_1;
	local_cache[6] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b0;
	}
	i32_0 = p0;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b6;
	}
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func___stpcpy_b3;

__func_func___stpcpy_b6:
	i32_0 = l2;
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_1;
	local_cache[6] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b0;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b7;
	}
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func___stpcpy_b3;

__func_func___stpcpy_b7:
	i32_0 = l2;
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_1;
	local_cache[6] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b0;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func___stpcpy_b3:
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l2;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b1;
	}
__func_func___stpcpy_l0_loop:
	i32_0 = p0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l2;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_l0_loop;
	}
	/* END (loop: __func_func___stpcpy_l0) */

__func_func___stpcpy_b1:
	i32_0 = p0;
	i32_1 = l2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___stpcpy_b8;
	}
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___stpcpy_b8:
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	l2 = i32_0;
	local_cache[4] = 1;
__func_func___stpcpy_l1_loop:
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_1;
	local_cache[0] = 1;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func___stpcpy_l1_loop;
	}
	/* END (loop: __func_func___stpcpy_l1) */

__func_func___stpcpy_b0:
	i32_0 = l2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___strchrnul(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l2 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b3;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b1;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b4;
	}
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___strchrnul_b4:
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b2;
	}
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___strchrnul_b3:
	i32_0 = p0;
	i32_1 = p0;
	i32_1 = __func_func_strlen_fastcall(i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___strchrnul_b2:
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b5;
	}
	i32_0 = l3;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func___strchrnul_b1;

__func_func___strchrnul_b5:
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = p0;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b6;
	}
	i32_0 = l3;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func___strchrnul_b1;

__func_func___strchrnul_b6:
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b7;
	}
	i32_0 = l3;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func___strchrnul_b1;

__func_func___strchrnul_b7:
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;

__func_func___strchrnul_b1:
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l3;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b8;
	}
	i32_0 = l2;
	i32_1 = 16843009;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
__func_func___strchrnul_l0_loop:
	i32_0 = l3;
	i32_1 = l2;
	i32_0 = i32_0 ^ i32_1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l3;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b8;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l3;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_l0_loop;
	}
	/* END (loop: __func_func___strchrnul_l0) */

__func_func___strchrnul_b8:
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
__func_func___strchrnul_l1_loop:
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_b0;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___strchrnul_l1_loop;
	}
	/* END (loop: __func_func___strchrnul_l1) */

__func_func___strchrnul_b0:
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_memset(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint p1 = 0;
	uint l5 = 0;
	uint l3 = 0;
	uint p2 = 0;
	uint l4 = 0;
	uint p0 = 0;
	ulong l6 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = p2;
	i32_1 = 33;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b0;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_memset_b0:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+3+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = p0;
	i32_1 = 0;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p1;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 16843009;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = -4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 25;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 24;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_b1;
	}
	i32_0 = l3;
	i64_0 = (ulong)(i32_0);
	i64_1 = 4294967297;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l6 = i64_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
__func_func_memset_l0_loop:
	i32_0 = p2;
	i64_0 = l6;
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i64_0 = l6;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i64_0 = l6;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i64_0 = l6;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = -32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memset_l0_loop;
	}
	/* END (loop: __func_func_memset_l0) */

__func_func_memset_b1:
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_memcpy(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint p1 = 0;
	uint p2 = 0;
	uint l3 = 0;
	uint l5 = 0;
	uint l6 = 0;
	uint l4 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = p2;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b2;
	}
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b1;
	}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b1;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = -3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b0;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+3+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	goto __func_func_memcpy_b0;

__func_func_memcpy_b2:
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_memcpy_b1:
	i32_0 = p2;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	l5 = i32_0;
	local_cache[10] = 1;

__func_func_memcpy_b0:
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func_memcpy_b4;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b6;
	}
	i32_0 = l3;
	p2 = i32_0;
	local_cache[4] = 1;
	goto __func_func_memcpy_b5;

__func_func_memcpy_b6:
	i32_0 = l3;
	i32_1 = -16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b7;
	}
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p2;
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_memcpy_b7:
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b5;
	}
	i32_0 = l3;
	p2 = i32_0;
	local_cache[4] = 1;
__func_func_memcpy_l0_loop:
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l5;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = -32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_l0_loop;
	}
	/* END (loop: __func_func_memcpy_l0) */

__func_func_memcpy_b5:
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b8;
	}
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_memcpy_b8:
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b9;
	}
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_memcpy_b9:
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b10;
	}
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;

__func_func_memcpy_b10:
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b3;
	}
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_memcpy_b4:
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b15;
	}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func_memcpy_b14;
			break;
		case 1:
	goto __func_func_memcpy_b17;
			break;
		case 2:
	goto __func_func_memcpy_b16;
			break;
		default:
	goto __func_func_memcpy_b3;
			break;
	}

__func_func_memcpy_b17:
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 18;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = 18;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 14;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = 14;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 14;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_memcpy_b13;

__func_func_memcpy_b16:
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 17;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = 17;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 13;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = 13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 15;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_memcpy_b13;

__func_func_memcpy_b15:
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b19;
	}
	i32_0 = l4;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func_memcpy_b18;

__func_func_memcpy_b19:
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned_checked((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+5+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+13+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+15+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func_memcpy_b18:
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b12;
	}
	goto __func_func_memcpy_b11;

__func_func_memcpy_b14:
	i32_0 = l4;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = p2;
	i32_2 = 16;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = p2;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+3+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+7+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 19;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = 19;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 15;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 13;
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_memcpy_b13:
	i32_0 = l4;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_memcpy_b12:
	i32_0 = p2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func_memcpy_b11:
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b20;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func_memcpy_b20:
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b21;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func_memcpy_b21:
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcpy_b3;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func_memcpy_b3:
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_memcmp(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l5 = 0;
	uint p2 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_memcmp_b0;
	}
__func_func_memcmp_l0_loop:
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_memcmp_b1;
	}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func_memcmp_l0_loop;
	}
	goto __func_func_memcmp_b0;
	/* END (loop: __func_func_memcmp_l0) */

__func_func_memcmp_b1:
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_memcmp_b0:
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasm_call_dtors(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	__func_func_dummy_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	__func_func_dummy_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_dummy(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasi_environ_get(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func___wasi_environ_get_hypercall_return_stub_0;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+2+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+2+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 3;
	*hypercall_continuation = 0;
	return;
__func_func___wasi_environ_get_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+2+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+2+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

    if (((*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)))*4) + *((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+4)) + 8) > hcall_size) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	for (uint count = 0; count < *((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))); count++) {
		*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+(count*4)+8)) -= (*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)))*4) - i32_1;
	}
	___private_memcpy_cpu2gpu((ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+8)), (ulong)(hypercall_buffer), (ulong)((global char *)heap_u32+i32_0), (ulong)(heap_u32), (ulong)((*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))))*4), warp_idx, read_idx, thread_idx, scratch_space);
	___private_memcpy_cpu2gpu((ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+8+(*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)))*4))), (ulong)(hypercall_buffer), (ulong)((global char *)heap_u32+i32_1), (ulong)(heap_u32), (ulong)(*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+4))), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = hcall_ret_val;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasi_environ_sizes_get(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func___wasi_environ_sizes_get_hypercall_return_stub_0;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+4+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+4+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 2;
	*hypercall_continuation = 0;
	return;
__func_func___wasi_environ_sizes_get_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+4+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+4+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32((ulong)((global char*)heap_u32+i32_0), (ulong)(heap_u32), *((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))), warp_idx, read_idx, thread_idx, scratch_space);
	write_u32((ulong)((global char*)heap_u32+i32_1), (ulong)(heap_u32), *((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx)+4)), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = hcall_ret_val;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasilibc_initialize_environ(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l0 = 0;
	uint l1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func___wasilibc_initialize_environ_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func___wasilibc_initialize_environ_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l0;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 193;
	*is_calling = 1;
	return;
	__func_func___wasilibc_initialize_environ_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
	goto __func_func___wasilibc_initialize_environ_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___wasilibc_initialize_environ_b2;
	}
	i32_0 = 1062680;
	l1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___wasilibc_initialize_environ_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func___wasilibc_initialize_environ_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___wasilibc_initialize_environ_b4;
	}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___wasilibc_initialize_environ_b4;
	}
	i32_0 = l1;
	i32_1 = 4;
	i32_0 = __func_func_calloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___wasilibc_initialize_environ_b3;
	}
	i32_0 = l2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func___wasilibc_initialize_environ_b4:
	i32_0 = 70;
	__func_func__Exit_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___wasilibc_initialize_environ_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 131;
	*is_calling = 1;
	return;
	__func_func___wasilibc_initialize_environ_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___wasilibc_initialize_environ_b0;
	}
	i32_0 = l2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func___wasilibc_initialize_environ_b1:
	i32_0 = 71;
	__func_func__Exit_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___wasilibc_initialize_environ_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062084+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasilibc_ensure_environ(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func___wasilibc_ensure_environ_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	*sp += 20;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062084+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___wasilibc_ensure_environ_b0;
	}
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 105;
	*is_calling = 1;
	return;
	__func_func___wasilibc_ensure_environ_call_return_stub_0:
*sp -= 0;

__func_func___wasilibc_ensure_environ_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_getenv(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint l1 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func_getenv_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 140;
	*is_calling = 1;
	return;
	__func_func_getenv_call_return_stub_0:
*sp -= 0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 61;
	i32_0 = __func_func___strchrnul_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b0;
	}
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func_getenv_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l1;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b1;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062084+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b1;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b1;
	}
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func_getenv_l0_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l1;
	i32_2 = l3;
	i32_0 = __func_func_strncmp_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b3;
	}
	i32_0 = l1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 61;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func_getenv_b3:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l1;
	if (i32_0 != 0) {
	goto __func_func_getenv_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_getenv_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func_getenv_l0) */

__func_func_getenv_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func_getenv_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__Exit(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	__func_func___wasi_proc_exit_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_sbrk(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_sbrk_b0;
	}
	i32_0 = *current_mem_size;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_sbrk_b0:
	i32_0 = p0;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_sbrk_b1;
	}
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_sbrk_b1;
	}
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	if (*current_mem_size + (int)(i32_0) <= *max_mem_size) {
		ulong temp = i32_0;
		i32_0 = *current_mem_size;
		*current_mem_size += temp;
	} else {
		i32_0 = (uint)(-1);
	}
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = -1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_sbrk_b2;
	}
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = -1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_sbrk_b2:
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_sbrk_b1:
	__func_func_abort_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_getcwd(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062080+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_getcwd_b1;
	}
	i32_0 = l2;
	i32_0 = __func_func_strdup_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	if (i32_0 != 0) {
	goto __func_func_getcwd_b0;
	}
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_getcwd_b1:
	i32_0 = l2;
	i32_0 = __func_func_strlen_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_getcwd_b2;
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_0 = __func_func_strcpy_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_getcwd_b2:
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	i32_1 = 68;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_getcwd_b0:
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_abort(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasi_proc_exit(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func___wasi_proc_exit_hypercall_return_stub_0;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+2+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
__func_func___wasi_proc_exit_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+2+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_aligned_alloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_aligned_alloc_b0;
	}
	i32_0 = p1;
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_aligned_alloc_b0:
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = __func_func_internal_memalign_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_internal_memalign(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint l6 = 0;
	uint l4 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	i32_1 = 16;
	i32_2 = p0;
	i32_3 = 16;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l2;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b1;
	}
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_internal_memalign_b0;

__func_func_internal_memalign_b1:
	i32_0 = 32;
	l3 = i32_0;
	local_cache[6] = 1;
__func_func_internal_memalign_l0_loop:
	i32_0 = l3;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_l0_loop;
	}
	/* END (loop: __func_func_internal_memalign_l0) */

__func_func_internal_memalign_b0:
	i32_0 = -64;
	i32_1 = p0;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b2;
	}
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_internal_memalign_b2:
	i32_0 = p0;
	i32_1 = 16;
	i32_2 = p1;
	i32_3 = 19;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = -16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 11;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b3;
	}
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_internal_memalign_b3:
	i32_0 = l3;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b5;
	}
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_internal_memalign_b4;

__func_func_internal_memalign_b5:
	i32_0 = l3;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l3;
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 0;
	i32_3 = p0;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 0;
	i32_3 = p0;
	i32_4 = l3;
	i32_5 = l2;
	i32_4 = (int)(i32_4) - (int)(i32_5);
	i32_5 = 15;
	i32_4 = (uint)(i32_4) > (uint)(i32_5);
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_2 = l2;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b6;
	}
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_internal_memalign_b4;

__func_func_internal_memalign_b6:
	i32_0 = p0;
	i32_1 = l6;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l3;
	i32_2 = l4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	__func_func_dispose_chunk_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func_internal_memalign_b4:
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b7;
	}
	i32_0 = l3;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_internal_memalign_b7;
	}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = l3;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l2;
	i32_2 = p1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	__func_func_dispose_chunk_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func_internal_memalign_b7:
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_dispose_chunk(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[15] = { 0 };
	uint l5 = 0;
	uint l6 = 0;
	uint l4 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint l7 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b1;
	}
	i32_0 = l3;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b0;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b3;
	}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b4;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b2;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l5;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b1;

__func_func_dispose_chunk_b4:
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b6;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b5;

__func_func_dispose_chunk_b6:
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b7;
	}
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b7;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dispose_chunk_b5;

__func_func_dispose_chunk_b7:
__func_func_dispose_chunk_l0_loop:
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_l0_loop;
	}
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_l0_loop;
	}
	/* END (loop: __func_func_dispose_chunk_l0) */
	i32_0 = l5;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b5:
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b1;
	}
	i32_0 = p0;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b9;
	}
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b8;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l4;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b1;

__func_func_dispose_chunk_b9:
	i32_0 = l7;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l7;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = p0;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b1;
	}

__func_func_dispose_chunk_b8:
	i32_0 = l6;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b10;
	}
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b10:
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b1;
	}
	i32_0 = l6;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b1;

__func_func_dispose_chunk_b3:
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b1;
	}
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b2:
	i32_0 = l3;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l3;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b1:
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b12;
	}
	i32_0 = l2;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b13;
	}
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b0;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b13:
	i32_0 = l2;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b14;
	}
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b14:
	i32_0 = l3;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b16;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b17;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l5;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b15;

__func_func_dispose_chunk_b17:
	i32_0 = l3;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l3;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b15;

__func_func_dispose_chunk_b16:
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b19;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b18;

__func_func_dispose_chunk_b19:
	i32_0 = l2;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b20;
	}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b20;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dispose_chunk_b18;

__func_func_dispose_chunk_b20:
__func_func_dispose_chunk_l1_loop:
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l3;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_l1_loop;
	}
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_l1_loop;
	}
	/* END (loop: __func_func_dispose_chunk_l1) */
	i32_0 = l5;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b18:
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b15;
	}
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b22;
	}
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b21;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l4;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dispose_chunk_b15;

__func_func_dispose_chunk_b22:
	i32_0 = l7;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l7;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l2;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b15;
	}

__func_func_dispose_chunk_b21:
	i32_0 = l6;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b23;
	}
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b23:
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b15;
	}
	i32_0 = l6;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b15:
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b11;
	}
	i32_0 = 0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b12:
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b11:
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b24;
	}
	i32_0 = p1;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 1;
	i32_2 = p1;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b26;
	}
	i32_0 = 0;
	i32_1 = l4;
	i32_2 = p1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func_dispose_chunk_b25;

__func_func_dispose_chunk_b26:
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;

__func_func_dispose_chunk_b25:
	i32_0 = p1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b24:
	i32_0 = 31;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b27;
	}
	i32_0 = p1;
	i32_1 = 38;
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l3 = i32_2;
	local_cache[6] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_dispose_chunk_b27:
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b28;
	}
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = l2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b28:
	i32_0 = p1;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l3;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l3;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
__func_func_dispose_chunk_l2_loop:
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_b29;
	}
	i32_0 = l3;
	i32_1 = 29;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = l6;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dispose_chunk_l2_loop;
	}
	/* END (loop: __func_func_dispose_chunk_l2) */
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dispose_chunk_b29:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dispose_chunk_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_realloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint l11 = 0;
	uint l9 = 0;
	uint l2 = 0;
	uint l7 = 0;
	uint l3 = 0;
	uint l12 = 0;
	uint l10 = 0;
	uint p1 = 0;
	uint l8 = 0;
	uint l4 = 0;
	uint l5 = 0;
	uint p0 = 0;
	uint l6 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_realloc_b0;
	}
	i32_0 = p1;
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b0:
	i32_0 = p1;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b1;
	}
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b1:
	i32_0 = 16;
	i32_1 = p1;
	i32_2 = 19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -16;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 11;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b4;
	}
	i32_0 = l2;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l5;
	i32_1 = l2;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l5;
	i32_1 = l2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062660+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b2;
	}
	goto __func_func_realloc_b3;

__func_func_realloc_b4:
	i32_0 = p0;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l5;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b5;
	}
	i32_0 = l5;
	i32_1 = l2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b2;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = l4;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l7;
	i32_1 = l7;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	__func_func_dispose_chunk_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b5:
	i32_0 = l7;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b6;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = l4;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = l2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l5;
	i32_2 = l2;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l2 = i32_1;
	local_cache[4] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l2;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b6:
	i32_0 = l7;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b7;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l5;
	i32_1 = l2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b9;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = l4;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_realloc_b8;

__func_func_realloc_b9:
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l5;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;

__func_func_realloc_b8:
	i32_0 = 0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b7:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l8;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b3;
	}
	i32_0 = l9;
	i32_1 = l2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l8;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b11;
	}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l8;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b12;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l11;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_realloc_b10;

__func_func_realloc_b12:
	i32_0 = l5;
	i32_1 = l8;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_realloc_b10;

__func_func_realloc_b11:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b14;
	}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l8;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_realloc_b13;

__func_func_realloc_b14:
	i32_0 = l7;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_realloc_b15;
	}
	i32_0 = l7;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_realloc_b15;
	}
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	goto __func_func_realloc_b13;

__func_func_realloc_b15:
__func_func_realloc_l0_loop:
	i32_0 = p1;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l5;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_realloc_l0_loop;
	}
	i32_0 = l8;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_realloc_l0_loop;
	}
	/* END (loop: __func_func_realloc_l0) */
	i32_0 = l11;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_realloc_b13:
	i32_0 = l12;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_realloc_b10;
	}
	i32_0 = l7;
	i32_1 = l7;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b17;
	}
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	if (i32_0 != 0) {
	goto __func_func_realloc_b16;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l5;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_realloc_b10;

__func_func_realloc_b17:
	i32_0 = l12;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l12;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l7;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_realloc_b10;
	}

__func_func_realloc_b16:
	i32_0 = l8;
	i32_1 = l12;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_realloc_b18;
	}
	i32_0 = l8;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_realloc_b18:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_realloc_b10;
	}
	i32_0 = l8;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_realloc_b10:
	i32_0 = l10;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_realloc_b19;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l9;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b19:
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = l4;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 2;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l10;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l10;
	__func_func_dispose_chunk_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b3:
	i32_0 = p1;
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func_realloc_b20;
	}
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_realloc_b20:
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = -4;
	i32_3 = -8;
	i32_4 = l3;
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_4;
	local_cache[10] = 1;
	i32_5 = 3;
	i32_4 = (uint)(i32_4) & (uint)(i32_5);
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_3 = l5;
	i32_4 = -8;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l5 = i32_2;
	local_cache[10] = 1;
	i32_3 = p1;
	i32_4 = l5;
	i32_5 = p1;
	i32_4 = (uint)(i32_4) < (uint)(i32_5);
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_0 = __func_func_memcpy_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	__func_func_dlfree_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	p0 = i32_0;
	local_cache[0] = 1;

__func_func_realloc_b2:
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_calloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	ulong l3 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_calloc_b1;
	}
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
	goto __func_func_calloc_b0;

__func_func_calloc_b1:
	i32_0 = p0;
	i64_0 = (ulong)(i32_0);
	i32_0 = p1;
	i64_1 = (ulong)(i32_0);
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l3 = i64_0;
	local_cache[6] = 1;
	i32_0 = (int)(i64_0);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_calloc_b0;
	}
	i32_0 = -1;
	i32_1 = l2;
	i64_0 = l3;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_2 = (int)(i64_0);
	i32_3 = 0;
	i32_2 = (uint)(i32_2) != (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l2 = i32_0;
	local_cache[4] = 1;

__func_func_calloc_b0:
	i32_0 = l2;
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_calloc_b2;
	}
	i32_0 = p0;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_calloc_b2;
	}
	i32_0 = p0;
	i32_1 = 0;
	i32_2 = l2;
	i32_0 = __func_func_memset_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func_calloc_b2:
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_dlfree(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[15] = { 0 };
	uint l7 = 0;
	uint l6 = 0;
	uint l5 = 0;
	uint l2 = 0;
	uint l4 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = p0;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = -8;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b1;
	}
	i32_0 = l2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = l1;
	i32_1 = l1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b2;
	}
	i32_0 = l2;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b3;
	}
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l2;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b4;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l5;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b1;

__func_func_dlfree_b4:
	i32_0 = l2;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l2;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b1;

__func_func_dlfree_b3:
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b6;
	}
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l6;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b5;

__func_func_dlfree_b6:
	i32_0 = l1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b7;
	}
	i32_0 = l1;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b7;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dlfree_b5;

__func_func_dlfree_b7:
__func_func_dlfree_l0_loop:
	i32_0 = l2;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_l0_loop;
	}
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_l0_loop;
	}
	/* END (loop: __func_func_dlfree_l0) */
	i32_0 = l5;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b5:
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b1;
	}
	i32_0 = l1;
	i32_1 = l1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l2 = i32_1;
	local_cache[4] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b9;
	}
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b8;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l4;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b1;

__func_func_dlfree_b9:
	i32_0 = l7;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l7;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l1;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b1;
	}

__func_func_dlfree_b8:
	i32_0 = l6;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b10;
	}
	i32_0 = l6;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b10:
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b1;
	}
	i32_0 = l6;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b1;

__func_func_dlfree_b2:
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b1;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dlfree_b1:
	i32_0 = l1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = l2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b12;
	}
	i32_0 = l3;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b13;
	}
	i32_0 = 0;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b0;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dlfree_b13:
	i32_0 = l3;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b14;
	}
	i32_0 = 0;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dlfree_b14:
	i32_0 = l2;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b16;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l2;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b17;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l5;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b15;

__func_func_dlfree_b17:
	i32_0 = l2;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l2;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b15;

__func_func_dlfree_b16:
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b19;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l6;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b18;

__func_func_dlfree_b19:
	i32_0 = l3;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b20;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b20;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dlfree_b18;

__func_func_dlfree_b20:
__func_func_dlfree_l1_loop:
	i32_0 = l2;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_l1_loop;
	}
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_l1_loop;
	}
	/* END (loop: __func_func_dlfree_l1) */
	i32_0 = l5;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b18:
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b15;
	}
	i32_0 = l3;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l2 = i32_1;
	local_cache[4] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b22;
	}
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dlfree_b21;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l4;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b15;

__func_func_dlfree_b22:
	i32_0 = l7;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l7;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l3;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b15;
	}

__func_func_dlfree_b21:
	i32_0 = l6;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b23;
	}
	i32_0 = l6;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b23:
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b15;
	}
	i32_0 = l6;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b15:
	i32_0 = l1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b11;
	}
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dlfree_b12:
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b11:
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b24;
	}
	i32_0 = p0;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 1;
	i32_2 = p0;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b26;
	}
	i32_0 = 0;
	i32_1 = l4;
	i32_2 = p0;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_dlfree_b25;

__func_func_dlfree_b26:
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;

__func_func_dlfree_b25:
	i32_0 = p0;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func_dlfree_b24:
	i32_0 = 31;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b27;
	}
	i32_0 = p0;
	i32_1 = 38;
	i32_2 = p0;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l2 = i32_2;
	local_cache[4] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l2;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;

__func_func_dlfree_b27:
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_2 = l2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b29;
	}
	i32_0 = l4;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b28;

__func_func_dlfree_b29:
	i32_0 = p0;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l2;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l2;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
__func_func_dlfree_l2_loop:
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlfree_b30;
	}
	i32_0 = l2;
	i32_1 = 29;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = l6;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlfree_l2_loop;
	}
	/* END (loop: __func_func_dlfree_l2) */
	i32_0 = l3;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlfree_b28;

__func_func_dlfree_b30:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b28:
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062212+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l1 = i32_1;
	local_cache[2] = 1;
	i32_2 = -1;
	i32_3 = l1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlfree_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_free(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	__func_func_dlfree_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_dlmalloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[23] = { 0 };
	uint l4 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l9 = 0;
	uint l7 = 0;
	uint l11 = 0;
	uint l6 = 0;
	uint l8 = 0;
	uint l5 = 0;
	uint l10 = 0;
	uint l1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b0;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062652+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b2;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062656+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b1;

__func_func_dlmalloc_b2:
	i32_0 = 0;
	i64_0 = -1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+1062664+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i64_0 = 281474976776192;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+1062656+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -16;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1431655768;
	i32_1 = i32_1 ^ i32_2;
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062652+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062672+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062624+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 65536;
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b1:
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 1114112;
	i32_1 = 1062720;
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 0;
	i32_3 = l4;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1114112;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = 1062720;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 89;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b0;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+1062632+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 1062720;
	write_u32_aligned((ulong)((global char*)heap_u32+1062628+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 1062720;
	write_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+1062216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = -1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
__func_func_dlmalloc_l0_loop:
	i32_0 = l4;
	i32_1 = 1062240;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062228;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062232;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062248;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062236;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062256;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062244;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062252;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l0_loop;
	}
	/* END (loop: __func_func_dlmalloc_l0) */
	i32_0 = 1062720;
	i32_1 = -8;
	i32_2 = 1062720;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = 1062720;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = -56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062668+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1062208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1062720;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b0:
	i32_0 = p0;
	i32_1 = 236;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b14;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 16;
	i32_2 = p0;
	i32_3 = 19;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = -16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p0;
	i32_4 = 11;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b15;
	}
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l3;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 1;
	i32_0 = i32_0 ^ i32_1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 1062228;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b17;
	}
	i32_0 = 0;
	i32_1 = l7;
	i32_2 = -2;
	i32_3 = l6;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b16;

__func_func_dlmalloc_b17:
	i32_0 = l4;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b16:
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = l6;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b15:
	i32_0 = l5;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b18;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 2;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 0;
	i32_3 = l4;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 0;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = ctz(i32_0);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l4;
	i32_2 = 1062228;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b20;
	}
	i32_0 = 0;
	i32_1 = l7;
	i32_2 = -2;
	i32_3 = l3;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b19;

__func_func_dlmalloc_b20:
	i32_0 = l6;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b19:
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l3;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l5;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b21;
	}
	i32_0 = l8;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l7;
	i32_1 = 1;
	i32_2 = l8;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b23;
	}
	i32_0 = 0;
	i32_1 = l7;
	i32_2 = l9;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	l9 = i32_0;
	local_cache[18] = 1;
	goto __func_func_dlmalloc_b22;

__func_func_dlmalloc_b23:
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;

__func_func_dlmalloc_b22:
	i32_0 = l9;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b21:
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b18:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = l10;
	i32_1 = 0;
	i32_2 = l10;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = ctz(i32_0);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	l6 = i32_0;
	local_cache[12] = 1;
__func_func_dlmalloc_l1_loop:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b25;
	}
	i32_0 = l6;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b24;
	}

__func_func_dlmalloc_b25:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_2 = l6;
	i32_3 = l3;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = p0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dlmalloc_l1_loop;
	/* END (loop: __func_func_dlmalloc_l1) */

__func_func_dlmalloc_b24:
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b26;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = l9;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b4;

__func_func_dlmalloc_b26:
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b27;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b12;
	}
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;

__func_func_dlmalloc_b27:
__func_func_dlmalloc_l2_loop:
	i32_0 = l6;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l2_loop;
	}
	i32_0 = l9;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l2_loop;
	}
	/* END (loop: __func_func_dlmalloc_l2) */
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b4;

__func_func_dlmalloc_b14:
	i32_0 = -1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_1 = -65;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = p0;
	i32_1 = 19;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = -16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l5;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b28;
	}
	i32_0 = 31;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l5;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b28;
	}
	i32_0 = l5;
	i32_1 = 38;
	i32_2 = l4;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l4 = i32_2;
	local_cache[8] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;

__func_func_dlmalloc_b28:
	i32_0 = 0;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b32;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	goto __func_func_dlmalloc_b31;

__func_func_dlmalloc_b32:
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l5;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l8;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l8;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
__func_func_dlmalloc_l3_loop:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b33;
	}
	i32_0 = l7;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l7;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b33;
	}
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b30;

__func_func_dlmalloc_b33:
	i32_0 = l4;
	i32_1 = l6;
	i32_2 = 20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l7;
	i32_3 = l6;
	i32_4 = p0;
	i32_5 = 29;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_5 = 4;
	i32_4 = (uint)(i32_4) & (uint)(i32_5);
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_3;
	local_cache[12] = 1;
	i32_2 = (int)(i32_2) == (int)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = l4;
	i32_2 = l7;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l3_loop;
	}
	/* END (loop: __func_func_dlmalloc_l3) */

__func_func_dlmalloc_b31:
	i32_0 = l4;
	i32_1 = l9;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b34;
	}
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 2;
	i32_1 = l8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 0;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l10;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = l4;
	i32_1 = 0;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = ctz(i32_0);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b34:
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b29;
	}

__func_func_dlmalloc_b30:
__func_func_dlmalloc_l4_loop:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b35;
	}
	i32_0 = l4;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;

__func_func_dlmalloc_b35:
	i32_0 = l7;
	i32_1 = l3;
	i32_2 = p0;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = l9;
	i32_2 = p0;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l4_loop;
	}
	/* END (loop: __func_func_dlmalloc_l4) */

__func_func_dlmalloc_b29:
	i32_0 = l9;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = l3;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l5;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b13;
	}
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b36;
	}
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b5;

__func_func_dlmalloc_b36:
	i32_0 = l9;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b37;
	}
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b11;
	}
	i32_0 = l9;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;

__func_func_dlmalloc_b37:
__func_func_dlmalloc_l5_loop:
	i32_0 = l6;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l4;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l5_loop;
	}
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l5_loop;
	}
	/* END (loop: __func_func_dlmalloc_l5) */
	i32_0 = l7;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b5;

__func_func_dlmalloc_b13:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b38;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b40;
	}
	i32_0 = l3;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b39;

__func_func_dlmalloc_b40:
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b39:
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b38:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b41;
	}
	i32_0 = l2;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l6;
	i32_2 = l5;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b41:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062652+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b43;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062660+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_dlmalloc_b42;

__func_func_dlmalloc_b43:
	i32_0 = 0;
	i64_0 = -1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+1062664+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i64_0 = 281474976776192;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+1062656+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l1;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -16;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1431655768;
	i32_1 = i32_1 ^ i32_2;
	write_u32_aligned((ulong)((global char*)heap_u32+1062652+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062672+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062624+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 65536;
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_dlmalloc_b42:
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = l5;
	i32_2 = 71;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 0;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b44;
	}
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b44:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062620+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b45;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062612+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b46;
	}
	i32_0 = l10;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b45;
	}

__func_func_dlmalloc_b46:
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b45:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062624+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b8;
	}
	i32_0 = l2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b49;
	}
	i32_0 = 1062628;
	l4 = i32_0;
	local_cache[8] = 1;
__func_func_dlmalloc_l6_loop:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b50;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b48;
	}

__func_func_dlmalloc_b50:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l6_loop;
	}
	/* END (loop: __func_func_dlmalloc_l6) */

__func_func_dlmalloc_b49:
	i32_0 = 0;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}
	i32_0 = l9;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062656+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b51;
	}
	i32_0 = l9;
	i32_1 = p0;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 0;
	i32_3 = l4;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;

__func_func_dlmalloc_b51:
	i32_0 = l7;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}
	i32_0 = l7;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062620+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b52;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062612+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}
	i32_0 = l6;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}

__func_func_dlmalloc_b52:
	i32_0 = l7;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b47;
	}
	goto __func_func_dlmalloc_b7;

__func_func_dlmalloc_b48:
	i32_0 = p0;
	i32_1 = l6;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l7;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b9;
	}
	i32_0 = l7;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b10;
	}
	i32_0 = p0;
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b47:
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b53;
	}
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b53;
	}
	i32_0 = l8;
	i32_1 = l7;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062660+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b54;
	}
	i32_0 = l4;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_dlmalloc_b7;

__func_func_dlmalloc_b54:
	i32_0 = l3;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b55;
	}
	i32_0 = l3;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l4;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_dlmalloc_b7;

__func_func_dlmalloc_b55:
	i32_0 = 0;
	i32_1 = l7;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	goto __func_func_dlmalloc_b9;

__func_func_dlmalloc_b53:
	i32_0 = l4;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b7;
	}
	goto __func_func_dlmalloc_b9;

__func_func_dlmalloc_b12:
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	goto __func_func_dlmalloc_b4;

__func_func_dlmalloc_b11:
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_dlmalloc_b5;

__func_func_dlmalloc_b10:
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b7;
	}

__func_func_dlmalloc_b9:
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062624+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062624+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b8:
	i32_0 = l9;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}
	i32_0 = l9;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	i32_0 = __func_func_sbrk_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}
	i32_0 = p0;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}
	i32_0 = l4;
	i32_1 = p0;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l5;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}

__func_func_dlmalloc_b7:
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062612+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062612+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062616+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b56;
	}
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062616+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b56:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b60;
	}
	i32_0 = 1062628;
	l4 = i32_0;
	local_cache[8] = 1;
__func_func_dlmalloc_l7_loop:
	i32_0 = p0;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_2;
	local_cache[18] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b59;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l7_loop;
	}
	goto __func_func_dlmalloc_b58;
	/* END (loop: __func_func_dlmalloc_l7) */

__func_func_dlmalloc_b60:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b62;
	}
	i32_0 = p0;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b61;
	}

__func_func_dlmalloc_b62:
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b61:
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+1062632+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062628+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = -1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062652+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1062216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062640+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
__func_func_dlmalloc_l8_loop:
	i32_0 = l4;
	i32_1 = 1062240;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062228;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062232;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062248;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062236;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062256;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1062244;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1062252;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l8_loop;
	}
	/* END (loop: __func_func_dlmalloc_l8) */
	i32_0 = p0;
	i32_1 = -8;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = p0;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l7;
	i32_2 = -56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062668+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1062208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b57;

__func_func_dlmalloc_b59:
	i32_0 = l4;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b58;
	}
	i32_0 = l3;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b58;
	}
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b58;
	}
	i32_0 = l3;
	i32_1 = -8;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = l3;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l9;
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062668+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1062208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b57;

__func_func_dlmalloc_b58:
	i32_0 = p0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_1;
	local_cache[18] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b63;
	}
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062196+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	l9 = i32_0;
	local_cache[18] = 1;

__func_func_dlmalloc_b63:
	i32_0 = p0;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 1062628;
	l4 = i32_0;
	local_cache[8] = 1;
__func_func_dlmalloc_l9_loop:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b70;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l9_loop;
	}
	goto __func_func_dlmalloc_b69;
	/* END (loop: __func_func_dlmalloc_l9) */

__func_func_dlmalloc_b70:
	i32_0 = l4;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b68;
	}

__func_func_dlmalloc_b69:
	i32_0 = 1062628;
	l4 = i32_0;
	local_cache[8] = 1;
__func_func_dlmalloc_l10_loop:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b71;
	}
	i32_0 = l6;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b67;
	}

__func_func_dlmalloc_b71:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_l10_loop;
	/* END (loop: __func_func_dlmalloc_l10) */

__func_func_dlmalloc_b68:
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = -8;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = p0;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = -8;
	i32_2 = l6;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = l6;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l2;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l7;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b72;
	}
	i32_0 = 0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b65;

__func_func_dlmalloc_b72:
	i32_0 = l7;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b73;
	}
	i32_0 = 0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b65;

__func_func_dlmalloc_b73:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b74;
	}
	i32_0 = l3;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b76;
	}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062220;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b77;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l9;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b75;

__func_func_dlmalloc_b77:
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b75;

__func_func_dlmalloc_b76:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b79;
	}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l9;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b78;

__func_func_dlmalloc_b79:
	i32_0 = l7;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b80;
	}
	i32_0 = l7;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b80;
	}
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
	goto __func_func_dlmalloc_b78;

__func_func_dlmalloc_b80:
__func_func_dlmalloc_l11_loop:
	i32_0 = l3;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l6;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l11_loop;
	}
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l11_loop;
	}
	/* END (loop: __func_func_dlmalloc_l11) */
	i32_0 = l9;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b78:
	i32_0 = l10;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b75;
	}
	i32_0 = l7;
	i32_1 = l7;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b82;
	}
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b81;
	}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_3 = l6;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b75;

__func_func_dlmalloc_b82:
	i32_0 = l10;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l10;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l7;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b75;
	}

__func_func_dlmalloc_b81:
	i32_0 = p0;
	i32_1 = l10;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b83;
	}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b83:
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b75;
	}
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b75:
	i32_0 = l8;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l7;
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_dlmalloc_b74:
	i32_0 = l7;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b84;
	}
	i32_0 = l4;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_2 = l4;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b86;
	}
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = l4;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b85;

__func_func_dlmalloc_b86:
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b85:
	i32_0 = l4;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b65;

__func_func_dlmalloc_b84:
	i32_0 = 31;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b87;
	}
	i32_0 = l4;
	i32_1 = 38;
	i32_2 = l4;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l3 = i32_2;
	local_cache[6] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_dlmalloc_b87:
	i32_0 = l5;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 1;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b88;
	}
	i32_0 = l6;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	i32_2 = l9;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b65;

__func_func_dlmalloc_b88:
	i32_0 = l4;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l3;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l3;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
__func_func_dlmalloc_l12_loop:
	i32_0 = p0;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b66;
	}
	i32_0 = l3;
	i32_1 = 29;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l12_loop;
	}
	/* END (loop: __func_func_dlmalloc_l12) */
	i32_0 = l9;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b65;

__func_func_dlmalloc_b67:
	i32_0 = p0;
	i32_1 = -8;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_3 = p0;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l7;
	i32_2 = -56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i32_2 = 55;
	i32_3 = l6;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 15;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 0;
	i32_4 = l6;
	i32_5 = -55;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 15;
	i32_4 = (uint)(i32_4) & (uint)(i32_5);
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -63;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_2 = l9;
	i32_3 = l3;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 35;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062668+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1062208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+1062636+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = 0;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+1062628+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l9;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062636+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+1062632+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062628+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062640+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = 36;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
__func_func_dlmalloc_l13_loop:
	i32_0 = l4;
	i32_1 = 7;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l13_loop;
	}
	/* END (loop: __func_func_dlmalloc_l13) */
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b57;
	}
	i32_0 = l9;
	i32_1 = l9;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = l9;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b89;
	}
	i32_0 = p0;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_2 = p0;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b91;
	}
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = p0;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
	goto __func_func_dlmalloc_b90;

__func_func_dlmalloc_b91:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;

__func_func_dlmalloc_b90:
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b57;

__func_func_dlmalloc_b89:
	i32_0 = 31;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b92;
	}
	i32_0 = p0;
	i32_1 = 38;
	i32_2 = p0;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l4 = i32_2;
	local_cache[8] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b92:
	i32_0 = l3;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 1;
	i32_2 = l4;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b93;
	}
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l9;
	i32_2 = l7;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b57;

__func_func_dlmalloc_b93:
	i32_0 = p0;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l4;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l4;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
__func_func_dlmalloc_l14_loop:
	i32_0 = l9;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b64;
	}
	i32_0 = l4;
	i32_1 = 29;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = l9;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l14_loop;
	}
	/* END (loop: __func_func_dlmalloc_l14) */
	i32_0 = l7;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b57;

__func_func_dlmalloc_b66:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b65:
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b64:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b57:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b6;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l4;
	i32_2 = l5;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+1062192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+1062204+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b6:
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b5:
	i32_0 = l2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b94;
	}
	i32_0 = l9;
	i32_1 = l9;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b96;
	}
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b95;
	}
	i32_0 = 0;
	i32_1 = l10;
	i32_2 = -2;
	i32_3 = l6;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l10 = i32_1;
	local_cache[20] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b94;

__func_func_dlmalloc_b96:
	i32_0 = l2;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l2;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l9;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b94;
	}

__func_func_dlmalloc_b95:
	i32_0 = p0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b97;
	}
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b97:
	i32_0 = l9;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b94;
	}
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b94:
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b99;
	}
	i32_0 = l9;
	i32_1 = l3;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b98;

__func_func_dlmalloc_b99:
	i32_0 = l9;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b100;
	}
	i32_0 = l3;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_2 = l3;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b102;
	}
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func_dlmalloc_b101;

__func_func_dlmalloc_b102:
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;

__func_func_dlmalloc_b101:
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b98;

__func_func_dlmalloc_b100:
	i32_0 = 31;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = 16777215;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b103;
	}
	i32_0 = l3;
	i32_1 = 38;
	i32_2 = l3;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_2 = clz(i32_2);
	l4 = i32_2;
	local_cache[8] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 62;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b103:
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1062484;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l10;
	i32_1 = 1;
	i32_2 = l4;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b104;
	}
	i32_0 = l6;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l10;
	i32_2 = l5;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b98;

__func_func_dlmalloc_b104:
	i32_0 = l3;
	i32_1 = 0;
	i32_2 = 25;
	i32_3 = l4;
	i32_4 = 1;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l4;
	i32_4 = 31;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
__func_func_dlmalloc_l15_loop:
	i32_0 = l5;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b105;
	}
	i32_0 = l4;
	i32_1 = 29;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_l15_loop;
	}
	/* END (loop: __func_func_dlmalloc_l15) */
	i32_0 = l7;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b98;

__func_func_dlmalloc_b105:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b98:
	i32_0 = l9;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	goto __func_func_dlmalloc_b3;

__func_func_dlmalloc_b4:
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b106;
	}
	i32_0 = p0;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1062484;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b108;
	}
	i32_0 = l4;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b107;
	}
	i32_0 = 0;
	i32_1 = l10;
	i32_2 = -2;
	i32_3 = l6;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062184+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b106;

__func_func_dlmalloc_b108:
	i32_0 = l11;
	i32_1 = 16;
	i32_2 = 20;
	i32_3 = l11;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = p0;
	i32_3 = (int)(i32_3) == (int)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b106;
	}

__func_func_dlmalloc_b107:
	i32_0 = l9;
	i32_1 = l11;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b109;
	}
	i32_0 = l9;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b109:
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b106;
	}
	i32_0 = l9;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b106:
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b111;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func_dlmalloc_b110;

__func_func_dlmalloc_b111:
	i32_0 = p0;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l5;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b112;
	}
	i32_0 = l8;
	i32_1 = -8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1062220;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 1;
	i32_1 = l8;
	i32_2 = 3;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l7;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func_dlmalloc_b114;
	}
	i32_0 = 0;
	i32_1 = l9;
	i32_2 = l7;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062180+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	l9 = i32_0;
	local_cache[18] = 1;
	goto __func_func_dlmalloc_b113;

__func_func_dlmalloc_b114:
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;

__func_func_dlmalloc_b113:
	i32_0 = l9;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b112:
	i32_0 = 0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+1062200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+1062188+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func_dlmalloc_b110:
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;

__func_func_dlmalloc_b3:
	i32_0 = l1;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_malloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	i32_0 = __func_func_dlmalloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[117] = { 0 };
	uint l43 = 0;
	ulong l24 = 0;
	uint l39 = 0;
	ulong l26 = 0;
	ulong l29 = 0;
	uint l53 = 0;
	ulong l18 = 0;
	ulong l13 = 0;
	ulong l33 = 0;
	uint l38 = 0;
	ulong l28 = 0;
	uint l47 = 0;
	ulong l21 = 0;
	ulong l23 = 0;
	uint l42 = 0;
	uint l15 = 0;
	uint l40 = 0;
	uint l51 = 0;
	uint l50 = 0;
	uint l14 = 0;
	ulong l10 = 0;
	uint l56 = 0;
	ulong l36 = 0;
	ulong l4 = 0;
	ulong l17 = 0;
	ulong l19 = 0;
	uint l44 = 0;
	uint l57 = 0;
	uint l5 = 0;
	ulong l32 = 0;
	uint l45 = 0;
	uint l37 = 0;
	uint l41 = 0;
	uint l7 = 0;
	ulong l25 = 0;
	uint l12 = 0;
	ulong l9 = 0;
	uint l49 = 0;
	uint p0 = 0;
	ulong l6 = 0;
	uint l48 = 0;
	ulong l20 = 0;
	ulong l22 = 0;
	uint l52 = 0;
	ulong l31 = 0;
	uint l3 = 0;
	ulong l27 = 0;
	ulong l30 = 0;
	ulong l8 = 0;
	uint l35 = 0;
	uint l34 = 0;
	double p1 = 0.0;
	uint l54 = 0;
	ulong l16 = 0;
	uint l58 = 0;
	uint p2 = 0;
	uint l11 = 0;
	uint l55 = 0;
	uint l46 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	double f64_0 = 0.0;
	double f64_1 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_54;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		{
			ulong temp = read_u64_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
			___private_memcpy_nonmmu(&p1, &temp, sizeof(ulong));
		}
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 42;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 1376;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	f64_0 = p1;
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		i64_0 = temp;
	}
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	f64_0 = p1;
	f64_1 = p1;
	i32_0 = (double)(f64_0) == (double)(f64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b1;
	}
	i32_0 = 2;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i64_1 = 4503599627370495;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l6 = i64_0;
	local_cache[12] = 1;
	i64_1 = 4503599627370496;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l4;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = 9007199254740990;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l4;
	i64_3 = 52;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i32_0 = (int)(i64_2);
	i32_1 = 2047;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l8 = i64_0;
	local_cache[16] = 1;
	i64_1 = 1;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = 3;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = 2;
	i32_2 = 4;
	i64_0 = l4;
	i64_1 = 9218868437227405312;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l10 = i64_0;
	local_cache[20] = 1;
	i32_3 = !(i64_0);
	l11 = i32_3;
	local_cache[22] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l10;
	i64_1 = 9218868437227405312;
	i32_2 = (ulong)(i64_0) == (ulong)(i64_1);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = 3;
	i32_2 = 4;
	i32_3 = l11;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l6;
	i32_2 = !(i64_0);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b4;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b3;
			break;
		case 3:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b2;
			break;
		default:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b4:
	i32_0 = 4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = -1075;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i64_0 = l9;
	i32_0 = !(i64_0);
	l5 = i32_0;
	local_cache[10] = 1;
	i64_0 = 1;
	l13 = i64_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = 18014398509481984;
	i64_1 = l8;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l8;
	i64_3 = 4503599627370496;
	i32_0 = (ulong)(i64_2) == (ulong)(i64_3);
	l11 = i32_0;
	local_cache[22] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l8 = i64_0;
	local_cache[16] = 1;
	i64_0 = 2;
	i64_1 = 1;
	i32_0 = l11;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l13 = i64_0;
	local_cache[26] = 1;
	i32_0 = -1077;
	i32_1 = -1076;
	i32_2 = l11;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i64_0 = l9;
	i32_0 = !(i64_0);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[72]) write_u64_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 3;
	i32_2 = l11;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b18;
	}
	i32_0 = 1051744;
	i32_1 = 1051745;
	i32_2 = 1057276;
	i32_3 = p2;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l4;
	i64_1 = 0;
	i32_2 = (long)(i64_0) < (long)(i64_1);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = 1;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = 1;
	i64_0 = l4;
	i64_1 = 63;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_1 = (int)(i64_0);
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b17;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b16;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b19;
			break;
		default:
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b17;
			break;
	}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l8;
	i64_1 = 0;
	i32_0 = (ulong)(i64_0) == (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b15;
	}
	i32_0 = l3;
	i64_0 = l8;
	i64_1 = -1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l10 = i64_0;
	local_cache[20] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+1040+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l12;
	write_u16_aligned((ulong)((global char*)heap_u32+1048+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l12;
	i32_1 = l12;
	i32_2 = -32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i64_0 = l13;
	i64_1 = l8;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l16 = i64_0;
	local_cache[32] = 1;
	i64_1 = 4294967296;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = -16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l11;
	i64_0 = l16;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l16;
	i32_3 = p2;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = 281474976710656;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l11;
	i64_0 = l4;
	i64_1 = 16;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l4;
	i32_3 = p2;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = 72057594037927936;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l11;
	i64_0 = l4;
	i64_1 = 8;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l4;
	i32_3 = p2;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = 1152921504606846976;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l11;
	i64_0 = l4;
	i64_1 = 4;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l4;
	i32_3 = p2;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = 4611686018427387904;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l4;
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l4;
	i32_2 = p2;
	(i32_2 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = -1;
	i32_2 = (long)(i64_0) > (long)(i64_1);
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_0 = (short)(i32_0);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b14;
	}
	i32_0 = l3;
	i64_0 = -1;
	i32_1 = l11;
	i64_1 = (ulong)(i32_1);
	l6 = i64_1;
	local_cache[12] = 1;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = l10;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+872+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l10;
	i64_1 = l4;
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b13;
	}
	i32_0 = l3;
	i32_1 = l12;
	write_u16_aligned((ulong)((global char*)heap_u32+1048+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = l8;
	write_u64_aligned((ulong)((global char*)heap_u32+1040+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = l4;
	i64_1 = l8;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+872+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l8;
	i64_1 = l4;
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b12;
	}
	i32_0 = -96;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_0 = (short)(i32_0);
	i32_1 = 80;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	i32_1 = 86960;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2126;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 1050032;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l17 = i64_0;
	local_cache[34] = 1;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = l8;
	i64_2 = l6;
	i64_3 = 63;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	l18 = i64_2;
	local_cache[36] = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l6 = i64_1;
	local_cache[12] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l19 = i64_1;
	local_cache[38] = 1;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l21 = i64_0;
	local_cache[42] = 1;
	i64_1 = l17;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l22 = i64_1;
	local_cache[44] = 1;
	i64_2 = l19;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l22;
	i64_2 = l6;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	l6 = i64_2;
	local_cache[12] = 1;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	l17 = i64_1;
	local_cache[34] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l23 = i64_1;
	local_cache[46] = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l24 = i64_0;
	local_cache[48] = 1;
	i64_0 = l20;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i64_1 = l4;
	i64_2 = l6;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l17;
	i64_2 = 4294967295;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 2147483648;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l25 = i64_0;
	local_cache[50] = 1;
	i64_0 = 1;
	i32_0 = 0;
	i32_1 = p2;
	i32_2 = l11;
	i32_3 = 1050040;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i64_1 = (ulong)(i32_0);
	l6 = i64_1;
	local_cache[12] = 1;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	l26 = i64_0;
	local_cache[52] = 1;
	i64_1 = -1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_0 = l4;
	i64_1 = l10;
	i64_2 = l18;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l10 = i64_1;
	local_cache[20] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l17 = i64_1;
	local_cache[34] = 1;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l18 = i64_0;
	local_cache[36] = 1;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i64_1 = l4;
	i64_2 = l10;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	l10 = i64_2;
	local_cache[20] = 1;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l22;
	i64_2 = l10;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	l10 = i64_1;
	local_cache[20] = 1;
	i64_2 = 4294967295;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 2147483648;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l27 = i64_0;
	local_cache[54] = 1;
	i64_0 = l22;
	i64_1 = l17;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l17 = i64_0;
	local_cache[34] = 1;
	i64_0 = l10;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l10 = i64_0;
	local_cache[20] = 1;
	i64_0 = l18;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l18 = i64_0;
	local_cache[36] = 1;
	i32_0 = l11;
	i32_1 = 1050042;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l22;
	i64_1 = l9;
	i32_0 = l7;
	i64_2 = (ulong)(i32_0);
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l9 = i64_1;
	local_cache[18] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l28 = i64_1;
	local_cache[56] = 1;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l29 = i64_0;
	local_cache[58] = 1;
	i64_1 = l4;
	i64_2 = l28;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	l30 = i64_1;
	local_cache[60] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l31 = i64_1;
	local_cache[62] = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l22;
	i64_2 = l9;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	l9 = i64_2;
	local_cache[18] = 1;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	l32 = i64_1;
	local_cache[64] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l33 = i64_1;
	local_cache[66] = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l30;
	i64_2 = 4294967295;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l4;
	i64_3 = l9;
	i64_2 = (long)(i64_2) * (long)(i64_3);
	i64_3 = 32;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = l32;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = 2147483648;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l32 = i64_1;
	local_cache[64] = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l30 = i64_0;
	local_cache[60] = 1;
	i64_1 = l6;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 10000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[58]) write_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[66]) write_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[56]) write_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[64]) write_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[62]) write_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b20;
	}
	i32_0 = l7;
	i32_1 = 1000000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[58]) write_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[66]) write_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[56]) write_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[64]) write_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[62]) write_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b11;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[58]) write_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[66]) write_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[56]) write_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[64]) write_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[62]) write_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 100000000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b21;
	}
	i32_0 = 8;
	i32_1 = 9;
	i32_2 = l7;
	i32_3 = 1000000000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l34 = i32_0;
	local_cache[68] = 1;
	i32_0 = 100000000;
	i32_1 = 1000000000;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 6;
	i32_1 = 7;
	i32_2 = l7;
	i32_3 = 10000000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l34 = i32_0;
	local_cache[68] = 1;
	i32_0 = 1000000;
	i32_1 = 10000000;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[58]) write_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[66]) write_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[56]) write_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[64]) write_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[62]) write_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[58]) write_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[66]) write_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[56]) write_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[64]) write_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[62]) write_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 100;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b22;
	}
	i32_0 = 2;
	i32_1 = 3;
	i32_2 = l7;
	i32_3 = 1000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l34 = i32_0;
	local_cache[68] = 1;
	i32_0 = 100;
	i32_1 = 1000;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 10;
	i32_1 = 1;
	i32_2 = l7;
	i32_3 = 9;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	l34 = i32_2;
	local_cache[68] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+1216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1051746;
	write_u32_aligned((ulong)((global char*)heap_u32+1212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l15 = i32_0;
	local_cache[30] = 1;
	i32_0 = 1057276;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+1216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1051749;
	write_u32_aligned((ulong)((global char*)heap_u32+1212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1051752;
	write_u32_aligned((ulong)((global char*)heap_u32+1212+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b15:
	i32_0 = 1049920;
	i32_1 = 28;
	i32_2 = 1051452;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_0:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b14:
	i32_0 = 1049504;
	i32_1 = 29;
	i32_2 = 1049536;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_1:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 1040;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l3;
	i32_3 = 1208;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 121;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 1040;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l3;
	i32_3 = 1208;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 121;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 4;
	i32_1 = 5;
	i32_2 = l7;
	i32_3 = 100000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l34 = i32_0;
	local_cache[68] = 1;
	i32_0 = 10000;
	i32_1 = 100000;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l24;
	i64_1 = l25;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l24 = i64_0;
	local_cache[48] = 1;
	i64_0 = l30;
	i64_1 = l20;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l34;
	i32_1 = l11;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l35 = i32_0;
	local_cache[70] = 1;
	i64_0 = l30;
	i64_1 = l17;
	i64_2 = l18;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = l10;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = l27;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	l36 = i64_1;
	local_cache[72] = 1;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l18 = i64_0;
	local_cache[36] = 1;
	i64_1 = l20;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = 0;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[72]) write_u64_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l11;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_1 = l7;
	i32_2 = p2;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i64_0 = l18;
	i32_0 = l7;
	i32_1 = l38;
	i32_2 = p2;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i64_1 = (ulong)(i32_0);
	i64_2 = l6;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l10 = i64_1;
	local_cache[20] = 1;
	i64_2 = l4;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	l17 = i64_1;
	local_cache[34] = 1;
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b27;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l34;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b28;
	}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
	i64_0 = 1;
	l10 = i64_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l1_loop:
	i64_0 = l10;
	l17 = i64_0;
	local_cache[34] = 1;
	i64_0 = l9;
	l18 = i64_0;
	local_cache[36] = 1;
	i32_0 = l40;
	i32_1 = 17;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b29;
	}
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l4;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = l6;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_1 = (int)(i64_0);
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l40;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
	i64_0 = l17;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l10 = i64_0;
	local_cache[20] = 1;
	i64_0 = l18;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = l4;
	i64_2 = l20;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	l4 = i64_1;
	local_cache[8] = 1;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l1) */
	i64_0 = l9;
	i64_1 = l4;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l6 = i64_0;
	local_cache[12] = 1;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i64_0 = l10;
	i64_1 = l30;
	i64_2 = l24;
	i64_1 = (long)(i64_1) - (long)(i64_2);
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_1 = l10;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l25 = i64_0;
	local_cache[50] = 1;
	i64_0 = l6;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b26;
	}
	i64_0 = l20;
	i64_1 = l10;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_1 = l4;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b26;
	}
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i64_0 = l18;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l26;
	i64_2 = l4;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l22 = i64_0;
	local_cache[44] = 1;
	i64_0 = l26;
	i64_1 = l20;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l30 = i64_0;
	local_cache[60] = 1;
	i64_0 = l20;
	i64_1 = l4;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l19 = i64_0;
	local_cache[38] = 1;
	i64_0 = 0;
	l6 = i64_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l2_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i64_1 = l26;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l10 = i64_0;
	local_cache[20] = 1;
	i64_1 = l20;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b30;
	}
	i64_0 = l19;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l30;
	i64_2 = l4;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b30;
	}
	i32_0 = 1;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b26;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b30:
	i32_0 = l7;
	i32_1 = p2;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i64_0 = l22;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l18 = i64_0;
	local_cache[36] = 1;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i64_0 = l10;
	i64_1 = l20;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b25;
	}
	i64_0 = l6;
	i64_1 = l26;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l6 = i64_0;
	local_cache[12] = 1;
	i64_0 = l10;
	l4 = i64_0;
	local_cache[8] = 1;
	i64_0 = l18;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b25;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 17;
	i32_1 = 17;
	i32_2 = 1051420;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = p2;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 75;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l0) */
	i32_0 = 1051392;
	i32_1 = 25;
	i32_2 = 1051376;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_6:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u64_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u64_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u64_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u64_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u64_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u64_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u64_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 17;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b32;
	}
	i64_0 = l18;
	i64_1 = l17;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i32_0 = p2;
	i64_1 = (ulong)(i32_0);
	i64_2 = l6;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l6 = i64_1;
	local_cache[12] = 1;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l30;
	i64_1 = l24;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l27 = i64_0;
	local_cache[54] = 1;
	i64_0 = l9;
	i64_1 = -1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l26 = i64_0;
	local_cache[52] = 1;
	i64_1 = l17;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b31;
	}
	i64_0 = l20;
	i64_1 = l6;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b31;
	}
	i64_0 = l4;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l17 = i64_0;
	local_cache[34] = 1;
	i64_1 = l21;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l23;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l25;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l22;
	i64_2 = l19;
	i64_3 = l28;
	i64_2 = (long)(i64_2) - (long)(i64_3);
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l31;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = l33;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = l32;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_0 = l31;
	i64_1 = l33;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l32;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l29;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_0 = 0;
	i64_1 = l24;
	i64_2 = l10;
	i64_3 = l4;
	i64_2 = (long)(i64_2) + (long)(i64_3);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l25 = i64_0;
	local_cache[50] = 1;
	i64_0 = 2;
	i64_1 = l36;
	i64_2 = l17;
	i64_3 = l10;
	i64_2 = (long)(i64_2) + (long)(i64_3);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l19 = i64_0;
	local_cache[38] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l3_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l10;
	i64_1 = l17;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l22 = i64_0;
	local_cache[44] = 1;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b33;
	}
	i64_0 = l25;
	i64_1 = l9;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l10;
	i64_2 = l20;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b33;
	}
	i64_0 = l10;
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l17 = i64_0;
	local_cache[34] = 1;
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b31;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[44]) write_u64_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b33:
	i32_0 = l37;
	i32_1 = l39;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i64_0 = l4;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_0 = l19;
	i64_1 = l9;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l30 = i64_0;
	local_cache[60] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l22;
	i64_1 = l26;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b34;
	}
	i64_0 = l17;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l17 = i64_0;
	local_cache[34] = 1;
	i64_0 = l20;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_0 = l9;
	i64_1 = l6;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_0 = l30;
	i64_1 = l6;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[60]) write_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l3) */
	i64_0 = l30;
	i64_1 = l6;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l10;
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l17 = i64_0;
	local_cache[34] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b31;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[34]) write_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[50]) write_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[54]) write_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l40;
	i32_1 = 17;
	i32_2 = 1051436;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_7:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l27;
	i64_1 = l17;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b35;
	}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b35;
	}
	i64_0 = l17;
	i64_1 = l6;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = l27;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
	i64_0 = l27;
	i64_1 = l17;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = l4;
	i64_2 = l27;
	i64_1 = (long)(i64_1) - (long)(i64_2);
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l17;
	i64_1 = 2;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
	i64_0 = l17;
	i64_1 = l18;
	i64_2 = -4;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b23;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	l10 = i64_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u64_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l25;
	i64_1 = l10;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b36;
	}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b36;
	}
	i64_0 = l10;
	i64_1 = l26;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i64_1 = l25;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
	i64_0 = l25;
	i64_1 = l10;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = l4;
	i64_2 = l25;
	i64_1 = (long)(i64_1) - (long)(i64_2);
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l17;
	i64_1 = 20;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l10;
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24;
	}
	i64_0 = l10;
	i64_1 = l17;
	i64_2 = -40;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_2 = l9;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b23;
	}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i64_0 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	i32_2 = 2;
	i64_0 = l8;
	i64_1 = 4294967296;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	p2 = i32_3;
	local_cache[4] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 0;
	i64_0 = l8;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_2 = (int)(i64_0);
	i32_3 = p2;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = 152;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+360+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 0;
	i32_2 = 156;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = l13;
	write_u32_aligned((ulong)((global char*)heap_u32+368+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 0;
	i32_2 = 156;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 536;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 0;
	i32_2 = 156;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+536+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l12;
	i64_0 = (ulong)(i32_0);
	i64_0 = (short)(i64_0);
	i64_1 = l16;
	i64_2 = -1;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_1 = clz(i64_1);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = 1292913986;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = 82746495104;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = (short)(i32_0);
	l35 = i32_0;
	local_cache[70] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_0 = (short)(i32_0);
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b38;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b37;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 536;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l12;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_1 = (short)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l35;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b40;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l35;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_1 = (short)(i32_1);
	p2 = i32_1;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b39;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 536;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l11;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l41 = i32_1;
	local_cache[82] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1368+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l41;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l42 = i32_1;
	local_cache[84] = 1;
	i32_2 = l41;
	i32_3 = l42;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b52;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b57;
	}
	i32_0 = 0;
	l43 = i32_0;
	local_cache[86] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b56;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 0;
	l38 = i32_0;
	local_cache[76] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[88]) l44 = read_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b60;
	}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l44 = i32_0;
	local_cache[88] = 1;
	i32_0 = l43;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
	i32_0 = 0;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l4_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l45;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l4) */
	i32_0 = l44;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b59;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l3;
	i32_3 = 368;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b58;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b58;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b56;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b56;
	}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b55;
	}
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l43;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l43;
	write_u32_aligned((ulong)((global char*)heap_u32+1368+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l39 = i32_0;
	local_cache[78] = 1;
	i32_1 = l43;
	i32_2 = l39;
	i32_3 = l43;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b54;
	}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l5_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b62;
	}
	i32_0 = -1;
	i32_1 = p2;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l3;
	i32_3 = 1208;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 536;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b61;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l5) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = l5;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b63;
	}
	i32_0 = l41;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b53;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l41;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b64;
	}
	i32_0 = 0;
	l41 = i32_0;
	local_cache[82] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b50;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l41;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b65;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b51;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l6_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l6_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b51;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l6) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l35;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l35 = i32_0;
	local_cache[70] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b42;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b55:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_16:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_17:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l41;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_18:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_19:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b66;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l7_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l7_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l7) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b50;
	}
	i32_0 = l41;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b49;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l41;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l41;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l41 = i32_0;
	local_cache[82] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l41;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+360+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_0;
	local_cache[74] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b48;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b67;
	}
	i32_0 = 0;
	l37 = i32_0;
	local_cache[74] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b46;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b68;
	}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b47;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l8_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l8_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b47;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l8) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b49:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_20:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_21:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b69;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l9_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l9_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l9) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b46;
	}
	i32_0 = l37;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b45;
	}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l37;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l37;
	write_u32_aligned((ulong)((global char*)heap_u32+360+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l42;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b44;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l42;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b70;
	}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b42;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l42;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b71;
	}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b43;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l10_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l10_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b43;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l10) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b45:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_22:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l42;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_23:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b72;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l11_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l11_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l11) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b73;
	}
	i32_0 = l42;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b41;
	}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l42;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l42;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l42 = i32_0;
	local_cache[84] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l42;
	write_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l39;
	write_u32_aligned((ulong)((global char*)heap_u32+864+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 704;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 536;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 704;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l46 = i32_0;
	local_cache[92] = 1;
	i32_0 = l3;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1032+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 536;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l47 = i32_0;
	local_cache[94] = 1;
	i32_0 = l3;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1200+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1040;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 536;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1040;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l48 = i32_0;
	local_cache[96] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l45 = i32_0;
	local_cache[90] = 1;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l49 = i32_1;
	local_cache[98] = 1;
	i32_2 = l45;
	i32_3 = l49;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[102]) write_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, l51, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[102] = 0;
	if (local_cache[100]) write_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, l50, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[100] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[98]) write_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, l49, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[98] = 0;
	if (local_cache[104]) write_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, l52, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[104] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b75;
	}
	i32_0 = l3;
	i32_1 = 704;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l44 = i32_0;
	local_cache[88] = 1;
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l42 = i32_0;
	local_cache[84] = 1;
	i32_0 = l3;
	i32_1 = 1040;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l50 = i32_0;
	local_cache[100] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+864+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l51 = i32_0;
	local_cache[102] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1032+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l52 = i32_0;
	local_cache[104] = 1;
	i32_0 = 0;
	l40 = i32_0;
	local_cache[80] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[102]) write_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, l51, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[102] = 0;
	if (local_cache[100]) write_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, l50, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[100] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[98]) write_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, l49, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[98] = 0;
	if (local_cache[104]) write_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, l52, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[104] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l40;
	l53 = i32_0;
	local_cache[106] = 1;
	i32_0 = l43;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[106]) write_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, l53, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[106] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l13_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b77;
	}
	i32_0 = -1;
	i32_1 = l41;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	i32_3 = l3;
	i32_4 = 32;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l13_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b76;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l13) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[106]) write_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, l53, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[106] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b78;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b79;
	}
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[96]) l48 = read_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b81;
	}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l55 = i32_0;
	local_cache[110] = 1;
	i32_0 = l43;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 1040;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l14_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l45;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l14_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l14) */
	i32_0 = l55;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b80;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[96]) l48 = read_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l48;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b79;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b79;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b80:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l43;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 8;
	l54 = i32_0;
	local_cache[108] = 1;
	i32_0 = l43;
	l45 = i32_0;
	local_cache[90] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[106]) write_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, l53, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[106] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_1 = l52;
	i32_2 = l45;
	i32_3 = l52;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b104;
	}
	i32_0 = l43;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l15_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b106;
	}
	i32_0 = -1;
	i32_1 = l42;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	i32_3 = l3;
	i32_4 = 32;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l15_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b105;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l15) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b106:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b105:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b108;
	}
	i32_0 = l45;
	l43 = i32_0;
	local_cache[86] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b107;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b108:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b109;
	}
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[94]) l47 = read_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b111;
	}
	i32_0 = l43;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l55 = i32_0;
	local_cache[110] = 1;
	i32_0 = l43;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l16_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l45;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l16_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l16) */
	i32_0 = l55;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b110;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b111:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[94]) l47 = read_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l47;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b109;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b109;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b110:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b109:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l43;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l54;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b107:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = l51;
	i32_2 = l43;
	i32_3 = l51;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l55 = i32_0;
	local_cache[110] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b103;
	}
	i32_0 = l55;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[88]) l44 = read_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l17_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b113;
	}
	i32_0 = -1;
	i32_1 = l44;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	i32_3 = l3;
	i32_4 = 32;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l17_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b112;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l17) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b113:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b112:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b115;
	}
	i32_0 = l43;
	l55 = i32_0;
	local_cache[110] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b114;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b115:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l55;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b116;
	}
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[92]) l46 = read_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l55;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b118;
	}
	i32_0 = l55;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_0 = l55;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 704;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l18_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l45;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l18_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l18) */
	i32_0 = l43;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b117;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b118:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[92]) l46 = read_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l46;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b116;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b116;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b117:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b7;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b116:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l55;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l54;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b114:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l55;
	i32_1 = l50;
	i32_2 = l55;
	i32_3 = l50;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b102;
	}
	i32_0 = l45;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l19_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b120;
	}
	i32_0 = -1;
	i32_1 = p2;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l3;
	i32_3 = 536;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 32;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l19_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b119;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l19) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b120:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b119:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b122;
	}
	i32_0 = l55;
	l45 = i32_0;
	local_cache[90] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b121;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b122:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b123;
	}
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b125;
	}
	i32_0 = l45;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l55 = i32_0;
	local_cache[110] = 1;
	i32_0 = l45;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 1;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 536;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l20_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l43;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l20_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l20) */
	i32_0 = l55;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b124;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b125:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l3;
	i32_3 = 536;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b123;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b123;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b124:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b8;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b123:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l45;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l54;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b121:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l53;
	i32_1 = 17;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b98;
	}
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l53;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l54;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l45;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+360+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l56 = i32_1;
	local_cache[112] = 1;
	i32_2 = l45;
	i32_3 = l56;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b101;
	}
	i32_0 = l53;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l21_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b127;
	}
	i32_0 = -1;
	i32_1 = p2;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l3;
	i32_3 = 200;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 32;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l21_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b126;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l21) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b127:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b126:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l45;
	write_u32_aligned((ulong)((global char*)heap_u32+1368+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l45;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l57 = i32_1;
	local_cache[114] = 1;
	i32_2 = l45;
	i32_3 = l57;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l54 = i32_0;
	local_cache[108] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b93;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l54;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b129;
	}
	i32_0 = 0;
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b129:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 0;
	l38 = i32_0;
	local_cache[76] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[116]) l58 = read_u32_aligned((ulong)(stack_u32+110+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l54;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[116]) write_u32_aligned((ulong)(stack_u32+110+sfp_ptr), (ulong)stack_u32, l58, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[116] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b132;
	}
	i32_0 = l54;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l58 = i32_0;
	local_cache[116] = 1;
	i32_0 = l54;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l55 = i32_0;
	local_cache[110] = 1;
	i32_0 = 0;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[116]) write_u32_aligned((ulong)(stack_u32+110+sfp_ptr), (ulong)stack_u32, l58, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[116] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l22_loop:
	i32_0 = p2;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l38;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l11;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l38 = i32_1;
	local_cache[76] = 1;
	i32_2 = l7;
	i32_3 = l37;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l34;
	i32_4 = l7;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l7;
	i32_2 = l38;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l55;
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l22_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l22) */
	i32_0 = l58;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[116]) write_u32_aligned((ulong)(stack_u32+110+sfp_ptr), (ulong)stack_u32, l58, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[116] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b131;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[116]) write_u32_aligned((ulong)(stack_u32+110+sfp_ptr), (ulong)stack_u32, l58, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[116] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b132:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l39;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l11;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = l3;
	i32_3 = 368;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b130;
	}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b130;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b131:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b128;
	}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b130:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l54;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b100;
	}
	i32_0 = l3;
	i32_1 = 1208;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l54;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l54;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l54 = i32_0;
	local_cache[108] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b128:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l54;
	write_u32_aligned((ulong)((global char*)heap_u32+1368+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l50;
	i32_1 = l54;
	i32_2 = l50;
	i32_3 = l54;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b99;
	}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l23_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b134;
	}
	i32_0 = -1;
	i32_1 = p2;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l3;
	i32_3 = 1208;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 536;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l11;
	i32_3 = l7;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l23_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b133;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l23) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b134:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b133:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = l5;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b135;
	}
	i32_0 = l11;
	i32_1 = l5;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b135;
	}
	i32_0 = l45;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b97;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b136;
	}
	i32_0 = 0;
	l45 = i32_0;
	local_cache[90] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b90;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b136:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b137;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b91;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b137:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l24_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l24_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b91;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l24) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b135:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = l5;
	i32_0 = (int)(i32_0) >= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b92;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = l5;
	i32_0 = (int)(i32_0) >= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b138;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+696+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_1;
	local_cache[22] = 1;
	i32_2 = p2;
	i32_3 = l11;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b96;
	}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l3;
	i32_1 = 536;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l25_loop:
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b140;
	}
	i32_0 = l38;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l39;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p2;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = -1;
	i32_1 = l7;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l11;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_2;
	local_cache[22] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l7;
	i32_3 = l11;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l25_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b139;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l25) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b140:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b139:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b92;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b138:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l53;
	i32_1 = 17;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b95;
	}
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = l53;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = -1;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l26_loop:
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b141;
	}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 57;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l26_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l26) */
	i32_0 = l3;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l38;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l38;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l53;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b92;
	}
	i32_0 = l7;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l11;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b92;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b141:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 49;
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l53;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b142;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l53;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l53;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b94;
	}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b142:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l39;
	i32_1 = 48;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l35;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l35 = i32_0;
	local_cache[70] = 1;
	i32_0 = l53;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b23;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[110]) write_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, l55, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[110] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_29:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l55;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_30:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[110]) l55 = read_u32_aligned((ulong)(stack_u32+104+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_31:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_32:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b100:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_33:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_34:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b98:
	i32_0 = 17;
	i32_1 = 17;
	i32_2 = 1049856;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_35:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l45;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_36:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_37:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l40;
	i32_1 = 17;
	i32_2 = 1049872;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_38:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l40;
	i32_1 = 17;
	i32_2 = 1049888;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_39:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l54;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_40:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[108]) l54 = read_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l53;
	i32_1 = 17;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b23;
	}
	i32_0 = l40;
	i32_1 = 17;
	i32_2 = 1049904;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_41:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[106]) l53 = read_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b143;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l27_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l27_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l27) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b143:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b90;
	}
	i32_0 = l45;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b89;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l45;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l45;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l45 = i32_0;
	local_cache[90] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l45;
	write_u32_aligned((ulong)((global char*)heap_u32+192+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l56;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b88;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l56;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b144;
	}
	i32_0 = 0;
	l56 = i32_0;
	local_cache[112] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b86;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b144:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l56;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b145;
	}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b87;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b145:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l28_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l28_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b87;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l28) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b89:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_42:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l56;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_43:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b146;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l29_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l29_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l29) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b146:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b86;
	}
	i32_0 = l56;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b85;
	}
	i32_0 = l3;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l56;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l56;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l56 = i32_0;
	local_cache[112] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[112]) write_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, l56, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[112] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l56;
	write_u32_aligned((ulong)((global char*)heap_u32+360+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l57;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b84;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l57;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b147;
	}
	i32_0 = 0;
	l57 = i32_0;
	local_cache[114] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b82;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b147:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l57;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b148;
	}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b83;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b148:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[112]) l56 = read_u32_aligned((ulong)(stack_u32+106+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l30_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_1 = l38;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l30_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b83;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l30) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b85:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_44:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l57;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_45:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b149;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l31_loop:
	i32_0 = p2;
	i32_1 = p2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l31_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l31) */

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b149:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b82;
	}
	i32_0 = l57;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b74;
	}
	i32_0 = l3;
	i32_1 = 368;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l57;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l57;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l57 = i32_0;
	local_cache[114] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[114]) write_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, l57, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[114] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[114]) l57 = read_u32_aligned((ulong)(stack_u32+108+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l57;
	write_u32_aligned((ulong)((global char*)heap_u32+528+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l45;
	i32_1 = l49;
	i32_2 = l45;
	i32_3 = l49;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l43 = i32_0;
	local_cache[86] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[106]) write_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, l53, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[106] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 75;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[106]) write_u32_aligned((ulong)(stack_u32+100+sfp_ptr), (ulong)stack_u32, l53, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[106] = 0;
	if (local_cache[108]) write_u32_aligned((ulong)(stack_u32+102+sfp_ptr), (ulong)stack_u32, l54, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[108] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_l12) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[102]) write_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, l51, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[102] = 0;
	if (local_cache[100]) write_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, l50, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[100] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[98]) write_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, l49, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[98] = 0;
	if (local_cache[104]) write_u32_aligned((ulong)(stack_u32+98+sfp_ptr), (ulong)stack_u32, l52, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[104] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l43;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_46:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_47:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_48:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u64_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l40;
	i32_3 = l35;
	i32_4 = 0;
	i32_5 = l3;
	i32_6 = 1208;
	i32_5 = (int)(i32_5) + (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[72]) write_u64_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 49;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_49:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u64_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u64_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u64_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u64_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u64_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[36]) write_u64_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[72]) write_u64_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1052;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l11;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+1048+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l15;
	write_u32_aligned((ulong)((global char*)heap_u32+1044+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l14;
	write_u32_aligned((ulong)((global char*)heap_u32+1040+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1040;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 204;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l3;
	i32_1 = 1376;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b8:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_51:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b7:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_52:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b6:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_53:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE_call_return_stub_54:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[83] = { 0 };
	uint l27 = 0;
	uint l30 = 0;
	uint l16 = 0;
	uint l26 = 0;
	uint l34 = 0;
	uint p0 = 0;
	uint l39 = 0;
	uint l23 = 0;
	uint l24 = 0;
	uint l6 = 0;
	ulong l5 = 0;
	uint l41 = 0;
	uint l37 = 0;
	uint l15 = 0;
	ulong l7 = 0;
	uint l14 = 0;
	uint p3 = 0;
	uint l12 = 0;
	ulong l21 = 0;
	ulong l11 = 0;
	uint l38 = 0;
	ulong l10 = 0;
	uint l13 = 0;
	uint l32 = 0;
	uint l40 = 0;
	ulong l20 = 0;
	uint l17 = 0;
	ulong l9 = 0;
	uint l4 = 0;
	uint l29 = 0;
	uint l36 = 0;
	uint l35 = 0;
	uint l19 = 0;
	double p1 = 0.0;
	uint l28 = 0;
	uint l22 = 0;
	uint p2 = 0;
	uint l18 = 0;
	uint l33 = 0;
	uint l25 = 0;
	uint l8 = 0;
	uint l31 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	double f64_0 = 0.0;
	double f64_1 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_43;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		{
			ulong temp = read_u64_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
			___private_memcpy_nonmmu(&p1, &temp, sizeof(ulong));
		}
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 42;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 1888;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	f64_0 = p1;
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		i64_0 = temp;
	}
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	f64_0 = p1;
	f64_1 = p1;
	i32_0 = (double)(f64_0) == (double)(f64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b1;
	}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i64_1 = 4503599627370495;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = 4503599627370496;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l5;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = 9007199254740990;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l5;
	i64_3 = 52;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i32_0 = (int)(i64_2);
	i32_1 = 2047;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = 1;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l10 = i64_0;
	local_cache[20] = 1;
	i32_0 = 3;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = 2;
	i32_2 = 4;
	i64_0 = l5;
	i64_1 = 9218868437227405312;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l11 = i64_0;
	local_cache[22] = 1;
	i32_3 = !(i64_0);
	l12 = i32_3;
	local_cache[24] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l11;
	i64_1 = 9218868437227405312;
	i32_2 = (ulong)(i64_0) == (ulong)(i64_1);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = 3;
	i32_2 = 4;
	i32_3 = l12;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l7;
	i32_2 = !(i64_0);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b0;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b5;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b4;
			break;
		case 3:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b3;
			break;
		default:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b0;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b5:
	i32_0 = 4;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = -1075;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = 18014398509481984;
	i64_1 = l9;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l9;
	i64_3 = 4503599627370496;
	i32_0 = (ulong)(i64_2) == (ulong)(i64_3);
	l6 = i32_0;
	local_cache[12] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = -1077;
	i32_1 = -1076;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l10;
	i32_0 = !(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 3;
	i32_2 = l6;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b11;
	}
	i32_0 = 1051744;
	i32_1 = 1051745;
	i32_2 = 1057276;
	i32_3 = p2;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l5;
	i64_1 = 0;
	i32_2 = (long)(i64_0) < (long)(i64_1);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 1;
	i64_0 = l5;
	i64_1 = 63;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_1 = (int)(i64_0);
	i32_2 = p2;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_0 = l12;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b10;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b9;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b8;
			break;
		default:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b10;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051746;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1720+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l15 = i32_0;
	local_cache[30] = 1;
	i32_0 = 1057276;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051749;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1720+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1720+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b7;
	}
	i32_0 = l4;
	i32_1 = 1736;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+1732+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051676;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -12;
	i32_1 = 5;
	i32_2 = l13;
	i32_2 = (short)(i32_2);
	l16 = i32_2;
	local_cache[32] = 1;
	i32_3 = 0;
	i32_2 = (int)(i32_2) < (int)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_1 = l16;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 16063;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b31;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l9;
	i64_1 = 0;
	i32_0 = (ulong)(i64_0) == (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b33;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 21;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l18 = i32_0;
	local_cache[36] = 1;
	i32_0 = 0;
	i32_1 = p3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = -32768;
	i32_2 = p3;
	i32_3 = 32768;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	i32_0 = (short)(i32_0);
	l19 = i32_0;
	local_cache[38] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -96;
	i32_1 = l13;
	i32_2 = -32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l13;
	i64_0 = l9;
	i64_1 = 4294967296;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = -16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i64_0 = l9;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l9;
	i32_3 = l6;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 281474976710656;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i64_0 = l5;
	i64_1 = 16;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l5;
	i32_3 = l6;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 72057594037927936;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i64_0 = l5;
	i64_1 = 8;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l5;
	i32_3 = l6;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 1152921504606846976;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i64_0 = l5;
	i64_1 = 4;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l5;
	i32_3 = l6;
	(i32_3 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 4611686018427387904;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i64_0 = l5;
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l5;
	i32_2 = l6;
	(i32_2 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = -1;
	i32_2 = (long)(i64_0) > (long)(i64_1);
	p2 = i32_2;
	local_cache[4] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_0 = (short)(i32_0);
	i32_1 = 80;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	i32_1 = 86960;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2126;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1050032;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l11 = i64_0;
	local_cache[22] = 1;
	i64_1 = l5;
	i32_0 = p2;
	i64_2 = (ulong)(i32_0);
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l5 = i64_1;
	local_cache[10] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l10 = i64_1;
	local_cache[20] = 1;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i64_1 = l7;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	l7 = i64_1;
	local_cache[14] = 1;
	i64_2 = l10;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l7;
	i64_2 = l5;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	l5 = i64_2;
	local_cache[10] = 1;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	l7 = i64_1;
	local_cache[14] = 1;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = l20;
	i64_2 = 4294967295;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l11;
	i64_3 = l5;
	i64_2 = (long)(i64_2) * (long)(i64_3);
	i64_3 = 32;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = l7;
	i64_3 = 4294967295;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = 2147483648;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 1;
	i32_0 = -64;
	i32_1 = l12;
	i32_2 = l6;
	i32_3 = 1050040;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i64_2 = (ulong)(i32_0);
	l11 = i64_2;
	local_cache[22] = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	l21 = i64_1;
	local_cache[42] = 1;
	i64_2 = -1;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	l10 = i64_1;
	local_cache[20] = 1;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = 0;
	i32_0 = (ulong)(i64_0) != (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b34;
	}
	i32_0 = l4;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1032+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b29;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[42]) write_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 1050042;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i64_1 = l11;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 10000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b35;
	}
	i32_0 = l12;
	i32_1 = 1000000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b32;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 100000000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b36;
	}
	i32_0 = 8;
	i32_1 = 9;
	i32_2 = l12;
	i32_3 = 1000000000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = 100000000;
	i32_1 = 1000000000;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 6;
	i32_1 = 7;
	i32_2 = l12;
	i32_3 = 10000000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = 1000000;
	i32_1 = 10000000;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 100;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b37;
	}
	i32_0 = 2;
	i32_1 = 3;
	i32_2 = l12;
	i32_3 = 1000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = 100;
	i32_1 = 1000;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 10;
	i32_1 = 1;
	i32_2 = l12;
	i32_3 = 9;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b33:
	i32_0 = 1049920;
	i32_1 = 28;
	i32_2 = 1051576;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_0:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 4;
	i32_1 = 5;
	i32_2 = l12;
	i32_3 = 100000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = 10000;
	i32_1 = 100000;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b31:
	i32_0 = 1051753;
	i32_1 = 37;
	i32_2 = 1051792;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_1:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l22;
	i32_1 = l8;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (short)(i32_0);
	l23 = i32_0;
	local_cache[46] = 1;
	i32_1 = l19;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b39;
	}
	i32_0 = p2;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l24 = i32_0;
	local_cache[48] = 1;
	i32_0 = l23;
	i32_1 = l19;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (short)(i32_0);
	i32_1 = l18;
	i32_2 = p2;
	i32_3 = l18;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l25 = i32_0;
	local_cache[50] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l26 = i32_0;
	local_cache[52] = 1;
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l0_loop:
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_2 = l6;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l12;
	i32_1 = l8;
	i32_2 = l6;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l26;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b41;
	}
	i32_0 = l22;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b42;
	}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l6;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l0) */
	i32_0 = 1051392;
	i32_1 = 25;
	i32_2 = 1051544;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_2:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = -20;
	i32_1 = l17;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l24;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i64_0 = (ulong)(i32_0);
	l20 = i64_0;
	local_cache[40] = 1;
	i64_0 = 1;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l1_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i64_1 = l20;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = !(i64_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b43;
	}
	i32_0 = l4;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1032+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b29;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b43:
	i32_0 = p2;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b40;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l7;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = l11;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_1 = (int)(i64_0);
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i64_0 = l5;
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_0 = l7;
	i64_1 = l10;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l25;
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l1) */
	i32_0 = l4;
	i32_1 = 1032;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = l25;
	i32_4 = l23;
	i32_5 = l19;
	i64_0 = l7;
	i64_1 = l21;
	i64_2 = l5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 10;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_3:
*sp -= 18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b38;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[40]) write_u64_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1032;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = l25;
	i32_4 = l23;
	i32_5 = l19;
	i32_6 = l12;
	i64_0 = (ulong)(i32_6);
	i64_1 = l11;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i32_6 = l6;
	i64_1 = (ulong)(i32_6);
	i64_2 = l11;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l21;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 10;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_4:
*sp -= 18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b38;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l18;
	i32_2 = 1051560;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1032;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = 0;
	i32_4 = l23;
	i32_5 = l19;
	i64_0 = l5;
	i64_1 = 10;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	i32_6 = l6;
	i64_1 = (ulong)(i32_6);
	i64_2 = l11;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l21;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 10;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_6:
*sp -= 18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u64_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1032+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b28;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i64_0 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+1048+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1;
	i32_2 = 2;
	i64_0 = l9;
	i64_1 = 4294967296;
	i32_3 = (ulong)(i64_0) < (ulong)(i64_1);
	l6 = i32_3;
	local_cache[12] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 0;
	i64_0 = l9;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_2 = (int)(i64_0);
	i32_3 = l6;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1052+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1056;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = 152;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 0;
	i32_2 = 156;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1216+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i64_0 = (ulong)(i32_0);
	i64_0 = (short)(i64_0);
	i64_1 = l9;
	i64_2 = -1;
	i64_1 = (long)(i64_1) + (long)(i64_2);
	i64_1 = clz(i64_1);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = 1292913986;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = 82746495104;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (short)(i32_0);
	l24 = i32_0;
	local_cache[48] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b45;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l13;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b44;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l13;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_1 = (short)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l24;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b47;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l24;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_1 = (short)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b46;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 13;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l23 = i32_1;
	local_cache[46] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1216;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l23;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b50;
	}
	i32_0 = l23;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b49;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = l18;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l23;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l2_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b51;
	}
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b53;
	}
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b52;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b53:
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l22;
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l3_loop:
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l12;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 1000000000;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l9;
	i64_1 = -1000000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l6;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 1000000000;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l9;
	i64_1 = -1000000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l3) */
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b51;
	}
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b52:
	i32_0 = l6;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l6;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = 1000000000;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b51:
	i32_0 = l13;
	i32_1 = -9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b48;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_11:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1049552;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b58;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b27;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b59;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b54;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = p2;
	i64_0 = (ulong)(i32_0);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b57;
	}
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b56;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b58:
	i32_0 = 1055139;
	i32_1 = 27;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_12:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l6;
	i32_1 = 2147483646;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l12;
	i32_1 = l4;
	i32_2 = 1720;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l4_loop:
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i64_0 = l9;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l12;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = l5;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l9;
	i64_1 = l7;
	i64_2 = l5;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l6;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i64_1 = l5;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l9;
	i64_1 = l7;
	i64_2 = l5;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = l6;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l4) */
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b55;
	}
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l9;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i32_1 = l6;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l5;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l16 = i32_1;
	local_cache[32] = 1;
	i32_2 = l6;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l27 = i32_0;
	local_cache[54] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b23;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l27;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b61;
	}
	i32_0 = 0;
	l27 = i32_0;
	local_cache[54] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b60;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l27;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b64;
	}
	i32_0 = l27;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l28 = i32_0;
	local_cache[56] = 1;
	i32_0 = l27;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_0 = 0;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l5_loop:
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l13;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l26 = i32_1;
	local_cache[52] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l13;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l25 = i32_1;
	local_cache[50] = 1;
	i32_2 = p2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_2 = l12;
	i32_3 = l22;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l26;
	i32_4 = l12;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = l25;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l12;
	i32_2 = l13;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l17;
	i32_1 = l8;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l5) */
	i32_0 = l28;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b63;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l4;
	i32_3 = 1048;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = l6;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l13;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b62;
	}
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b62;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b60;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b60;
	}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l27;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b26;
	}
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l27;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l27;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l27 = i32_0;
	local_cache[54] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l27;
	write_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l27;
	i32_1 = l23;
	i32_2 = l27;
	i32_3 = l23;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b25;
	}
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l6_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b66;
	}
	i32_0 = -1;
	i32_1 = l6;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l4;
	i32_3 = 1216;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = l4;
	i32_4 = 1720;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l6_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b65;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l6) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b67;
	}
	i32_0 = l24;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l24 = i32_0;
	local_cache[48] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b20;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b24;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b68;
	}
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b21;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b69;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l7_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l13;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l13;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l13;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l12;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l7_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l7) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+1040+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l24 = i32_0;
	local_cache[48] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1036+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b13;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_13:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b26:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_14:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_15:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_16:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l27;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_17:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b70;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l8_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l8_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l8) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i32_0 = (int)(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b21;
	}
	i32_0 = l16;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b19;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l16;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l16;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l22 = i32_0;
	local_cache[44] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l24;
	i32_0 = (short)(i32_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l19;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b72;
	}
	i32_0 = l24;
	i32_1 = l19;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_0 = (short)(i32_0);
	i32_1 = l18;
	i32_2 = l6;
	i32_3 = l19;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l18;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b71;
	}
	i32_0 = 0;
	l22 = i32_0;
	local_cache[44] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b72:
	i32_0 = 0;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b14;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l23;
	write_u32_aligned((ulong)((global char*)heap_u32+1544+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1384;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1216;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1384;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l29 = i32_0;
	local_cache[58] = 1;
	i32_0 = l4;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1712+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1552;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1216;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1552;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l30 = i32_0;
	local_cache[60] = 1;
	i32_0 = l4;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1216;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_0 = l4;
	i32_1 = 1384;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l25 = i32_0;
	local_cache[50] = 1;
	i32_0 = l4;
	i32_1 = 1552;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l26 = i32_0;
	local_cache[52] = 1;
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 107;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l31 = i32_0;
	local_cache[62] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l23 = i32_0;
	local_cache[46] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1544+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l32 = i32_0;
	local_cache[64] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1712+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l33 = i32_0;
	local_cache[66] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1880+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l34 = i32_0;
	local_cache[68] = 1;
	i32_0 = 0;
	l35 = i32_0;
	local_cache[70] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l35;
	l36 = i32_0;
	local_cache[72] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b82;
	}
	i32_0 = l36;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l35 = i32_0;
	local_cache[70] = 1;
	i32_0 = l16;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l10_loop:
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b86;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l10_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l10) */
	i32_0 = l16;
	i32_1 = l34;
	i32_2 = l16;
	i32_3 = l34;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b81;
	}
	i32_0 = l37;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l11_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b88;
	}
	i32_0 = -1;
	i32_1 = l22;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = l4;
	i32_4 = 1048;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l11_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b87;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l11) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b83;
	}
	i32_0 = l37;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b84;
	}
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b89;
	}
	i32_0 = l37;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l37;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l12_loop:
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l8;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l40 = i32_1;
	local_cache[80] = 1;
	i32_2 = p2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = l12;
	i32_3 = l27;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l28;
	i32_4 = l12;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = l40;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l12;
	i32_2 = l8;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l39;
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l16 = i32_1;
	local_cache[32] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l12_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l12) */
	i32_0 = l38;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b85;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l31;
	i32_3 = l6;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b84;
	}
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b84;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b15;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l36;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b80;
	}
	i32_0 = l13;
	i32_1 = l18;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b79;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l36;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b90;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l36;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l13;
	i32_3 = l36;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b13;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b15;
	}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l37;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 8;
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l37;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = l33;
	i32_2 = l16;
	i32_3 = l33;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b78;
	}
	i32_0 = l39;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l13_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b92;
	}
	i32_0 = -1;
	i32_1 = l26;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = l4;
	i32_4 = 1048;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l13_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b91;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l13) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b94;
	}
	i32_0 = l16;
	l39 = i32_0;
	local_cache[78] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b93;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l39;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b95;
	}
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l39;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b97;
	}
	i32_0 = l39;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l39;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l4;
	i32_1 = 1552;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l14_loop:
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l8;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l40 = i32_1;
	local_cache[80] = 1;
	i32_2 = p2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = l12;
	i32_3 = l27;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l28;
	i32_4 = l12;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = l40;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l12;
	i32_2 = l8;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l37;
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l16 = i32_1;
	local_cache[32] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l14_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l14) */
	i32_0 = l41;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b96;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l30;
	i32_3 = l6;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b95;
	}
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b95;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l39;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l39;
	i32_1 = l32;
	i32_2 = l39;
	i32_3 = l32;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b77;
	}
	i32_0 = l37;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l15_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b99;
	}
	i32_0 = -1;
	i32_1 = l25;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = l4;
	i32_4 = 1048;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l15_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b98;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l15) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b101;
	}
	i32_0 = l39;
	l37 = i32_0;
	local_cache[74] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b102;
	}
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b104;
	}
	i32_0 = l37;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l37;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l4;
	i32_1 = 1384;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l16_loop:
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l8;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l40 = i32_1;
	local_cache[80] = 1;
	i32_2 = p2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = l12;
	i32_3 = l27;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l28;
	i32_4 = l12;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = l40;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l12;
	i32_2 = l8;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l39;
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l16 = i32_1;
	local_cache[32] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l16_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l16) */
	i32_0 = l41;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b103;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l29;
	i32_3 = l6;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b102;
	}
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b102;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b17;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l37;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = l23;
	i32_2 = l37;
	i32_3 = l23;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b76;
	}
	i32_0 = l16;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l17_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b106;
	}
	i32_0 = -1;
	i32_1 = l17;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = -4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = l4;
	i32_4 = 1048;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l17_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b105;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l17) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b106:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b105:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b108;
	}
	i32_0 = l37;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b107;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b108:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b109;
	}
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l27 = i32_0;
	local_cache[54] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b111;
	}
	i32_0 = l16;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l16;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_0 = 0;
	l27 = i32_0;
	local_cache[54] = 1;
	i32_0 = 1;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l18_loop:
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l28 = i32_1;
	local_cache[56] = 1;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l8;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l40 = i32_1;
	local_cache[80] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l39 = i32_1;
	local_cache[78] = 1;
	i32_2 = p2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = l12;
	i32_3 = l28;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	i32_3 = l40;
	i32_4 = l12;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = l39;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l12;
	i32_2 = l8;
	i32_1 = (uint)(i32_1) < (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l37;
	i32_1 = l27;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l27 = i32_1;
	local_cache[54] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l18_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l18) */
	i32_0 = l41;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b110;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b111:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l27;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l4;
	i32_3 = 1216;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = l6;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b109;
	}
	i32_0 = l12;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b109;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b110:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b18;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b109:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l16;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l38;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b107:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l36;
	i32_1 = l18;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b112;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l36;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l38;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b113;
	}
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b74;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b113:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b114;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b75;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b114:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l19_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l12;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l19_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b75;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l19) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b112:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l18;
	i32_1 = l18;
	i32_2 = 1049996;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_22:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_23:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_24:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b80:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l36;
	i32_1 = l13;
	i32_2 = 1050012;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_25:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l18;
	i32_2 = 1050012;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_26:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l39;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_27:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l37;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_28:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_29:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b115;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l20_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 10;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l20_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l20) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b115:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i32_0 = (int)(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b74;
	}
	i32_0 = l16;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b73;
	}
	i32_0 = l4;
	i32_1 = 1048;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l16;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l16;
	write_u32_aligned((ulong)((global char*)heap_u32+1208+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l35;
	i32_1 = l13;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 32;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l9) */
	i32_0 = 1;
	l22 = i32_0;
	local_cache[44] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b14;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_30:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b19:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_31:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b18:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_32:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b17:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_33:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b16:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_34:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b15:
	i32_0 = 1055084;
	i32_1 = 26;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_35:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l23;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b123;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l23;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b124;
	}
	i32_0 = 0;
	l23 = i32_0;
	local_cache[46] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b121;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b124:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l23;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b125;
	}
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b122;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b125:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = 0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l21_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 5;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 5;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 5;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 5;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l12;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l21_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b122;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l21) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b123:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l23;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_36:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b122:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b126;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l22_loop:
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 5;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l5;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l5;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l5 = i64_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l22_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l22) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b126:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i32_0 = (int)(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b121;
	}
	i32_0 = l23;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b120;
	}
	i32_0 = l4;
	i32_1 = 1216;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l23;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l23;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l23 = i32_0;
	local_cache[46] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b121:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l23;
	write_u32_aligned((ulong)((global char*)heap_u32+1376+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l16;
	i32_1 = l23;
	i32_2 = l16;
	i32_3 = l23;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b119;
	}
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l23_loop:
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b128;
	}
	i32_0 = -1;
	i32_1 = l6;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l4;
	i32_3 = 1216;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_2 = l6;
	i32_3 = l4;
	i32_4 = 1048;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l23_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b127;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l23) */

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b128:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 0;
	i32_2 = l6;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b127:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b130;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b129;
			break;
		default:
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
			break;
	}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b130:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l22;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
	}
	i32_0 = l13;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l18;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b118;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b129:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l18;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b117;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l24_loop:
	i32_0 = l13;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b131;
	}
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 57;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l24_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_l24) */
	i32_0 = l12;
	i32_1 = l12;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l13;
	i32_1 = l6;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l13;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
	}
	i32_0 = l12;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l6;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b131:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b133;
	}
	i32_0 = 49;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b133:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 49;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 48;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l13;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b132;
	}
	i32_0 = 48;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l13;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b132:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l24;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (short)(i32_0);
	l24 = i32_0;
	local_cache[48] = 1;
	i32_1 = l19;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
	}
	i32_0 = l13;
	i32_1 = l18;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
	}
	i32_0 = l8;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l13;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b120:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_37:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b119:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_38:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b118:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l18;
	i32_2 = 1049948;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_39:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b117:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l18;
	i32_2 = 1049964;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_40:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b116:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l18;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b12;
	}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l24;
	i32_0 = (short)(i32_0);
	i32_1 = l19;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b134;
	}
	i32_0 = l4;
	i32_1 = l6;
	i32_2 = l13;
	i32_3 = l24;
	i32_4 = p3;
	i32_5 = l4;
	i32_6 = 1720;
	i32_5 = (int)(i32_5) + (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 49;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_41:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b134:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+1720+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b135;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051752;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b135:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1736;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+1732+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051676;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l18;
	i32_2 = 1049980;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_42:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1728+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1051752;
	write_u32_aligned((ulong)((global char*)heap_u32+1724+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1720;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1564;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+1560+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l15;
	write_u32_aligned((ulong)((global char*)heap_u32+1556+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l14;
	write_u32_aligned((ulong)((global char*)heap_u32+1552+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 1552;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 204;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		p1 = tempaddr;
	}
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l4;
	i32_1 = 1888;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[15] = { 0 };
	uint l2 = 0;
	ulong l6 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint l7 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_14;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 512;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 512;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b4;
	}
	i32_0 = l2;
	i32_1 = 512;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 512;
	i32_0 = __func_func_getcwd_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 68;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b7;
	}
	i32_0 = 512;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 164;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = __func_func_getcwd_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b3;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062676+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 68;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i64_0 = (ulong)(i32_0);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	l6 = i64_0;
	local_cache[12] = 1;
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i64_0 = (ulong)(i32_0);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	l6 = i64_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b4:
	i32_0 = 1;
	i32_1 = 512;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_2:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = __func_func_strlen_fastcall(i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b8;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b10;
	}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l5;
	i32_0 = __func_func_realloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i64_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b0;
	}
	i64_0 = l6;
	i64_1 = 255;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i64_1 = 3;
	i32_0 = (ulong)(i64_0) != (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b0;
	}
	i64_0 = l6;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l4;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_3:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_4:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_5:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_6:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_7:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_8:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_9:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_10:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_11:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b11;
	}
	i32_0 = l7;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = l5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_12:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1058284;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b15;
	}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b14;
	}
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1058380;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b14;
	}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b12;
	}
	i64_0 = l6;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i64_1 = 0;
	i32_0 = (ulong)(i64_0) != (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b13;
	}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b12;

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b12;
	}
	i64_0 = l6;
	i64_1 = 4294967295;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i32_0 = !(i64_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b12;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l4 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint l5 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_83;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 1088;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b8;
			break;
		case 1:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b7;
			break;
		case 2:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b6;
			break;
		case 3:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b5;
			break;
		default:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b8;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1057688;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+21+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	write_u8((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057690;
	i32_2 = 4;
	i32_3 = l2;
	i32_4 = 12;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1057696;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_6:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 40;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
	}
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b22;
			break;
		case 1:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b17;
			break;
		case 2:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b18;
			break;
		case 3:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 4:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b11;
			break;
		case 5:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 6:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 7:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 8:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 9:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 10:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 11:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b19;
			break;
		case 12:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
			break;
		case 13:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b23;
			break;
		case 14:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 15:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 16:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 17:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 18:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b12;
			break;
		case 19:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 20:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 21:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 22:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 23:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 24:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 25:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b15;
			break;
		case 26:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b14;
			break;
		case 27:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 28:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 29:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 30:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 31:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 32:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 33:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 34:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 35:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 36:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 37:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 38:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 39:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 40:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 41:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 42:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b16;
			break;
		case 43:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 44:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 45:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 46:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 47:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 48:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 49:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 50:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b10;
			break;
		case 51:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b20;
			break;
		case 52:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 53:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 54:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 55:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 56:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 57:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 58:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 59:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 60:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 61:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b22;
			break;
		case 62:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b21;
			break;
		case 63:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 64:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 65:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 66:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 67:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 68:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 69:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 70:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
		case 71:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b13;
			break;
		default:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24;
			break;
	}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 38;
	i32_1 = 40;
	i32_2 = l3;
	i32_3 = 48;
	i32_2 = (int)(i32_2) == (int)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b23:
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b22:
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b21:
	i32_0 = 11;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b20:
	i32_0 = 7;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b19:
	i32_0 = 6;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b18:
	i32_0 = 9;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b17:
	i32_0 = 8;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b16:
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b15:
	i32_0 = 35;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b14:
	i32_0 = 20;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b13:
	i32_0 = 22;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b12:
	i32_0 = 12;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b11:
	i32_0 = 13;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 36;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+31+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1057712;
	i32_2 = 4;
	i32_3 = l2;
	i32_4 = 31;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1057716;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_7:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = 1024;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1024;
	i32_0 = __func_func_strerror_r_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b4;
	}
	i32_0 = l2;
	i32_1 = 1056;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 32;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = __func_func_strlen_fastcall(i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b25;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1060+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1064;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b26;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b3;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b28;
	}
	i32_0 = l5;
	i32_1 = p1;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b27;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b1;
	}
	i32_0 = l5;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_8:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+1060+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+1080+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1057590;
	i32_1 = 43;
	i32_2 = l2;
	i32_3 = 1080;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1059812;
	i32_4 = 1059860;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_9:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1057756;
	i32_3 = 4;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+12+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+12+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+41+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 1056;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1057716;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b29;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b2;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+41+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b2;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b2;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_20:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1057760;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_23:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_24:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_25:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_26:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_27:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_28:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+37+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057712;
	i32_2 = 4;
	i32_3 = p0;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1057716;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_29:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = 1057732;
	i32_2 = 7;
	i32_3 = p0;
	i32_4 = 1057768;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_30:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+37+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b30;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b31;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052207;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_31:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_32:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_33:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_34:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_35:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_36:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052206;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_37:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_38:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_39:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_40:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_41:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_42:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1059083;
	i32_2 = 6;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_43:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_44:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_45:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_46:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_47:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_48:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+37+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057712;
	i32_2 = 4;
	i32_3 = p0;
	i32_4 = 8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1057716;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_49:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = 1059089;
	i32_2 = 5;
	i32_3 = l2;
	i32_4 = 1056;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1059096;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_50:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+37+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b32;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b33;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052207;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_51:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_52:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_53:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_54:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_55:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_56:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052206;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_57:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_58:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_59:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_60:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_61:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_62:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1068;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1060+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1059896;
	write_u32_aligned((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+1064+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1059904;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_63:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_64:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_65:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_66:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_69:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_70:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = p1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+1064+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+1060+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1057732;
	i32_2 = 7;
	i32_3 = l2;
	i32_4 = 1056;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1057740;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_71:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+21+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b35;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b34;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b36;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b37;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052207;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_72:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_73:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_74:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_76:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b36;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052206;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_78:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_79:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_80:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_81:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_82:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_call_return_stub_83:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1060+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1056+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1088;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[35] = { 0 };
	uint p0 = 0;
	uint l15 = 0;
	uint l13 = 0;
	uint l6 = 0;
	uint l17 = 0;
	uint l4 = 0;
	uint l5 = 0;
	uint l14 = 0;
	uint l9 = 0;
	uint l8 = 0;
	ulong l16 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint l10 = 0;
	uint l11 = 0;
	uint l12 = 0;
	uint l7 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_144;
			case 145:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_145;
			case 146:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_146;
			case 147:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_147;
			case 148:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_148;
			case 149:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_149;
			case 150:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_150;
			case 151:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_151;
			case 152:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_152;
			case 153:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_153;
			case 154:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_154;
			case 155:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_155;
			case 156:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_156;
			case 157:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_157;
			case 158:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_158;
			case 159:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_159;
			case 160:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_160;
			case 161:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_161;
			case 162:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_162;
			case 163:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_163;
			case 164:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_164;
			case 165:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_165;
			case 166:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_166;
			case 167:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_167;
			case 168:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_168;
			case 169:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_169;
			case 170:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_170;
			case 171:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_171;
			case 172:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_172;
			case 173:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_173;
			case 174:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_174;
			case 175:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_175;
			case 176:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_176;
			case 177:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_177;
			case 178:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_178;
			case 179:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_179;
			case 180:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_180;
			case 181:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_181;
			case 182:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_182;
			case 183:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_183;
			case 184:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_184;
			case 185:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_185;
			case 186:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_186;
			case 187:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_187;
			case 188:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_188;
			case 189:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_189;
			case 190:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_190;
			case 191:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_191;
			case 192:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_192;
			case 193:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_193;
			case 194:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_194;
			case 195:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_195;
			case 196:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_196;
			case 197:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_197;
			case 198:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_198;
			case 199:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_199;
			case 200:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_200;
			case 201:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_201;
			case 202:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_202;
			case 203:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_203;
			case 204:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_204;
			case 205:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_205;
			case 206:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_206;
			case 207:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_207;
			case 208:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_208;
			case 209:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_209;
			case 210:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_210;
			case 211:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_211;
			case 212:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_212;
			case 213:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_213;
			case 214:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_214;
			case 215:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_215;
			case 216:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_216;
			case 217:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_217;
			case 218:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_218;
			case 219:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_219;
			case 220:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_220;
			case 221:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_221;
			case 222:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_222;
			case 223:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_223;
			case 224:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_224;
			case 225:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_225;
			case 226:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_226;
			case 227:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_227;
			case 228:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_228;
			case 229:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_229;
			case 230:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_230;
			case 231:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_231;
			case 232:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_232;
			case 233:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_233;
			case 234:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_234;
			case 235:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_235;
			case 236:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_236;
			case 237:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_237;
			case 238:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_238;
			case 239:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_239;
			case 240:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_240;
			case 241:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_241;
			case 242:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_242;
			case 243:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_243;
			case 244:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_244;
			case 245:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_245;
			case 246:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_246;
			case 247:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_247;
			case 248:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_248;
			case 249:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_249;
			case 250:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_250;
			case 251:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_251;
			case 252:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_252;
			case 253:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_253;
			case 254:
				*sfp -= 1;
				goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_254;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 34;
	i32_2 = p2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_2;
	local_cache[12] = 1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_2;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b3;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 0;
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b7;
	}
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l12;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l12;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b8;
	}
	i32_0 = l15;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l14;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l11;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l11;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l11;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = -16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b9;
	}
	i32_0 = l14;
	i32_1 = l15;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l9;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l15;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1835008;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b4;
	}
	i32_0 = l11;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l13;
	i32_2 = 65537;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 168;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_60:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 128;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b11;
	}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+10+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b11;
	}
	i32_0 = l10;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b12;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b13;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b12;
	}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5;

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -64;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5;
	}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b14;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b15;
	}
	i32_0 = l10;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b14;
	}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5;

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5;
	}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p0;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l10;
	i32_3 = p2;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = l6;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_61:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_62:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_63:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_64:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_65:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_66:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b17;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l16 = i64_0;
	local_cache[32] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l16;
	i32_0 = (int)(i64_0);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 128;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b18;
	}
	i32_0 = 128;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 128;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b20;
	}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+26+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+27+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b16;
	}
	i32_0 = l3;
	i32_1 = l12;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+26+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l12;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b10;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l15;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l3;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = l7;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_68:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_69:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_77:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_78:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 0;
	return;
	}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b17;
	/* END (loop: __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+26+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 10;
	i32_2 = p2;
	i32_3 = 10;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+27+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = p2;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_127:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l17;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b16;
	}
	i32_0 = l3;
	i32_1 = p2;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l14 = i32_1;
	local_cache[28] = 1;
	write_u8((ulong)((global char*)heap_u32+26+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l12;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b10;
	}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_0 = l14;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = l15;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_132:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_133:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_134:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_135:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_136:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_137:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_138:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_139:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_140:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_141:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_142:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_143:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_144:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 145, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_145:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 146, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_146:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 147, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_147:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 148, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_148:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 149, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_149:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 150, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_150:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 151, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_151:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 152, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_152:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 153, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_153:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 154, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_154:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 155, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_155:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 156, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_156:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 157, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_157:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 158, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_158:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 159, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_159:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 160, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_160:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 161, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_161:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 162, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_162:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 163, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_163:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 164, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_164:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 165, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_165:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 166, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_166:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 167, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_167:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 168, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_168:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 169, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_169:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 170, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_170:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 171, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_171:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 172, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_172:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 173, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_173:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 174, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_174:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 175, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_175:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 176, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_176:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 177, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_177:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 178, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_178:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 179, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_179:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 180, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_180:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 181, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_181:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 182, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_182:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 183, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_183:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 184, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_184:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 185, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_185:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 186, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_186:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b17:
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b21;
	}
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l13;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b21;
	}
	i32_0 = 3;
	i32_1 = 4;
	i32_2 = l13;
	i32_3 = 65536;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = l11;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l9;
	i32_1 = l8;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = 10;
	i32_2 = 1055020;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 187, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_187:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = l10;
	i32_4 = 1052628;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 188, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 199;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_188:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b22;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b23;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b0;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = p1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l12;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b0;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p0;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	i32_3 = l6;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 189, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_189:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 190, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_190:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 191, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_191:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 192, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_192:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 193, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_193:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 194, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_194:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b1;
	}
	i32_0 = l5;
	i32_1 = 34;
	i32_2 = l7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 195, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_195:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 196, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_196:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 197, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_197:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 198, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_198:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 199, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_199:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 200, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_200:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 201, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_201:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 202, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_202:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 203, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_203:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 204, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_204:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 205, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_205:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 206, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_206:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 207, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_207:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 208, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_208:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 209, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_209:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 210, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_210:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 211, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_211:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 212, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_212:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 213, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_213:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 214, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_214:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 215, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_215:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 216, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_216:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 217, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_217:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 218, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_218:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 219, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_219:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 220, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_220:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 221, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_221:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 222, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_222:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 223, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_223:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 224, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_224:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 225, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_225:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 226, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_226:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 227, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_227:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 228, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_228:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 229, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_229:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 230, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_230:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 231, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_231:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 232, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_232:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 233, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_233:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 234, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_234:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 235, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_235:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 236, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_236:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 237, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_237:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 238, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_238:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 239, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_239:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 240, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_240:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 241, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_241:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 242, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_242:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 243, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_243:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 244, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_244:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 245, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_245:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 246, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_246:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 247, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_247:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 248, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_248:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 249, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_249:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 250, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_250:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 251, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_251:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 252, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_252:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 253, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_253:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = p1;
	i32_4 = 1052612;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 254, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 199;
	*is_calling = 1;
	return;
	__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E_call_return_stub_254:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[27] = { 0 };
	uint l11 = 0;
	uint l13 = 0;
	uint l12 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint l7 = 0;
	uint p2 = 0;
	uint l8 = 0;
	uint p1 = 0;
	uint l6 = 0;
	uint l5 = 0;
	uint l4 = 0;
	uint l9 = 0;
	uint l10 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_12;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l1_loop:
	i32_0 = p1;
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = l8;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b4;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b7;
	}
	i32_0 = p0;
	i32_1 = l10;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b7;
	}
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l2_loop:
	i32_0 = l10;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b3;
	}
	i32_0 = l12;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l2) */
	i32_0 = l12;
	i32_1 = l11;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b7:
	i32_0 = l11;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = 0;
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b6:
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l3_loop:
	i32_0 = l10;
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p0;
	i32_2 = 168430090;
	i32_1 = i32_1 ^ i32_2;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b5;
	}
	i32_0 = l9;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p0;
	i32_2 = 168430090;
	i32_1 = i32_1 ^ i32_2;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b5;
	}
	i32_0 = l12;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = l13;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l3) */

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b8;
	}
	i32_0 = p2;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l4_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 10;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b9;
	}
	i32_0 = l12;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b9:
	i32_0 = l11;
	i32_1 = l12;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l4) */
	i32_0 = p2;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b10;
	}
	i32_0 = p2;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b10:
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l5_loop:
	i32_0 = l10;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b3;
	}
	i32_0 = l11;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l5) */
	i32_0 = p2;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b3:
	i32_0 = l8;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b11;
	}
	i32_0 = p1;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 10;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b11;
	}
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l8;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l8;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b11:
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l1) */

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l7;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = p2;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b13;
	}
	i32_0 = l4;
	i32_1 = 1052192;
	i32_2 = 4;
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b12;
	}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = p0;
	i32_1 = l7;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 0;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b14;
	}
	i32_0 = l10;
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l11;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l13;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l4;
	i32_1 = l12;
	i32_2 = l10;
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_l0) */
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint l12 = 0;
	uint l9 = 0;
	uint p1 = 0;
	uint p3 = 0;
	uint p5 = 0;
	uint p0 = 0;
	uint l11 = 0;
	uint l6 = 0;
	uint l7 = 0;
	uint l8 = 0;
	uint p2 = 0;
	uint l10 = 0;
	uint p4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_144;
			case 145:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_145;
			case 146:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_146;
			case 147:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_147;
			case 148:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_148;
			case 149:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_149;
			case 150:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_150;
			case 151:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_151;
			case 152:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_152;
			case 153:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_153;
			case 154:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_154;
			case 155:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_155;
			case 156:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_156;
			case 157:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_157;
			case 158:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_158;
			case 159:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_159;
			case 160:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_160;
			case 161:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_161;
			case 162:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_162;
			case 163:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_163;
			case 164:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_164;
			case 165:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_165;
			case 166:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_166;
			case 167:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_167;
			case 168:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_168;
			case 169:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_169;
			case 170:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_170;
			case 171:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_171;
			case 172:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_172;
			case 173:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_173;
			case 174:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_174;
			case 175:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_175;
			case 176:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_176;
			case 177:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_177;
			case 178:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_178;
			case 179:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_179;
			case 180:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_180;
			case 181:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_181;
			case 182:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_182;
			case 183:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_183;
			case 184:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_184;
			case 185:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_185;
			case 186:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_186;
			case 187:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_187;
			case 188:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_188;
			case 189:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_189;
			case 190:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_190;
			case 191:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_191;
			case 192:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_192;
			case 193:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_193;
			case 194:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_194;
			case 195:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_195;
			case 196:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_196;
			case 197:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_197;
			case 198:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_198;
			case 199:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_199;
			case 200:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_200;
			case 201:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_201;
			case 202:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_202;
			case 203:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_203;
			case 204:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_204;
			case 205:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_205;
			case 206:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_206;
			case 207:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_207;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b1;
	}
	i32_0 = 43;
	i32_1 = 1114112;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	p1 = i32_2;
	local_cache[2] = 1;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p1;
	i32_1 = p5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 45;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b3;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b5;
	}
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l0_loop:
	i32_0 = l9;
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l10;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b8;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = p0;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_1;
	local_cache[20] = 1;
	i32_2 = l7;
	i32_3 = p2;
	i32_4 = p3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 23;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_0:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = l9;
	i32_1 = p4;
	i32_2 = p5;
	i32_3 = l10;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l8;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b9;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = p0;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_1;
	local_cache[20] = 1;
	i32_2 = l7;
	i32_3 = p2;
	i32_4 = p3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 23;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_7:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = l9;
	i32_1 = p4;
	i32_2 = p5;
	i32_3 = l10;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b10;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = p0;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_1;
	local_cache[20] = 1;
	i32_2 = l7;
	i32_3 = p2;
	i32_4 = p3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 23;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_14:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = l11;
	i32_1 = l8;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b11;
	}
	i32_0 = l9;
	i32_1 = 48;
	i32_2 = l10;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_66:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_67:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_68:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_69:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l1) */
	i32_0 = 1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l9;
	i32_1 = p4;
	i32_2 = p5;
	i32_3 = l10;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_76:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_78:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_79:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_80:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = p0;
	i32_1 = l12;
	write_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = l8;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b12;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b14;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b13;
			break;
		case 3:
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b14;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b12;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l9;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l9;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b15;
	}
	i32_0 = l8;
	i32_1 = l9;
	i32_2 = l10;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_132:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_133:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_134:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_135:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_136:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_137:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_138:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_139:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_140:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l2) */
	i32_0 = 1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l9;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = l8;
	i32_1 = l10;
	i32_2 = l7;
	i32_3 = p2;
	i32_4 = p3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 23;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_141:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = l8;
	i32_1 = p4;
	i32_2 = p5;
	i32_3 = l10;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_142:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_143:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_144:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 145, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_145:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 146, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_146:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 147, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_147:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7;
	}
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_148:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b16;
	}
	i32_0 = l6;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l8;
	i32_1 = l9;
	i32_2 = l10;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 149, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_149:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 150, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_150:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 151, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_151:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 152, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_152:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 153, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_153:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 154, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_154:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 155, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_155:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 156, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_156:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 157, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_157:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 158, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_158:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 159, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_159:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 160, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_160:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 161, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_161:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 162, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_162:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 163, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_163:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 164, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_164:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 165, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_165:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 166, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_166:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 167, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_167:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 168, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_168:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 169, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_169:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 170, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_170:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 171, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_171:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 172, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_172:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 173, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_173:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 174, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_174:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 175, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_175:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 176, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_176:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 177, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_177:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 178, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_178:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 179, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_179:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 180, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_180:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 181, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_181:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 182, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_182:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 183, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_183:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 184, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_184:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 185, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_185:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 186, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_186:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 187, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_187:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 188, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_188:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 189, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_189:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 190, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_190:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 191, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_191:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 192, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_192:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 193, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_193:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 194, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_194:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 195, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_195:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 196, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_196:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 197, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_197:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 198, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_198:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 199, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_199:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 200, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_200:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 201, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_201:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 202, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_202:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 203, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_203:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 204, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_204:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 205, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_205:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 206, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_206:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 207, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_call_return_stub_207:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 148, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_l3) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint l9 = 0;
	uint l8 = 0;
	uint p1 = 0;
	uint l11 = 0;
	uint l10 = 0;
	uint l12 = 0;
	uint p2 = 0;
	uint p6 = 0;
	uint p3 = 0;
	uint p5 = 0;
	uint p4 = 0;
	uint p0 = 0;
	uint l7 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_3;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p6 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-14+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_1 = p2;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p0;
	i32_1 = 65280;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) p6 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l0_loop:
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l9;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l8;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b4;
	}
	i32_0 = p1;
	i32_1 = l8;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b1;
	}
	i32_0 = l12;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l11;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l11;
	i32_1 = l7;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b4:
	i32_0 = l12;
	i32_1 = l9;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b3;
	}
	i32_0 = l12;
	i32_1 = p4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b2;
	}
	i32_0 = p3;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l1_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b5;
	}
	i32_0 = l12;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l11;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l11;
	i32_1 = l7;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b5:
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l9;
	i32_1 = l10;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l0) */
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l12;
	i32_2 = 1053464;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = p4;
	i32_2 = 1053464;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) p6 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p5;
	i32_1 = p6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (char)(i32_0);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b7;
	}
	i32_0 = l10;
	p5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = l12;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b8;
	}
	i32_0 = l11;
	i32_1 = 127;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p5;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b8:
	i32_0 = 1057184;
	i32_1 = 43;
	i32_2 = 1053448;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_call_return_stub_3:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = p1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b0;
	}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = i32_0 ^ i32_1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p5;
	i32_1 = l12;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 200;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) p6 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-14+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p1 = 0;
	uint l4 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p2;
	i32_2 = l4;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 8;
	i32_2 = p2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b3;
	}
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b4;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b0;
	}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b1;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint l2 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p1;
	i32_2 = l4;
	i32_3 = p1;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 8;
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b3;
	}
	i32_0 = l2;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l4;
	i32_2 = p1;
	i32_3 = l2;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b4;
	}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b1;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	uint l3 = 0;
	ulong p0 = 0;
	uint p2 = 0;
	uint l4 = 0;
	uint l6 = 0;
	uint p1 = 0;
	ulong l5 = 0;
	uint l8 = 0;
	uint l7 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u64_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 34;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 39;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = p0;
	i64_1 = 10000;
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b1;
	}
	i64_0 = p0;
	l5 = i64_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b1:
	i32_0 = 39;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_l0_loop:
	i32_0 = l3;
	i32_1 = 9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = p0;
	i64_1 = 10000;
	i64_0 = (ulong)(i64_0) / (ulong)(i64_1);
	l5 = i64_0;
	local_cache[10] = 1;
	i64_1 = 55536;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = p0;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i32_1 = (int)(i64_0);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 100;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1052278;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i32_2 = -100;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1052278;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i64_0 = p0;
	i64_1 = 99999999;
	i32_0 = (ulong)(i64_0) > (ulong)(i64_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i64_0 = l5;
	p0 = i64_0;
	local_cache[0] = 1;
	i32_0 = l6;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l5;
	i32_0 = (int)(i64_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 99;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b2;
	}
	i32_0 = l3;
	i32_1 = 9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l5;
	i32_1 = (int)(i64_0);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 100;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = -100;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_2 = l7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1052278;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b4;
	}
	i32_0 = l3;
	i32_1 = 9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1052278;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_2 = 1057276;
	i32_3 = 0;
	i32_4 = l3;
	i32_5 = 9;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = l4;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 39;
	i32_6 = l4;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E_call_return_stub_0:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint l8 = 0;
	ulong l4 = 0;
	uint l2 = 0;
	uint p1 = 0;
	ulong l7 = 0;
	uint l5 = 0;
	uint l6 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_8;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b3;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b0;

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1051504;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b4;
	}
	i64_0 = 0;
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = p0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i64_0 = 0;
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = p0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l0_loop:
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = l4;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l7;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = l4;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l7;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = l4;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l7;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = l4;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l7;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l7;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l1_loop:
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = l4;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l7;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l7 = i64_0;
	local_cache[14] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l7;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l1) */

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l7;
	i32_0 = (int)(i64_0);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b7;
	}
	i32_0 = l3;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b6;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b0;

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b9;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b12;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b13;
	}
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1073741823;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b14;
	}
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b11;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2147483644;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i64_0 = 0;
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = p0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l2_loop:
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 100000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 100000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 100000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l8;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 100000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_2 = 32;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b11;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b15;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l3_loop:
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = 100000000;
	i64_0 = (long)(i64_0) * (long)(i64_1);
	i64_1 = l4;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i64_0 = l4;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_l3) */

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l4;
	i32_0 = (int)(i64_0);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b10;
	}
	i32_0 = l3;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b8;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b16;
	}
	i32_0 = p0;
	i32_1 = 1049592;
	i32_2 = 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 108;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b17;
	}
	i32_0 = p0;
	i32_1 = 1049600;
	i32_2 = 4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 108;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 64;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b18;
	}
	i32_0 = p0;
	i32_1 = 1049616;
	i32_2 = 7;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 108;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b19;
	}
	i32_0 = p0;
	i32_1 = 1049644;
	i32_2 = 14;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 108;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b20;
	}
	i32_0 = p0;
	i32_1 = 1049700;
	i32_2 = 27;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 108;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_b8:
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE_call_return_stub_8:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[15] = { 0 };
	uint l3 = 0;
	uint l4 = 0;
	uint l6 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint p1 = 0;
	uint l7 = 0;
	uint l5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b4;
			break;
		case 1:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 2:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 3:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 4:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 5:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 6:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 7:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 8:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 9:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b8;
			break;
		case 10:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b6;
			break;
		case 11:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 12:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 13:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b7;
			break;
		case 14:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 15:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 16:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 17:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 18:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 19:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 20:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 21:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 22:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 23:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 24:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 25:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 26:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 27:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 28:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 29:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 30:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 31:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 32:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 33:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 34:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b3;
			break;
		case 35:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 36:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 37:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 38:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
			break;
		case 39:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b2;
			break;
		default:
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b9;
			break;
	}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 92;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b5;
	}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 29788;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 29276;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 28252;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 23644;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12380;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
	}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8796;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1;
	}
	i32_0 = p0;
	i32_1 = 512;
	write_u16_aligned((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 10076;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b17;
	}
	i32_0 = p1;
	i32_1 = 11;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 33;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 33;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l0_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = l5;
	i32_2 = 1;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1055228;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 11;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_2 = l4;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	i32_2 = l7;
	i32_3 = l4;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b21;
	}
	i32_0 = l5;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b20;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b21:
	i32_0 = l7;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b19;
	}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b20:
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l0) */

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b26;
	}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 1055228;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 21;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b25;
	}
	i32_0 = 727;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 31;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b26:
	i32_0 = 33;
	i32_1 = 33;
	i32_2 = 1054924;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_0:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1055232;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 21;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b23;
	}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = 1055228;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 2097151;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b23:
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = l6;
	i32_2 = -1;
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b27;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = 727;
	i32_2 = l6;
	i32_3 = 727;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l7;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l1_loop:
	i32_0 = l4;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b12;
	}
	i32_0 = p2;
	i32_1 = l6;
	i32_2 = 1055360;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b27;
	}
	i32_0 = l7;
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_l1) */
	i32_0 = l7;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = 127;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b13;
	}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b14;
	}
	i32_0 = p1;
	i32_1 = 131072;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b15;
	}
	i32_0 = p1;
	i32_1 = -918000;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 196112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -205744;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 712016;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -201547;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 5;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -195102;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1506;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -191457;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3103;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -183970;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 14;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 178206;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 173792;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	i32_0 = p1;
	i32_1 = -177978;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b13;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 125;
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 20;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+9+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_0 = clz(i32_0);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 11;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b11;
	}
	i32_0 = l3;
	i32_1 = 6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 0;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+1055016+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1055018+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 10;
	write_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p2;
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1053480;
	i32_2 = 44;
	i32_3 = 1053568;
	i32_4 = 196;
	i32_5 = 1053764;
	i32_6 = 450;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_6, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 200;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_1:
	*sp += 2;
	*sp -= 14;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b13;
	}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1054214;
	i32_2 = 40;
	i32_3 = 1054294;
	i32_4 = 287;
	i32_5 = 1054581;
	i32_6 = 303;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_6, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 200;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_2:
	*sp += 2;
	*sp -= 14;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10;
	}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 128;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 727;
	i32_2 = 1054940;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 10;
	i32_2 = 1055000;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_4:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 125;
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 20;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 1054956;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+9+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_0 = clz(i32_0);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 11;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b28;
	}
	i32_0 = l3;
	i32_1 = 6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 0;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+1055016+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1055018+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 10;
	write_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p2;
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 10;
	i32_2 = 1055000;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	uint l3 = 0;
	uint p1 = 0;
	uint l8 = 0;
	uint p0 = 0;
	uint l7 = 0;
	uint l6 = 0;
	uint l2 = 0;
	uint l5 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_144;
			case 145:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_145;
			case 146:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_146;
			case 147:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_147;
			case 148:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_148;
			case 149:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_149;
			case 150:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_150;
			case 151:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_151;
			case 152:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_152;
			case 153:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_153;
			case 154:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_154;
			case 155:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_155;
			case 156:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_156;
			case 157:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_157;
			case 158:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_158;
			case 159:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_159;
			case 160:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_160;
			case 161:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_161;
			case 162:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_162;
			case 163:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_163;
			case 164:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_164;
			case 165:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_165;
			case 166:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_166;
			case 167:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_167;
			case 168:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_168;
			case 169:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_169;
			case 170:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_170;
			case 171:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_171;
			case 172:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_172;
			case 173:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_173;
			case 174:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_174;
			case 175:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_175;
			case 176:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_176;
			case 177:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_177;
			case 178:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_178;
			case 179:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_179;
			case 180:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_180;
			case 181:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_181;
			case 182:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_182;
			case 183:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_183;
			case 184:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_184;
			case 185:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_185;
			case 186:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_186;
			case 187:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_187;
			case 188:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_188;
			case 189:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_189;
			case 190:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_190;
			case 191:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_191;
			case 192:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_192;
			case 193:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_193;
			case 194:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_194;
			case 195:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_195;
			case 196:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_196;
			case 197:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_197;
			case 198:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_198;
			case 199:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_199;
			case 200:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_200;
			case 201:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_201;
			case 202:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_202;
			case 203:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_203;
			case 204:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_204;
			case 205:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_205;
			case 206:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_206;
			case 207:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_207;
			case 208:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_208;
			case 209:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_209;
			case 210:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_210;
			case 211:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_211;
			case 212:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_212;
			case 213:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_213;
			case 214:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_214;
			case 215:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_215;
			case 216:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_216;
			case 217:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_217;
			case 218:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_218;
			case 219:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_219;
			case 220:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_220;
			case 221:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_221;
			case 222:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_222;
			case 223:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_223;
			case 224:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_224;
			case 225:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_225;
			case 226:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_226;
			case 227:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_227;
			case 228:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_228;
			case 229:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_229;
			case 230:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_230;
			case 231:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_231;
			case 232:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_232;
			case 233:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_233;
			case 234:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_234;
			case 235:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_235;
			case 236:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_236;
			case 237:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_237;
			case 238:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_238;
			case 239:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_239;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 39;
	i32_2 = p1;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_2;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b1;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 257;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 168;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_59:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 128;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b3;
	}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 128;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 128;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b5;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+11+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b2;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b0;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_66:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_67:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_68:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_69:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_77:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_78:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 0;
	return;
	}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b1;
	/* END (loop: __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 10;
	i32_2 = p1;
	i32_3 = 10;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+11+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = p1;
	i32_2 = l7;
	i32_3 = p1;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_120:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b2;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	write_u8((ulong)((global char*)heap_u32+10+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b0;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l7;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l4;
	i32_1 = l6;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_132:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_133:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_134:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_135:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_136:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_137:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_138:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_139:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_140:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_141:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_142:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_143:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_144:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 145, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_145:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 146, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_146:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 147, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_147:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 148, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_148:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 149, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_149:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 150, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_150:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 151, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_151:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 152, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_152:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 153, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_153:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 154, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_154:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 155, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_155:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 156, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_156:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 157, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_157:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 158, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_158:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 159, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_159:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 160, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_160:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 161, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_161:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 162, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_162:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 163, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_163:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 164, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_164:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 165, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_165:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 166, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_166:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 167, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_167:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 168, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_168:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 169, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_169:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 170, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_170:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 171, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_171:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 172, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_172:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 173, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_173:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 174, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_174:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 175, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_175:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 176, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_176:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 177, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_177:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 178, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_178:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 179, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_179:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 39;
	i32_2 = l5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 180, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_180:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 181, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_181:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 182, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_182:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 183, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_183:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 184, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_184:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 185, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_185:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 186, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_186:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 187, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_187:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 188, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_188:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 189, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_189:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 190, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_190:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 191, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_191:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 192, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_192:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 193, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_193:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 194, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_194:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 195, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_195:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 196, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_196:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 197, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_197:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 198, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_198:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 199, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_199:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 200, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_200:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 201, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_201:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 202, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_202:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 203, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_203:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 204, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_204:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 205, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_205:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 206, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_206:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 207, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_207:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 208, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_208:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 209, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_209:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 210, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_210:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 211, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_211:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 212, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_212:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 213, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_213:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 214, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_214:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 215, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_215:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 216, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_216:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 217, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_217:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 218, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_218:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 219, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_219:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 220, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_220:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 221, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_221:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 222, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_222:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 223, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_223:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 224, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_224:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 225, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_225:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 226, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_226:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 227, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_227:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 228, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_228:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 229, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_229:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 230, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_230:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 231, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_231:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 232, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_232:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 233, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_233:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 234, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_234:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 235, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_235:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 236, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_236:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 237, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_237:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 238, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_238:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 10;
	i32_2 = 1055020;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 239, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E_call_return_stub_239:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint l4 = 0;
	uint l5 = 0;
	uint p1 = 0;
	uint l8 = 0;
	uint l7 = 0;
	uint l6 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_6;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1279;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b1;
	}
	i32_0 = p1;
	i32_1 = 5;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b4;
	}
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l3;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l3;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l0_loop:
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b3;
	}
	i32_0 = l2;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b2;
	}
	i32_0 = l6;
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = -1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	i32_2 = l2;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 5;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 11;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 12;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 13;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 14;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 15;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 17;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 18;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 19;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 20;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 21;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+84+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 22;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 23;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+92+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 24;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 25;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 26;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 27;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+108+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 28;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 29;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 30;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 31;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+128+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 33;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+132+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 34;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+136+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 35;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+140+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 36;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+144+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 37;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+148+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 38;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+152+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 39;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+156+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 40;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0;
	}
	i32_0 = 40;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b1:
	i32_0 = 1055110;
	i32_1 = 29;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_3:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b5;
	}
	i32_0 = p0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b7;
	}
	i32_0 = l5;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 0;
	i32_2 = p1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b8;
	}
	i32_0 = p0;
	i32_1 = l5;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_4:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b10;
	}
	i32_0 = p1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l1_loop:
	i32_0 = l5;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b9;
	}
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_2;
	local_cache[12] = 1;
	i32_3 = p1;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l7;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = -1;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E_call_return_stub_6:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint l4 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint l6 = 0;
	uint l5 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_hypercall_return_stub_0;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_10;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	i32_1 = l3;
	i32_2 = 1;
	i32_3 = l3;
	i32_4 = 12;
	i32_3 = (int)(i32_3) + (int)(i32_4);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+14+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+14+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+14+4), (ulong)stack_u32, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+14+6), (ulong)stack_u32, i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 0;
	fd_write_helper(stack_u32, heap_u32, hypercall_buffer, sp, warp_idx, thread_idx, read_idx, scratch_space, i32_3, i32_2, i32_1, i32_0, hcall_size);
	*hypercall_continuation = 0;
	return;
__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+14+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+14+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_2 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+14+4), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_3 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+14+6), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	write_u32((ulong)((global char*)heap_u32+(int)(i32_3)), (ulong)(heap_u32), hcall_ret_val, warp_idx, read_idx, thread_idx, scratch_space);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b14;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b13;
	}
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 1057916;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 27;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b12;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b9;
			break;
		case 1:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b4;
			break;
		case 2:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b5;
			break;
		case 3:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 4:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 5:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 6:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 7:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 8:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 9:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 10:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 11:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b6;
			break;
		case 12:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
			break;
		case 13:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b11;
			break;
		case 14:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 15:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 16:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 17:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 18:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 19:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 20:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 21:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 22:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 23:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 24:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 25:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 26:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 27:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 28:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 29:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 30:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 31:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 32:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 33:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 34:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 35:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 36:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 37:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 38:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 39:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 40:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 41:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 42:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b3;
			break;
		case 43:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 44:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 45:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 46:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 47:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 48:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 49:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 50:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 51:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b7;
			break;
		case 52:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 53:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 54:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 55:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 56:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 57:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 58:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 59:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 60:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
		case 61:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b10;
			break;
		case 62:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b8;
			break;
		default:
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15;
			break;
	}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b0;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p2;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	if (i32_0 != 0) {
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 0;
	return;
	}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b1;
	/* END (loop: __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_l0) */

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b11:
	i32_0 = 15;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b10:
	i32_0 = 63;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b9:
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b8:
	i32_0 = 64;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b7:
	i32_0 = 53;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b6:
	i32_0 = 13;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b5:
	i32_0 = 4;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b4:
	i32_0 = 3;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b3:
	i32_0 = 44;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b17;
	}
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l5;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_1;
	local_cache[2] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_1:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_2:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_3:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_4:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_5:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_6:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_7:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_8:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_9:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b18;
	}
	i32_0 = l4;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = 1057928;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E_call_return_stub_10:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint l3 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l4 = 0;
	ulong l6 = 0;
	uint l2 = 0;
	uint l5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_b0;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 44;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057228;
	i32_2 = l4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i64_0;
	local_cache[12] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = l6;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i64_0;
	local_cache[12] = 1;
	i32_0 = p1;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = l2;
	i64_0 = l6;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 12;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_b1;
	}
	i32_0 = 4;
	i32_1 = 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_call_return_stub_1:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1058800;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l5 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_10;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062136+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+1062136+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b0;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062144+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 2147483647;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b1;
	}
	i32_0 = __func_func__ZN3std9panicking11panic_count17is_zero_slow_path17h88f026da919a15b3E_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 20;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
	write_u8((ulong)((global char*)heap_u32+23+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1057680;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l3;
	i32_3 = 40;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b4;
	}
	i32_0 = p0;
	i32_1 = 1057960;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b2;

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b2;

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b5;
	}
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_1:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_2:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_3:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_4:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_5:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_6:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_7:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_8:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_9:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b6;
	}
	i32_0 = p2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b7;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062144+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 2147483647;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b7;
	}
	i32_0 = __func_func__ZN3std9panicking11panic_count17is_zero_slow_path17h88f026da919a15b3E_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	if (i32_0 != 0) {
	goto __func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b7;
	}
	i32_0 = 0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+1062137+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062136+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1059676;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 123;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE_call_return_stub_10:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint p0 = 0;
	uint l5 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_15;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 34;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 80;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 1051888;
	i32_2 = 12;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_3;
	local_cache[2] = 1;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b2;
	}
	i32_0 = l2;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051904;
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = 12;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 80:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 11;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_7:
*sp -= 4;
			break;
		case 79:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 139;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_8:
*sp -= 4;
			break;
		case 38:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 187;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_9:
*sp -= 4;
			break;
		case 77:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 86;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_10:
*sp -= 4;
			break;
		case 76:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 125;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_11:
*sp -= 4;
			break;
		case 75:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 137;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_12:
*sp -= 4;
			break;
		case 74:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 124;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_13:
*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = -4493808902380553279;
	i64_0 = (ulong)(i64_0) ^ (ulong)(i64_1);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_1 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_2 = -163230743173927068;
	i64_1 = (ulong)(i64_1) ^ (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i32_0 = !(i64_0);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b1;
	}
	i32_0 = l2;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 17;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051904;
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 52;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 3;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051864;
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 80;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 36;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b2;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i64_0 = (ulong)(i32_0);
	i64_1 = 0;
	i32_0 = p0;
	i64_2 = (int)(i32_0);
	i64_1 = (long)(i64_1) - (long)(i64_2);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	i32_0 = p0;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l0_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l1_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b4;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b5;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 36;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b2;
	}
	i32_0 = p0;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	p0 = i32_0;
	local_cache[0] = 1;
	i64_0 = (ulong)(i32_0);
	i64_1 = 255;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	i64_1 = 0;
	i32_0 = p0;
	i64_2 = (int)(i32_0);
	i64_1 = (long)(i64_1) - (long)(i64_2);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	(i32_0 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	i32_0 = p0;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l0_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l1_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b4;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b5;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b2;
	}
	i32_0 = p0;
	i64_0 = (ulong)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = 1;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l0_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l1_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b4;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b5;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b2;
	}
	i32_0 = p0;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = 1;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l0_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l1_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b4;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b5;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b2;
	}
	i32_0 = p0;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = 1;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l0_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l1_loop:
	i32_0 = l2;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = p0;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b4;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b5;
	}
	i32_0 = p0;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = l3;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = l3;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint l6 = 0;
	uint p4 = 0;
	uint p3 = 0;
	uint p2 = 0;
	uint p5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b3;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 48;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b2;
	}
	i32_0 = p5;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = (short)(i32_0);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b4;
	}
	i32_0 = p5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b5;
	}
	i32_0 = p5;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p3;
	i32_2 = p2;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b6;
	}
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1051675;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_2 = p3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p2 = i32_1;
	local_cache[4] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1051675;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p2;
	i32_1 = p4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b0;
	}
	i32_0 = p4;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 2;
	write_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 1051676;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l6;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	p3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p4;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b0;
	}
	i32_0 = p4;
	i32_1 = p2;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p3;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b0;
	}
	i32_0 = p2;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b3:
	i32_0 = 1051468;
	i32_1 = 33;
	i32_2 = 1051728;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_call_return_stub_0:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b2:
	i32_0 = 1051678;
	i32_1 = 33;
	i32_2 = 1051712;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_call_return_stub_1:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_1 = 0;
	write_u16_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p5;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l3 = 0;
	uint p1 = 0;
	uint l4 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b2;
	}
	i32_0 = p0;
	i64_0 = (ulong)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = 1;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l0_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l1_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i32_3 = l3;
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l4 = i32_3;
	local_cache[8] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b4;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b5;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p1 = 0;
	uint l2 = 0;
	ulong l4 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	uint i32_6 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 34;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b3;
	}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b2;
	}
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = 1;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l0_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 87;
	i64_0 = l4;
	i32_3 = (int)(i64_0);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l3 = i32_3;
	local_cache[6] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i64_0 = l4;
	i64_1 = 16;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i64_0 = l4;
	i64_1 = 4;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l1_loop:
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 127;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = 55;
	i64_0 = l4;
	i32_3 = (int)(i64_0);
	i32_4 = 15;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l3 = i32_3;
	local_cache[6] = 1;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) < (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i64_0 = l4;
	i64_1 = 16;
	i32_0 = (ulong)(i64_0) < (ulong)(i64_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i64_0 = l4;
	i64_1 = 4;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b4;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_2:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 129;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b5;
	}
	i32_0 = l3;
	i32_1 = 128;
	i32_2 = 1052260;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_2 = 1052276;
	i32_3 = 2;
	i32_4 = l2;
	i32_5 = p0;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 128;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 0;
	i32_6 = p0;
	i32_5 = (int)(i32_5) - (int)(i32_6);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 95;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_call_return_stub_4:
	*sp += 2;
	*sp -= 12;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l4 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_2;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_b0;
	}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051840;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_b0;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3str16slice_error_fail17h910c703df873ef46E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p1 = 0;
	uint p3 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint p4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3str16slice_error_fail17h910c703df873ef46E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = p3;
	i32_4 = p4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 115;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str16slice_error_fail17h910c703df873ef46E_call_return_stub_0:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core6result13unwrap_failed17hf48c8310675f070eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint p0 = 0;
	uint p3 = 0;
	uint l5 = 0;
	uint p4 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core6result13unwrap_failed17hf48c8310675f070eE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1052152;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core6result13unwrap_failed17hf48c8310675f070eE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$i64$GT$3fmt17hed20ad7e0e66252bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	ulong l2 = 0;
	ulong l3 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$i64$GT$3fmt17hed20ad7e0e66252bE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i64_0;
	local_cache[4] = 1;
	i64_1 = l2;
	i64_2 = 63;
	i64_1 = (long)i64_1 >> (i64_2 & 63);
	l3 = i64_1;
	local_cache[6] = 1;
	i64_0 = (ulong)(i64_0) ^ (ulong)(i64_1);
	i64_1 = l3;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = l2;
	i64_2 = -1;
	i32_0 = (long)(i64_1) > (long)(i64_2);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u64_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$i64$GT$3fmt17hed20ad7e0e66252bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u64_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_24;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b1;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1055166;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1055170;
	i32_3 = 4;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1052216;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b2;
	}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b3;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b3;
	}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b3;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = l3;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = l3;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_20:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_23:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_call_return_stub_24:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_144;
			case 145:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_145;
			case 146:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_146;
			case 147:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_147;
			case 148:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_148;
			case 149:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_149;
			case 150:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_150;
			case 151:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_151;
			case 152:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_152;
			case 153:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_153;
			case 154:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_154;
			case 155:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_155;
			case 156:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_156;
			case 157:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_157;
			case 158:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_158;
			case 159:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_159;
			case 160:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_160;
			case 161:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_161;
			case 162:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_162;
			case 163:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_163;
			case 164:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_164;
			case 165:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_165;
			case 166:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_166;
			case 167:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_167;
			case 168:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_168;
			case 169:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_169;
			case 170:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_170;
			case 171:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_171;
			case 172:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_172;
			case 173:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_173;
			case 174:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_174;
			case 175:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_175;
			case 176:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_176;
			case 177:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_177;
			case 178:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_178;
			case 179:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_179;
			case 180:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_180;
			case 181:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_181;
			case 182:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_182;
			case 183:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_183;
			case 184:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_184;
			case 185:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_185;
			case 186:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_186;
			case 187:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_187;
			case 188:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_188;
			case 189:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_189;
			case 190:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_190;
			case 191:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_191;
			case 192:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_192;
			case 193:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_193;
			case 194:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_194;
			case 195:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_195;
			case 196:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_196;
			case 197:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_197;
			case 198:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_198;
			case 199:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_199;
			case 200:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_200;
			case 201:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_201;
			case 202:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_202;
			case 203:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_203;
			case 204:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_204;
			case 205:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_205;
			case 206:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_206;
			case 207:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_207;
			case 208:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_208;
			case 209:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_209;
			case 210:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_210;
			case 211:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_211;
			case 212:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_212;
			case 213:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_213;
			case 214:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_214;
			case 215:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_215;
			case 216:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_216;
			case 217:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_217;
			case 218:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_218;
			case 219:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_219;
			case 220:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_220;
			case 221:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_221;
			case 222:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_222;
			case 223:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_223;
			case 224:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_224;
			case 225:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_225;
			case 226:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_226;
			case 227:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_227;
			case 228:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_228;
			case 229:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_229;
			case 230:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_230;
			case 231:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_231;
			case 232:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_232;
			case 233:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_233;
			case 234:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_234;
			case 235:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_235;
			case 236:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_236;
			case 237:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_237;
			case 238:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_238;
			case 239:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_239;
			case 240:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_240;
			case 241:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_241;
			case 242:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_242;
			case 243:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_243;
			case 244:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_244;
			case 245:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_245;
			case 246:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_246;
			case 247:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_247;
			case 248:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_248;
			case 249:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_249;
			case 250:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_250;
			case 251:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_251;
			case 252:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_252;
			case 253:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_253;
			case 254:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_254;
			case 255:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_255;
			case 256:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_256;
			case 257:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_257;
			case 258:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_258;
			case 259:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_259;
			case 260:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_260;
			case 261:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_261;
			case 262:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_262;
			case 263:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_263;
			case 264:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_264;
			case 265:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_265;
			case 266:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_266;
			case 267:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_267;
			case 268:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_268;
			case 269:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_269;
			case 270:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_270;
			case 271:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_271;
			case 272:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_272;
			case 273:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_273;
			case 274:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_274;
			case 275:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_275;
			case 276:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_276;
			case 277:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_277;
			case 278:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_278;
			case 279:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_279;
			case 280:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_280;
			case 281:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_281;
			case 282:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_282;
			case 283:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_283;
			case 284:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_284;
			case 285:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_285;
			case 286:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_286;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b42;
			break;
		case 1:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b41;
			break;
		case 2:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b40;
			break;
		case 3:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b39;
			break;
		case 4:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b38;
			break;
		case 5:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b37;
			break;
		case 6:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b36;
			break;
		case 7:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b35;
			break;
		case 8:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b34;
			break;
		case 9:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b33;
			break;
		case 10:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b32;
			break;
		case 11:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b31;
			break;
		case 12:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b30;
			break;
		case 13:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b29;
			break;
		case 14:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b28;
			break;
		case 15:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b27;
			break;
		case 16:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b26;
			break;
		case 17:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b25;
			break;
		case 18:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b24;
			break;
		case 19:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b23;
			break;
		case 20:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b22;
			break;
		case 21:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b21;
			break;
		case 22:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b20;
			break;
		case 23:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b19;
			break;
		case 24:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b18;
			break;
		case 25:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b17;
			break;
		case 26:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b16;
			break;
		case 27:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b15;
			break;
		case 28:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b14;
			break;
		case 29:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b13;
			break;
		case 30:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b12;
			break;
		case 31:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b11;
			break;
		case 32:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b10;
			break;
		case 33:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b9;
			break;
		case 34:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b8;
			break;
		case 35:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b7;
			break;
		case 36:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b6;
			break;
		default:
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b42;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056104;
	i32_3 = 6;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056088;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b43;
	}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b1;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b1;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b1;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056110;
	i32_3 = 6;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b44;
	}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b2;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b2;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b2;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_20:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_23:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_24:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_25:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056132;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_26:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_27:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_28:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_29:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_30:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_31:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056136;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_32:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_33:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_34:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_35:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_36:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_37:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056140;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_38:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_39:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_40:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_41:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_42:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_43:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056145;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_44:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_45:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_46:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_47:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_48:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_49:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056147;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_50:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_51:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_52:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_53:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_54:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_55:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056150;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_56:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_57:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_58:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_59:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_60:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_61:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056153;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_62:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_63:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_64:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_65:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_66:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056156;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_69:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_70:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_71:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_72:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_73:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056158;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_74:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_76:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_78:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_79:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056161;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_80:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_81:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_82:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_83:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_84:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_85:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056164;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_86:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_87:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_88:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_89:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_90:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_91:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056167;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_92:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_93:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_94:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_95:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_96:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_97:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056170;
	i32_2 = 3;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_98:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_99:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_100:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_101:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_102:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_103:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056173;
	i32_3 = 6;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_104:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_105:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_106:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_107:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_108:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_109:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056088;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_110:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b45;
	}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b3;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b3;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b3;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_111:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_112:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_113:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_114:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_115:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_116:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056179;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_117:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_118:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_119:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_120:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_121:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_122:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056183;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_123:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_124:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_125:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_126:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_127:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_128:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056188;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_129:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_130:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_131:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_132:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_133:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_134:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056193;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_135:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_136:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_137:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_138:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_139:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_140:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056197;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_141:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_142:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_143:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_144:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 145, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_145:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 146, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_146:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056202;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 147, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_147:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 148, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_148:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 149, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_149:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 150, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_150:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 151, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_151:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 152, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_152:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056207;
	i32_3 = 8;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 153, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_153:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 154, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_154:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 155, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_155:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 156, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_156:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 157, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_157:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 158, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_158:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056088;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 159, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_159:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b46;
	}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b4;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b4;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b4;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 160, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_160:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 161, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_161:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 162, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_162:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 163, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_163:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 164, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_164:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 165, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_165:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b4;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056215;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 166, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_166:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 167, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_167:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 168, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_168:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 169, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_169:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 170, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_170:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 171, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_171:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056222;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 172, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_172:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 173, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_173:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 174, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_174:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 175, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_175:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 176, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_176:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 177, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_177:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056229;
	i32_3 = 6;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 178, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_178:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 179, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_179:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 180, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_180:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 181, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_181:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 182, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_182:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 183, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_183:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056088;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 184, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_184:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b47;
	}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b5;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b5;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b5;
	}
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 185, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_185:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 186, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_186:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 187, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_187:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 188, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_188:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 189, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_189:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 190, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_190:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056235;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 191, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_191:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 192, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_192:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 193, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_193:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 194, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_194:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 195, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_195:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 196, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_196:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056240;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 197, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_197:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 198, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_198:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 199, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_199:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 200, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_200:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 201, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_201:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 202, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_202:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056245;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 203, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_203:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 204, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_204:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 205, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_205:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 206, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_206:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 207, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_207:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 208, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_208:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056252;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 209, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_209:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 210, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_210:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 211, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_211:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 212, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_212:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 213, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_213:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 214, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_214:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056259;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 215, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_215:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 216, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_216:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 217, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_217:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 218, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_218:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 219, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_219:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 220, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_220:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056266;
	i32_2 = 7;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 221, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_221:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 222, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_222:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 223, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_223:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 224, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_224:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 225, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_225:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 226, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_226:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056273;
	i32_2 = 8;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 227, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_227:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 228, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_228:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 229, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_229:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 230, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_230:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 231, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_231:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 232, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_232:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056281;
	i32_2 = 4;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 233, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_233:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 234, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_234:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 235, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_235:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 236, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_236:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 237, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_237:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 238, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_238:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056285;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 239, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_239:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 240, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_240:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 241, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_241:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 242, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_242:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 243, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_243:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 244, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_244:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056290;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 245, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_245:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 246, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_246:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 247, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_247:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 248, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_248:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 249, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_249:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 250, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_250:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056295;
	i32_2 = 8;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 251, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_251:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 252, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_252:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 253, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_253:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 254, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_254:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 255, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_255:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 256, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_256:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 257, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_257:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 258, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_258:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 259, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_259:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 260, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_260:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 261, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_261:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 262, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_262:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 263, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_263:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 264, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_264:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 265, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_265:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 266, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_266:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 267, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_267:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 268, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_268:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 269, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_269:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 270, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_270:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 271, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_271:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 272, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_272:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 273, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_273:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 274, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_274:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 275, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_275:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 276, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_276:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 277, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_277:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 278, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_278:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 279, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_279:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 280, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_280:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 281, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_281:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 282, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_282:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 283, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_283:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 284, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_284:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 285, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_285:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 286, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_call_return_stub_286:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	double l3 = 0.0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	{
		ulong temp = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
		___private_memcpy_nonmmu(&f64_0, &temp, sizeof(double));
	}
	l3 = f64_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) {
		ulong temp = 0;
		double tempaddr = l3;
		___private_memcpy_nonmmu(&temp, &tempaddr, sizeof(double));
		write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		l3 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_b0;
	}
	i32_0 = p1;
	f64_0 = l3;
	i32_1 = l2;
	i32_2 = p1;
	i32_3 = 12;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 32;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_call_return_stub_0:
	*sp += 2;
	*sp -= 8;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		l3 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		l3 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	f64_0 = l3;
	i32_1 = l2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) {
		ulong temp = 0;
		double tempaddr = l3;
		___private_memcpy_nonmmu(&temp, &tempaddr, sizeof(double));
		write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 75;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) {
		ulong temp = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		double tempaddr = 0.0;
		___private_memcpy_nonmmu(&tempaddr, &temp, sizeof(double));
		l3 = tempaddr;
	}
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_144;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b16;
			break;
		case 1:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b15;
			break;
		case 2:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b14;
			break;
		case 3:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b13;
			break;
		case 4:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b12;
			break;
		case 5:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b11;
			break;
		case 6:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b10;
			break;
		case 7:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b9;
			break;
		case 8:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b8;
			break;
		default:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b16;
			break;
	}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056336;
	i32_3 = 17;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056356;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b17;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b1;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b1;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b1;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056372;
	i32_3 = 15;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056356;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b18;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b2;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b2;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b2;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_20:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_23:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_24:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_25:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056387;
	i32_3 = 12;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_26:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_27:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_28:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_29:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_30:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_31:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056400;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_32:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b19;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b3;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b3;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b3;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_33:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_34:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_35:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_36:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_37:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_38:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056416;
	i32_2 = 10;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_39:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_40:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_41:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_42:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_43:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_44:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056426;
	i32_3 = 14;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_45:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_46:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_47:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_48:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_49:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_50:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056440;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_51:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b20;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b4;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b4;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b4;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_52:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_53:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_54:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_55:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_56:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_57:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b4;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1059630;
	i32_3 = 13;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_58:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_59:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_60:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_61:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_62:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_63:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056320;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_64:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b21;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b5;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b5;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b5;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_65:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_66:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_69:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_70:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056456;
	i32_3 = 6;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_71:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_72:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_73:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_74:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_76:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056320;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b22;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b6;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b6;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b6;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_78:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_79:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_80:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_81:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_82:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_83:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1056462;
	i32_3 = 9;
	i32_4 = p1;
	i32_5 = 24;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_4) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_84:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_85:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_86:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_87:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_88:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_89:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+8+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1056304;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 190;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_90:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b23;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b7;
	}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b7;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b7;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052212;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_91:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_92:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_93:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_94:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_95:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_96:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b7;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056471;
	i32_2 = 18;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_97:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_98:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_99:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_100:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_101:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_102:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_103:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_104:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_105:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_106:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_107:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_108:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_109:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_110:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_111:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_112:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_113:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_114:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_115:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_116:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_117:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_118:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_119:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_120:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_121:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_122:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_123:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_124:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_125:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_126:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_127:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_128:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_129:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_130:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_131:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_132:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_133:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_134:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_135:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_136:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_137:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_138:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051808;
	i32_2 = 1;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_139:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_140:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_141:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_142:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_143:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_call_return_stub_144:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_19;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056462;
	i32_2 = 9;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1055192;
	i32_2 = 11;
	i32_3 = p0;
	i32_4 = 1055176;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_6:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_1 = 1055203;
	i32_2 = 9;
	i32_3 = l2;
	i32_4 = 4;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_4 = 1055212;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 148;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_7:
	*sp += 2;
	*sp -= 10;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b1;
	}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b2;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052207;
	i32_2 = 2;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052206;
	i32_2 = 1;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint l2 = 0;
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b3;
			break;
		case 1:
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b2;
			break;
		default:
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b0;
			break;
	}

__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b0;
	}
	i32_0 = 1057276;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1058832;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_2;
	local_cache[4] = 1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p0;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l2;
	i32_4 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 70;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_call_return_stub_0:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1058852;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_2;
	local_cache[4] = 1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p0;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l2;
	i32_4 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_4)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 70;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE_call_return_stub_1:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking13assert_failed17h88aeb5e475543e29E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking13assert_failed17h88aeb5e475543e29E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057280;
	i32_2 = l2;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1057280;
	i32_4 = l2;
	i32_5 = 8;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 1059740;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 1;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking13assert_failed17h88aeb5e475543e29E_call_return_stub_0:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_8;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b1;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_0:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_1:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_2:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_3:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_4:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_5:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_6:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_7:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_call_return_stub_8:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b2;
	}
	i32_0 = l2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core5slice5index24slice_end_index_len_fail17h392bb1693dec020aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p2 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core5slice5index24slice_end_index_len_fail17h392bb1693dec020aE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1052728;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core5slice5index24slice_end_index_len_fail17h392bb1693dec020aE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint l3 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b3;
	}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b4;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b5;
	}
	i32_0 = p0;
	i32_1 = l3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 99;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b0;

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b6;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 164;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint l3 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E_b0;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 164;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE_b0;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 66;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking18panic_bounds_check17h543a833f43a239ecE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking18panic_bounds_check17h543a833f43a239ecE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1051988;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking18panic_bounds_check17h543a833f43a239ecE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking5panic17h2f7f1e15b374dfd2E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking5panic17h2f7f1e15b374dfd2E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking5panic17h2f7f1e15b374dfd2E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_22;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b18;
			break;
		case 1:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b17;
			break;
		case 2:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b16;
			break;
		case 3:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b15;
			break;
		case 4:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b14;
			break;
		case 5:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b13;
			break;
		case 6:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b12;
			break;
		case 7:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b11;
			break;
		case 8:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b10;
			break;
		case 9:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b9;
			break;
		case 10:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b8;
			break;
		case 11:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b7;
			break;
		case 12:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b6;
			break;
		case 13:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b5;
			break;
		case 14:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b4;
			break;
		case 15:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b3;
			break;
		case 16:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b2;
			break;
		case 17:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b1;
			break;
		default:
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b18;
			break;
	}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 5;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056672;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 6;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056700;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 7;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056700;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	{
		ulong temp = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
		___private_memcpy_nonmmu(&f64_0, &temp, sizeof(double));
	}
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	i32_0 = l2;
	i32_1 = 8;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056732;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 9;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056760;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 10;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056784;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056792;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056812;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056832;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056856;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056872;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056884;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056896;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056916;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056940;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056964;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1056988;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_20:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint l2 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b3;
	}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b4;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b5;
	}
	i32_0 = p0;
	i32_1 = l3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 134;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b0;

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b6;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 66;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core5slice5index22slice_index_order_fail17h679e58da08ea621aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p2 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core5slice5index22slice_index_order_fail17h679e58da08ea621aE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1052780;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core5slice5index22slice_index_order_fail17h679e58da08ea621aE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5Write9write_fmt17h457cd451a20d6529E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5Write9write_fmt17h457cd451a20d6529E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1052480;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5Write9write_fmt17h457cd451a20d6529E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h6c8cb4c347fceb98E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h6c8cb4c347fceb98E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i64_0 = 3;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051864;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h6c8cb4c347fceb98E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h9b33e863e98a54a9E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h9b33e863e98a54a9E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1052480;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h9b33e863e98a54a9E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17hed3fe2abb51394d6E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17hed3fe2abb51394d6E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1049248;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17hed3fe2abb51394d6E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h751c0741d29bc5ffE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h751c0741d29bc5ffE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057228;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h751c0741d29bc5ffE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h7c22f686d2d0e8d8E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h7c22f686d2d0e8d8E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057252;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h7c22f686d2d0e8d8E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5Write9write_fmt17h7008031b2f3a175fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p1 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5Write9write_fmt17h7008031b2f3a175fE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057252;
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5Write9write_fmt17h7008031b2f3a175fE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_59;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b1;
	}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b5;
	}
	i32_0 = p0;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b4;
	}
	i32_0 = p0;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b3;
	}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p0;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_2 = p1;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b3;
	}
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b2;
	}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b1;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1049161;
	i32_2 = 16;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b3;
	}
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b2;
	}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b1;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1049177;
	i32_2 = 16;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_rust_begin_unwind(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func_rust_begin_unwind_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func_rust_begin_unwind_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func_rust_begin_unwind_b0;
	}
	i32_0 = 1057184;
	i32_1 = 43;
	i32_2 = 1058784;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func_rust_begin_unwind_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func_rust_begin_unwind_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 77;
	*is_calling = 1;
	return;
	__func_func_rust_begin_unwind_call_return_stub_1:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p1 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b3;
	}
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b2;
	}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b1;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3fc94b77ededba77E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3fc94b77ededba77E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3fc94b77ededba77E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1048576;
	i32_2 = 10;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1056644;
	i32_2 = 8;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b3;
	}
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b2;
	}
	i32_0 = p1;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b1;
	}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 224;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 192;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+15+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+14+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 128;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+13+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 7;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 240;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 4;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1051848;
	i32_2 = 14;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	p0 = i32_1;
	local_cache[0] = 1;
	i32_2 = 1060200;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_3 = 1060036;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 26;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1057760;
	i32_2 = 5;
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h76913d7c9fce1378E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h76913d7c9fce1378E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h76913d7c9fce1378E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_58;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 24;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p0;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u32$GT$3fmt17h4fbd4b654b964086E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u32$GT$3fmt17h4fbd4b654b964086E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i64_0 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = 1;
	i32_1 = p1;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u32$GT$3fmt17h4fbd4b654b964086E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u64$GT$3fmt17hc6d34ca91759d841E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u64$GT$3fmt17hc6d34ca91759d841E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = 1;
	i32_1 = p1;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 171;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u64$GT$3fmt17hc6d34ca91759d841E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17h9296ce6d0b4dad2bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i64_0 = 7912501143857784762;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 1677015036563326081;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_58;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtDebug$GT$3fmt17h381ed2cb32560180E332(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtDebug$GT$3fmt17h381ed2cb32560180E332_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 1;
	return;
	__func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtDebug$GT$3fmt17h381ed2cb32560180E332_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17h644e479311ce68f2E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i64_0 = -163230743173927068;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = -4493808902380553279;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hac957ce827fb6e33E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hac957ce827fb6e33E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hac957ce827fb6e33E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h54e5431924cf55b2E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h54e5431924cf55b2E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h54e5431924cf55b2E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h628701fbe6b33d3fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h628701fbe6b33d3fE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h628701fbe6b33d3fE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3a6550c49951b1d9E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3a6550c49951b1d9E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3a6550c49951b1d9E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
	goto __func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_b0;
	}
	i32_0 = p1;
	i32_1 = 1052600;
	i32_2 = 5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1052605;
	i32_2 = 4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hcaf0862805a36131E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hcaf0862805a36131E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 60;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hcaf0862805a36131E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
	goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_b0;
	}
	i32_0 = p1;
	i32_1 = 1052600;
	i32_2 = 5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1052605;
	i32_2 = 4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_58;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17hbee2961531151bddE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i64_0 = 6146099213658827405;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = -3988785156179279576;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN59_$LT$corefmtArguments$u20$as$u20$corefmtDisplay$GT$3fmt17h341ff6928aa3d36bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN59_$LT$corefmtArguments$u20$as$u20$corefmtDisplay$GT$3fmt17h341ff6928aa3d36bE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN59_$LT$corefmtArguments$u20$as$u20$corefmtDisplay$GT$3fmt17h341ff6928aa3d36bE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h95bfb4d5d740b326E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h95bfb4d5d740b326E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h95bfb4d5d740b326E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h36473c0450a6f995E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h36473c0450a6f995E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 22;
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p0;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 1;
	return;
	__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h36473c0450a6f995E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hd6b33ab562f09db7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hd6b33ab562f09db7E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hd6b33ab562f09db7E_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___rust_alloc_error_handler(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func___rust_alloc_error_handler_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 82;
	*is_calling = 1;
	return;
	__func_func___rust_alloc_error_handler_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___rg_oom(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func___rg_oom_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p1;
	i32_1 = p0;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 100;
	*is_calling = 1;
	return;
	__func_func___rg_oom_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc5alloc18handle_alloc_error17hac4f7515a97bd968E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc5alloc18handle_alloc_error17hac4f7515a97bd968E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 129;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc5alloc18handle_alloc_error17hac4f7515a97bd968E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std5alloc8rust_oom17hb466c6b0b424784eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc8rust_oom17hb466c6b0b424784eE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 45;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc8rust_oom17hb466c6b0b424784eE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	__func_func__ZN3std7process5abort17hd45c1523f6588d30E_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec17capacity_overflow17ha2fa7309cb777b97E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint l0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec17capacity_overflow17ha2fa7309cb777b97E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1049320;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1049328;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec17capacity_overflow17ha2fa7309cb777b97E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std6thread8ThreadId3new9exhausted17h35806fdda5b22e83E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint l0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std6thread8ThreadId3new9exhausted17h35806fdda5b22e83E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1057552;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057560;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN3std6thread8ThreadId3new9exhausted17h35806fdda5b22e83E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ops8function6FnOnce9call_once17h6f4abb2291c2f20eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3ops8function6FnOnce9call_once17h6f4abb2291c2f20eE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
__func_func__ZN4core3ops8function6FnOnce9call_once17h6f4abb2291c2f20eE_call_return_stub_0:
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 0;
	return;
	/* END (loop: __func_func__ZN4core3ops8function6FnOnce9call_once17h6f4abb2291c2f20eE_l0) */
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std10sys_common9backtrace26__rust_end_short_backtrace17hd312084468c4357cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace26__rust_end_short_backtrace17hd312084468c4357cE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 96;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace26__rust_end_short_backtrace17hd312084468c4357cE_call_return_stub_0:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr100drop_in_place$LT$$RF$mut$u20$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17hc678b1c1755486caE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr27drop_in_place$LT$$RF$i8$GT$17h101cdb19fde65453E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17he8cc0efc923178bfE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = 1058816;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l4 = 0;
	uint l3 = 0;
	ulong l5 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E_b0;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057228;
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_1;
	local_cache[2] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i64_0;
	local_cache[10] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = l5;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1058800;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l2 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_18;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1058572;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l2;
	i32_3 = 32;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b1;
	}
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b0;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b2;
	}
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_1;
	local_cache[2] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_1:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_2:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_3:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_4:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_5:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_6:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_7:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_8:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_9:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b3;
	}
	i32_0 = l4;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b4;
	}
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b0;
	}

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_1;
	local_cache[2] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_10:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_11:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_12:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_13:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_14:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_15:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_16:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_17:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_call_return_stub_18:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b5;
	}
	i32_0 = l4;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core5slice5index26slice_start_index_len_fail17h0d54849012697d98E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p0 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core5slice5index26slice_start_index_len_fail17h0d54849012697d98E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1052696;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core5slice5index26slice_start_index_len_fail17h0d54849012697d98E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[33] = { 0 };
	uint p0 = 0;
	uint l10 = 0;
	uint p2 = 0;
	uint l8 = 0;
	uint l6 = 0;
	uint l13 = 0;
	uint l14 = 0;
	uint l11 = 0;
	uint p1 = 0;
	uint l9 = 0;
	uint l4 = 0;
	uint l7 = 0;
	uint l3 = 0;
	ulong l16 = 0;
	uint l5 = 0;
	ulong l15 = 0;
	uint l12 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_5;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 160;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 0;
	i32_2 = 160;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b3;
	}
	i32_0 = l4;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b1;
	}
	i32_0 = l4;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p1;
	i32_1 = p2;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l0_loop:
	i32_0 = l3;
	i32_1 = l8;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l1_loop:
	i32_0 = l8;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l10;
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = p1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b2;
	}
	i32_0 = l12;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l11;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l1) */
	i32_0 = l13;
	i64_0 = (ulong)(i32_0);
	l15 = i64_0;
	local_cache[30] = 1;
	i64_0 = 0;
	l16 = i64_0;
	local_cache[32] = 1;
	i32_0 = l5;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l11;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l2_loop:
	i32_0 = p1;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b4;
	}
	i32_0 = l12;
	i64_0 = l16;
	i32_1 = l12;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i32_1 = l10;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_2 = l15;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l16 = i64_0;
	local_cache[32] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l16;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l16 = i64_0;
	local_cache[32] = 1;
	i32_0 = l12;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l10;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l13;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l2) */
	i32_0 = l4;
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l16;
	i32_0 = (int)(i64_0);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b6;
	}
	i32_0 = l11;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b5;
	}
	i32_0 = l3;
	i32_1 = l12;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b6:
	i32_0 = l9;
	i32_1 = l12;
	i32_2 = l11;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l9;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l14;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l0_loop;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l0) */
	i32_0 = l12;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 41;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b0;
	}
	i32_0 = p2;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = 0;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = p0;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l3_loop:
	i32_0 = l3;
	i32_1 = l11;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l4_loop:
	i32_0 = l11;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l8;
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l10;
	i32_1 = l14;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b2;
	}
	i32_0 = l12;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l13;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = l10;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l10;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l4) */
	i32_0 = l7;
	i64_0 = (ulong)(i32_0);
	l15 = i64_0;
	local_cache[30] = 1;
	i64_0 = 0;
	l16 = i64_0;
	local_cache[32] = 1;
	i32_0 = l5;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l13;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p1;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l5_loop:
	i32_0 = l10;
	i32_1 = 40;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b7;
	}
	i32_0 = l12;
	i64_0 = l16;
	i32_1 = l12;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_0 = (long)(i64_0) + (long)(i64_1);
	i32_1 = l8;
	i64_1 = (ulong)(read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_2 = l15;
	i64_1 = (long)(i64_1) * (long)(i64_2);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l16 = i64_0;
	local_cache[32] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (int)(i64_0), warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l16;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	l16 = i64_0;
	local_cache[32] = 1;
	i32_0 = l12;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l10;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l8;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l7;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l5) */
	i32_0 = p2;
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l16;
	i32_0 = (int)(i64_0);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b9;
	}
	i32_0 = l13;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = 39;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b8;
	}
	i32_0 = l3;
	i32_1 = l12;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l10;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b9:
	i32_0 = l9;
	i32_1 = l12;
	i32_2 = l13;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l9;
	i32_3 = l12;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l4;
	l10 = i32_0;
	local_cache[20] = 1;
	goto __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l3_loop;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[32]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_l3) */
	i32_0 = l12;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 160;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 160;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 40;
	i32_2 = 1055068;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_4:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 40;
	i32_2 = 1055068;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[23] = { 0 };
	uint l2 = 0;
	uint l8 = 0;
	uint l10 = 0;
	uint l6 = 0;
	uint l11 = 0;
	uint l7 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint l9 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_128;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b3;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_1;
	local_cache[2] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 8;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b4;
	}
	i32_0 = l8;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l7;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l6;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = l6;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b1;
	}
	i32_0 = 1;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 48;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p0;
	i32_1 = 48;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = l3;
	i32_2 = l6;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = l6;
	i32_3 = l3;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 154;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b5;
	}
	i32_0 = l4;
	i32_1 = 12;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_l0_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b9;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b7;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b8;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b9;
			break;
	}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b9:
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b8:
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = 1000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b10;
	}
	i32_0 = 4;
	i32_1 = 5;
	i32_2 = l11;
	i32_3 = 10000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b10:
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l11;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b6;
	}
	i32_0 = 2;
	i32_1 = 3;
	i32_2 = l11;
	i32_3 = 100;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b6:
	i32_0 = l5;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l4;
	i32_1 = -12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b13;
	}
	i32_0 = l3;
	i32_1 = p1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b14;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b16;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b15;
			break;
		case 3:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b16;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b14;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b14;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b12;
	}
	i32_0 = l6;
	i32_1 = l9;
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_66:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 204;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 154;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b11;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = p1;
	i32_2 = l2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 154;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b1;
	}
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b18;
	}
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_1 = l9;
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_77:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_78:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 204;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l7;
	write_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b0;

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b1:
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[21] = { 0 };
	uint p0 = 0;
	uint p3 = 0;
	uint l7 = 0;
	uint p1 = 0;
	uint p4 = 0;
	uint l5 = 0;
	ulong l10 = 0;
	uint p2 = 0;
	uint l9 = 0;
	uint l6 = 0;
	uint l8 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_143;
			case 144:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_144;
			case 145:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_145;
			case 146:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_146;
			case 147:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_147;
			case 148:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_148;
			case 149:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_149;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b1;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052199;
	i32_2 = 1052196;
	i32_3 = l7;
	i32_4 = 255;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	l7 = i32_3;
	local_cache[14] = 1;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = 2;
	i32_3 = 3;
	i32_4 = l7;
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_3 = l8;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = l8;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052148;
	i32_2 = 2;
	i32_3 = l8;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = p3;
	i32_1 = l8;
	i32_2 = p4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_66:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_67:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_68:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_69:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b2;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052201;
	i32_2 = 3;
	i32_3 = l8;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_78:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_79:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_80:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_81:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_82:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+23+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1052168;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l8;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l8;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i64_0;
	local_cache[20] = 1;
	i32_0 = l5;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l8;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l8;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i64_0 = l10;
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_83:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1052148;
	i32_2 = 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_84:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = p3;
	i32_1 = l5;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p4;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_132:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_133:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_134:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_135:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_136:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_137:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_138:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_139:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_140:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_141:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_142:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_143:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052204;
	i32_2 = 2;
	i32_3 = l5;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 144, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_144:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 145, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_145:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 146, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_146:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 147, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_147:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 148, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_148:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 149, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_call_return_stub_149:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt5write17h80c8117f546444b5E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint l5 = 0;
	uint l12 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint l8 = 0;
	uint l7 = 0;
	uint l4 = 0;
	uint p2 = 0;
	uint p1 = 0;
	uint l10 = 0;
	uint l11 = 0;
	uint l6 = 0;
	uint l9 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_137;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 32;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b3;
	}
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b2;
	}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 536870911;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b4;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l7;
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l6;
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5write17h80c8117f546444b5E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b2;
	}
	i32_0 = p1;
	i32_1 = 5;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 134217727;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b5;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_69:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_70:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_71:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_72:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l5;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 0;
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b7;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b8;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b6;
			break;
		default:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b7;
			break;
	}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l10;
	i32_1 = l12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 11;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b6;
	}
	i32_0 = l12;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b7:
	i32_0 = 1;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b10;
			break;
		case 1:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b11;
			break;
		case 2:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b9;
			break;
		default:
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b10;
			break;
	}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l10;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 11;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b9;
	}
	i32_0 = l9;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b10:
	i32_0 = 1;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l11;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l10;
	i32_1 = p1;
	i32_2 = 20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 3;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_77:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_78:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1;
	}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l8;
	i32_1 = l6;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt5write17h80c8117f546444b5E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b12;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l4;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_132:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_133:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_134:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_135:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_136:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt5write17h80c8117f546444b5E_call_return_stub_137:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b12:
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt5write17h80c8117f546444b5E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b1:
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt5write17h80c8117f546444b5E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	ulong l8 = 0;
	uint p2 = 0;
	uint l7 = 0;
	uint l5 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint l6 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_135;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b1;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b2;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052199;
	i32_2 = 1052209;
	i32_3 = l4;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	i32_2 = 2;
	i32_3 = 1;
	i32_4 = l4;
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	i32_3 = l6;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0;
	}
	i32_0 = p1;
	i32_1 = l6;
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052210;
	i32_2 = 2;
	i32_3 = l6;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_65:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_66:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_67:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_68:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_69:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_70:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b4;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l3;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+23+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1052168;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i64_0;
	local_cache[16] = 1;
	i32_0 = l3;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l6;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i64_0 = l8;
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_72:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_73:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_74:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_75:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_76:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_77:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_78:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1052204;
	i32_2 = 2;
	i32_3 = l3;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_130:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_131:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_132:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_133:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_134:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_call_return_stub_135:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l5;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc5alloc18handle_alloc_error8rt_error17hb51ed5ed7a7011fbE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc5alloc18handle_alloc_error8rt_error17hb51ed5ed7a7011fbE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p1;
	i32_1 = p0;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 160;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc5alloc18handle_alloc_error8rt_error17hb51ed5ed7a7011fbE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr25drop_in_place$LT$bool$GT$17h8b00e9de3af4761aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l5 = 0;
	uint p3 = 0;
	uint p4 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_64;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b2;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_1 = p2;
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_0:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_1:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_2:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_3:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_4:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_5:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_6:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_7:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_8:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_9:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_10:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_11:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_12:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b0;
	}
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p3;
	i32_2 = p4;
	i32_3 = p1;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_59:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_60:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_61:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_62:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_63:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E_call_return_stub_64:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[19] = { 0 };
	uint l5 = 0;
	uint p0 = 0;
	uint l8 = 0;
	uint l9 = 0;
	uint p3 = 0;
	uint p1 = 0;
	uint l7 = 0;
	uint p2 = 0;
	uint l6 = 0;
	uint p4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_6;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 112;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 257;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b2;
	}
	i32_0 = 256;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+256+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b3;
	}
	i32_0 = 255;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+255+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b3;
	}
	i32_0 = 254;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+254+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b3;
	}
	i32_0 = 253;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+253+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 5;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 1053140;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 1057276;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 0;
	i32_3 = 253;
	i32_4 = p4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 199;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_0:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b7;
	}
	i32_0 = p3;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b7;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p3;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b11;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b13;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b14;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b13;
	}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b12;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -64;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b12;
	}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b15;
	}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 0;
	i32_2 = p2;
	i32_3 = -3;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p3 = i32_2;
	local_cache[6] = 1;
	i32_3 = p3;
	i32_4 = p2;
	i32_3 = (uint)(i32_3) > (uint)(i32_4);
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	p3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = l6;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
	}
	i32_0 = p0;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	i32_2 = p3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b17;
	}
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b18;
	}
	i32_0 = l6;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b19;
	}
	i32_0 = l6;
	i32_1 = -3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b20;
	}
	i32_0 = l6;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16;
	}
	i32_0 = l6;
	i32_1 = -5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = p3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b21;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b23;
	}
	i32_0 = p1;
	i32_1 = p3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b22;
	}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b4;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b4;
	}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b25;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p2;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p2;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b24;
	}
	i32_0 = l6;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p0;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p2;
	i32_1 = -16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b10;
	}
	i32_0 = p0;
	i32_1 = l6;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 100;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 92;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 4;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1053284;
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 72;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l6;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1835008;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b5;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b8;
	}
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 2048;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b8;
	}
	i32_0 = 3;
	i32_1 = 4;
	i32_2 = p1;
	i32_3 = 65536;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = p3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 5;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 108;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 100;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 92;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 19;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 5;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1053208;
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 72;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_2:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	i32_2 = p3;
	i32_3 = l6;
	(i32_3 != 0) ? (i32_1 = i32_1) : (i32_1 = i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 92;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1053340;
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 72;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_3:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = l6;
	i32_2 = 1053392;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_4:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1057184;
	i32_1 = 43;
	i32_2 = p4;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p3;
	i32_3 = p1;
	i32_4 = p4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 199;
	*is_calling = 1;
	return;
	__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E_call_return_stub_6:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr70drop_in_place$LT$stdpanickingbegin_panic_handlerPanicPayload$GT$17hd62d624acfbbc3d7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ptr70drop_in_place$LT$stdpanickingbegin_panic_handlerPanicPayload$GT$17hd62d624acfbbc3d7E_b0;
	}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ptr70drop_in_place$LT$stdpanickingbegin_panic_handlerPanicPayload$GT$17hd62d624acfbbc3d7E_b0;
	}
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN4core3ptr70drop_in_place$LT$stdpanickingbegin_panic_handlerPanicPayload$GT$17hd62d624acfbbc3d7E_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[29] = { 0 };
	uint l12 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint l14 = 0;
	uint p0 = 0;
	uint l8 = 0;
	uint l6 = 0;
	uint l11 = 0;
	uint l5 = 0;
	uint l9 = 0;
	uint p2 = 0;
	uint l10 = 0;
	uint l13 = 0;
	uint l7 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_136;
			case 137:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_137;
			case 138:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_138;
			case 139:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_139;
			case 140:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_140;
			case 141:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_141;
			case 142:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_142;
			case 143:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_143;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p1;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l0_loop:
	i32_0 = l8;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b4;
	}
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b6;
	}
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l9;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b6:
	i32_0 = l4;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l9;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b7;
	}
	i32_0 = l8;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l10;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l4;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b7:
	i32_0 = l10;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = -16;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b8;
	}
	i32_0 = l10;
	i32_1 = l8;
	i32_2 = 12;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b8:
	i32_0 = l10;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l8;
	i32_2 = 18;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1835008;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
	}
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b5:
	i32_0 = l7;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l9;
	i32_1 = 1114112;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l0) */

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l5;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b9;
	}
	i32_0 = l8;
	i32_1 = -32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b9;
	}
	i32_0 = l8;
	i32_1 = -16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b9;
	}
	i32_0 = l4;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 63;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 6;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 12;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l8;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 18;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = 1835008;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b11;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b12;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l7;
	i32_1 = p2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b11;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -64;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b10;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = p2;
	i32_2 = l4;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l4;
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b13;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b14;
	}
	i32_0 = p2;
	i32_1 = p1;
	i32_2 = 3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l9 = i32_1;
	local_cache[18] = 1;
	i32_2 = p1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b15;
	}
	i32_0 = l8;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = p1;
	i32_2 = -1;
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b16;
	}
	i32_0 = 0;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l1_loop:
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = l6;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i32_2 = 3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b15;
	}
	i32_0 = p1;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l2_loop:
	i32_0 = l4;
	i32_1 = l8;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l8;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l7;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b17;
	}
	i32_0 = l9;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l10;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b17;
	}
	i32_0 = l5;
	i32_1 = l8;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l10;
	i32_1 = 2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b17;
	}
	i32_0 = l5;
	i32_1 = l8;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l5;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l3_loop:
	i32_0 = l9;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l7;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b0;
	}
	i32_0 = l7;
	i32_1 = 192;
	i32_2 = l7;
	i32_3 = 192;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 252;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b19;
	}
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b19:
	i32_0 = l3;
	i32_1 = l14;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l3;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l4_loop:
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b18;
	}
	i32_0 = l4;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l9;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 16843009;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_1;
	local_cache[18] = 1;
	i32_2 = -1;
	i32_1 = i32_1 ^ i32_2;
	i32_2 = 7;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = l9;
	i32_3 = 6;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = 16843009;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l4;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_2;
	local_cache[18] = 1;
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_3 = 7;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = l9;
	i32_4 = 6;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = 16843009;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l4;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_3;
	local_cache[18] = 1;
	i32_4 = -1;
	i32_3 = i32_3 ^ i32_4;
	i32_4 = 7;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = l9;
	i32_5 = 6;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_4 = 16843009;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = l8;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l4) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b18:
	i32_0 = l7;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l8;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 16711935;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l8;
	i32_2 = 16711935;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 65537;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l12;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l3) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b20;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l14;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l4;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 16843009;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l12;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b1;
	}
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l9;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 16843009;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l12;
	i32_1 = 2;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b1;
	}
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l8;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 16843009;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b21;
	}
	i32_0 = 0;
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b23;
	}
	i32_0 = 0;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p2;
	i32_1 = -4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b22;
	}
	i32_0 = l10;
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+5+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+6+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+7+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b22;
	}
	i32_0 = l10;
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+9+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+10+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+11+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b0;
	}
	i32_0 = p1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l5_loop:
	i32_0 = l10;
	i32_1 = l4;
	i32_1 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_2 = -65;
	i32_1 = (int)(i32_1) > (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l8;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l5) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_6:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = 459007;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l4;
	i32_2 = 16711935;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 65537;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	i32_1 = 16;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = l10;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b24;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l11;
	i32_1 = l10;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b25;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b27;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b26;
			break;
		case 3:
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b25;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b25;
			break;
	}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l8;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b25;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l8;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b28;
	}
	i32_0 = l6;
	i32_1 = l8;
	i32_2 = l9;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_13:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_14:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_15:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_16:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_17:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_18:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_19:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_20:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_21:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_22:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_23:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_24:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_25:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_26:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_27:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_28:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_29:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_30:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_31:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_32:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_33:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_34:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_35:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_36:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_37:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_38:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_39:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_40:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_41:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_42:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_43:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_44:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_45:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_46:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_47:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_48:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_49:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_50:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_51:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_52:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_53:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_54:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_55:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_56:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_57:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_58:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_59:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_60:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_61:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_62:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_63:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_64:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_65:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_66:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_67:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_68:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_69:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_70:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_71:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l6) */
	i32_0 = 1;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 1114112;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b29;
	}
	i32_0 = l6;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = l9;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_72:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_73:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_74:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_76:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_77:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b29;
	}
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b31;
	}
	i32_0 = l7;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = l8;
	i32_2 = l9;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 6;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_79:
	*sp += 2;
	*sp -= 4;
			break;
		case 43:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 78;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_80:
	*sp += 2;
	*sp -= 4;
			break;
		case 8:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 169;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_81:
	*sp += 2;
	*sp -= 4;
			break;
		case 5:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 98;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_82:
	*sp += 2;
	*sp -= 4;
			break;
		case 3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 93;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_83:
	*sp += 2;
	*sp -= 4;
			break;
		case 32:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 198;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_84:
	*sp += 2;
	*sp -= 4;
			break;
		case 29:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 39;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_85:
	*sp += 2;
	*sp -= 4;
			break;
		case 45:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 20;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_86:
	*sp += 2;
	*sp -= 4;
			break;
		case 51:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 192;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_87:
	*sp += 2;
	*sp -= 4;
			break;
		case 21:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 65;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_88:
	*sp += 2;
	*sp -= 4;
			break;
		case 62:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 113;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_89:
	*sp += 2;
	*sp -= 4;
			break;
		case 24:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 118;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_90:
	*sp += 2;
	*sp -= 4;
			break;
		case 60:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 138;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_91:
	*sp += 2;
	*sp -= 4;
			break;
		case 47:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 181;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_92:
	*sp += 2;
	*sp -= 4;
			break;
		case 72:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 142;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_93:
	*sp += 2;
	*sp -= 4;
			break;
		case 41:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 4;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_94:
	*sp += 2;
	*sp -= 4;
			break;
		case 67:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 180;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_95:
	*sp += 2;
	*sp -= 4;
			break;
		case 4:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 111;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_96:
	*sp += 2;
	*sp -= 4;
			break;
		case 65:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 202;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_97:
	*sp += 2;
	*sp -= 4;
			break;
		case 46:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 43;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_98:
	*sp += 2;
	*sp -= 4;
			break;
		case 10:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 15;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_99:
	*sp += 2;
	*sp -= 4;
			break;
		case 50:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 14;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_100:
	*sp += 2;
	*sp -= 4;
			break;
		case 13:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 68;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_101:
	*sp += 2;
	*sp -= 4;
			break;
		case 15:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 37;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_102:
	*sp += 2;
	*sp -= 4;
			break;
		case 18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 195;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_103:
	*sp += 2;
	*sp -= 4;
			break;
		case 58:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 88;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_104:
	*sp += 2;
	*sp -= 4;
			break;
		case 2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 79;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_105:
	*sp += 2;
	*sp -= 4;
			break;
		case 1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 41;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_106:
	*sp += 2;
	*sp -= 4;
			break;
		case 22:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 2;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_107:
	*sp += 2;
	*sp -= 4;
			break;
		case 48:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 196;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_108:
	*sp += 2;
	*sp -= 4;
			break;
		case 63:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 80;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_109:
	*sp += 2;
	*sp -= 4;
			break;
		case 19:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 28;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_110:
	*sp += 2;
	*sp -= 4;
			break;
		case 28:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 76;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_111:
	*sp += 2;
	*sp -= 4;
			break;
		case 69:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 104;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_112:
	*sp += 2;
	*sp -= 4;
			break;
		case 16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 201;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_113:
	*sp += 2;
	*sp -= 4;
			break;
		case 9:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 33;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_114:
	*sp += 2;
	*sp -= 4;
			break;
		case 17:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 189;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_115:
	*sp += 2;
	*sp -= 4;
			break;
		case 11:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 114;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_116:
	*sp += 2;
	*sp -= 4;
			break;
		case 73:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 12;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_117:
	*sp += 2;
	*sp -= 4;
			break;
		case 6:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 3;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_118:
	*sp += 2;
	*sp -= 4;
			break;
		case 39:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 161;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_119:
	*sp += 2;
	*sp -= 4;
			break;
		case 61:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 112;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_120:
	*sp += 2;
	*sp -= 4;
			break;
		case 36:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 50;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_121:
	*sp += 2;
	*sp -= 4;
			break;
		case 81:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 62;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_122:
	*sp += 2;
	*sp -= 4;
			break;
		case 57:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 128;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_123:
	*sp += 2;
	*sp -= 4;
			break;
		case 68:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 84;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_124:
	*sp += 2;
	*sp -= 4;
			break;
		case 55:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 116;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_125:
	*sp += 2;
	*sp -= 4;
			break;
		case 49:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 30;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_126:
	*sp += 2;
	*sp -= 4;
			break;
		case 12:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 35;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_127:
	*sp += 2;
	*sp -= 4;
			break;
		case 52:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 9;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_128:
	*sp += 2;
	*sp -= 4;
			break;
		case 20:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 48;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_129:
	*sp += 2;
	*sp -= 4;
			break;
		case 26:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 42;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_130:
	*sp += 2;
	*sp -= 4;
			break;
		case 7:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 83;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_131:
	*sp += 2;
	*sp -= 4;
			break;
		case 30:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 58;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_132:
	*sp += 2;
	*sp -= 4;
			break;
		case 27:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 185;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_133:
	*sp += 2;
	*sp -= 4;
			break;
		case 53:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 0;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_134:
	*sp += 2;
	*sp -= 4;
			break;
		case 82:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 130;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_135:
	*sp += 2;
	*sp -= 4;
			break;
		case 42:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 63;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_136:
	*sp += 2;
	*sp -= 4;
			break;
		case 54:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 137, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 162;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_137:
	*sp += 2;
	*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 110;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_l7) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l7;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 138, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_138:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 139, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_139:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 140, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_140:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 141, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_141:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 142, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_142:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 143, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE_call_return_stub_143:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking9panic_fmt17h826facefad16f5a7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking9panic_fmt17h826facefad16f5a7E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1051920;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 38;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking9panic_fmt17h826facefad16f5a7E_call_return_stub_0:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[21] = { 0 };
	uint l7 = 0;
	uint l9 = 0;
	uint l6 = 0;
	uint p2 = 0;
	uint l5 = 0;
	uint l3 = 0;
	uint l8 = 0;
	uint l10 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_33;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 16;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b1;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_1 = p2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l4;
	i32_3 = p1;
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_1:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_3:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_4:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_5:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b2;
	}
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b6;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b4;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b5;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b6;
			break;
	}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 65;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b8;
	}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1052504;
	i32_2 = 64;
	i32_3 = l5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_8:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_9:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_10:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_11:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_12:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_13:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b9;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = -64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 64;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 154;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b3;
	}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 63;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b11;
	}
	i32_0 = p2;
	i32_1 = 1052504;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b10;
	}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1052504;
	i32_2 = p2;
	i32_3 = p1;
	i32_4 = 12;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_14:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_15:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_16:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_17:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_18:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_19:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b3;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1052504;
	i32_1 = 64;
	i32_2 = 0;
	i32_3 = p2;
	i32_4 = 1052568;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 199;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_20:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l6;
	i32_3 = 8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = p1;
	i32_4 = 12;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_22:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_23:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_24:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_25:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_26:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b3;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l8;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b17;
			break;
		case 1:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b18;
			break;
		case 2:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b19;
			break;
		default:
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b17;
			break;
	}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b16;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 1000;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b20;
	}
	i32_0 = 4;
	i32_1 = 5;
	i32_2 = l5;
	i32_3 = 10000;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b15;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l5;
	i32_1 = 10;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b14;
	}
	i32_0 = 2;
	i32_1 = 3;
	i32_2 = l5;
	i32_3 = 100;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b15;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = 6;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b21;
	}
	i32_0 = l9;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b15;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 5;
	i32_2 = 1052584;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_27:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b14;
	}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p2;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b13;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p2;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 10;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 246;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 48;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l9;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b12;
	}
	i32_0 = l4;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_l2_loop:
	i32_0 = p2;
	i32_1 = l5;
	i32_2 = 65535;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 10;
	i32_1 = (uint)(i32_1) / (uint)(i32_2);
	l10 = i32_1;
	local_cache[20] = 1;
	i32_2 = 10;
	i32_1 = (uint)(i32_1) % (uint)(i32_2);
	i32_2 = 48;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l10;
	i32_2 = 246;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 48;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = 100;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) == (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p2;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_l2) */
	i32_0 = l9;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i32_3 = p1;
	i32_4 = 12;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_3) {
		case 59:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 119;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_28:
	*sp += 2;
	*sp -= 6;
			break;
		case 44:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 40;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_29:
	*sp += 2;
	*sp -= 6;
			break;
		case 71:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 206;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_30:
	*sp += 2;
	*sp -= 6;
			break;
		case 40:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 91;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_31:
	*sp += 2;
	*sp -= 6;
			break;
		case 56:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 146;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_32:
	*sp += 2;
	*sp -= 6;
			break;
		case 34:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 94;
	*is_calling = 1;
	return;
	__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_call_return_stub_33:
	*sp += 2;
	*sp -= 6;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b3;
	}
	i32_0 = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l7;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 154;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 8;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E_b0;
	}
	i32_0 = 4;
	i32_1 = 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E_call_return_stub_0:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1058816;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr29drop_in_place$LT$$LP$$RP$$GT$17hb98729e73ea57a1cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_17;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b5;
			break;
		case 1:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b4;
			break;
		case 2:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
			break;
		case 3:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
			break;
		case 4:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
			break;
		case 5:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b3;
			break;
		case 6:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b2;
			break;
		default:
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
			break;
	}

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
	}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_0:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_1:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_2:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_3:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_4:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_5:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_6:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_7:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_8:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1;
	}
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
	}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_9:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_10:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_11:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_12:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_13:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_14:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_15:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_16:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_call_return_stub_17:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1;
	}
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr125drop_in_place$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__Visitor$GT$17he5ce94fe758aed08E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p2;
	i32_2 = l4;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 8;
	i32_2 = p2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b3;
	}
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b4;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b0;
	}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b1;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l1 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_8;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b1;
	}
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_0:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_1:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_2:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_3:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_4:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_5:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_6:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_7:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_call_return_stub_8:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b2;
	}
	i32_0 = l2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint p0 = 0;
	ulong p6 = 0;
	ulong p7 = 0;
	uint l11 = 0;
	uint p5 = 0;
	uint p4 = 0;
	ulong p8 = 0;
	uint p2 = 0;
	uint l10 = 0;
	uint p3 = 0;
	uint l9 = 0;
	uint p1 = 0;
	uint l12 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_2;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-18+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p6 = read_u64_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p7 = read_u64_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p8 = read_u64_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-14+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-16+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = p7;
	i64_1 = p8;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b5;
	}
	i64_0 = p7;
	i64_1 = p8;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = p8;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b4;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) p6 = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = p7;
	i64_1 = p6;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = p6;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b8;
	}
	i64_0 = p7;
	i64_1 = p6;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = p8;
	i64_2 = 1;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i32_0 = (ulong)(i64_0) >= (ulong)(i64_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b7;
	}

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) p6 = read_u64_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = p6;
	i64_1 = p8;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b9;
	}
	i64_0 = p7;
	i64_1 = p6;
	i64_2 = p8;
	i64_1 = (long)(i64_1) - (long)(i64_2);
	p8 = i64_1;
	local_cache[16] = 1;
	i64_0 = (long)(i64_0) - (long)(i64_1);
	i64_1 = p8;
	i32_0 = (ulong)(i64_0) <= (ulong)(i64_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b3;
	}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b0;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b2;
	}
	i32_0 = p1;
	i32_1 = p3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 0;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p1;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_l0_loop:
	i32_0 = p3;
	i32_1 = l10;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b10;
	}
	i32_0 = l10;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l11;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = p3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 57;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_l0) */
	i32_0 = l12;
	i32_1 = l12;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p3;
	i32_1 = l10;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p3;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1;
	}
	i32_0 = l12;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = l10;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b12;
	}
	i32_0 = 49;
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b11;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 49;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 48;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b11;
	}
	i32_0 = 48;
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_2 = p3;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) p7 = read_u64_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) p8 = read_u64_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (short)(i32_0);
	p4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1;
	}
	i32_0 = p4;
	i32_1 = p5;
	i32_1 = (short)(i32_1);
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1;
	}
	i32_0 = l9;
	i32_1 = l10;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_2 = 1051624;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_2 = 1051592;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b0;
	}
	i32_0 = p3;
	i32_1 = p2;
	i32_2 = 1051608;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p4;
	write_u16_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[25] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint l5 = 0;
	uint p3 = 0;
	uint l9 = 0;
	ulong l11 = 0;
	uint l10 = 0;
	ulong l7 = 0;
	ulong l12 = 0;
	uint p4 = 0;
	uint p2 = 0;
	uint l6 = 0;
	uint l8 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_28;
			case 29:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_29;
			case 30:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_30;
			case 31:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_31;
			case 32:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_32;
			case 33:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_33;
			case 34:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_34;
			case 35:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_35;
			case 36:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_36;
			case 37:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_37;
			case 38:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_38;
			case 39:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_39;
			case 40:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_40;
			case 41:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_41;
			case 42:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_42;
			case 43:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_43;
			case 44:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_44;
			case 45:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_45;
			case 46:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_46;
			case 47:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_47;
			case 48:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_48;
			case 49:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_49;
			case 50:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_50;
			case 51:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_51;
			case 52:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_52;
			case 53:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_53;
			case 54:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_54;
			case 55:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_55;
			case 56:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_56;
			case 57:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_57;
			case 58:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_58;
			case 59:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_59;
			case 60:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_60;
			case 61:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_61;
			case 62:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_62;
			case 63:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_63;
			case 64:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_64;
			case 65:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_65;
			case 66:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_66;
			case 67:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_67;
			case 68:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_68;
			case 69:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_69;
			case 70:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_70;
			case 71:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_71;
			case 72:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_72;
			case 73:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_73;
			case 74:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_74;
			case 75:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_75;
			case 76:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_76;
			case 77:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_77;
			case 78:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_78;
			case 79:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_79;
			case 80:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_80;
			case 81:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_81;
			case 82:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_82;
			case 83:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_83;
			case 84:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_84;
			case 85:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_85;
			case 86:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_86;
			case 87:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_87;
			case 88:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_88;
			case 89:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_89;
			case 90:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_90;
			case 91:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_91;
			case 92:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_92;
			case 93:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_93;
			case 94:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_94;
			case 95:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_95;
			case 96:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_96;
			case 97:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_97;
			case 98:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_98;
			case 99:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_99;
			case 100:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_100;
			case 101:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_101;
			case 102:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_102;
			case 103:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_103;
			case 104:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_104;
			case 105:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_105;
			case 106:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_106;
			case 107:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_107;
			case 108:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_108;
			case 109:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_109;
			case 110:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_110;
			case 111:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_111;
			case 112:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_112;
			case 113:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_113;
			case 114:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_114;
			case 115:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_115;
			case 116:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_116;
			case 117:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_117;
			case 118:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_118;
			case 119:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_119;
			case 120:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_120;
			case 121:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_121;
			case 122:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_122;
			case 123:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_123;
			case 124:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_124;
			case 125:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_125;
			case 126:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_126;
			case 127:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_127;
			case 128:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_128;
			case 129:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_129;
			case 130:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_130;
			case 131:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_131;
			case 132:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_132;
			case 133:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_133;
			case 134:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_134;
			case 135:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_135;
			case 136:
				*sfp -= 1;
				goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_136;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 36;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 496;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062144+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062144+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b3;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062164+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b2;
	}
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+1062164+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062160+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062160+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062140+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b0;
	}
	i32_0 = l5;
	i32_1 = 124;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1059804;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 27;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 174;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+84+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1058872;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p4;
	write_u8((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 21;
	write_u32_aligned((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 72;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1058940;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 64;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 96;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_2:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b4;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b5;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_3:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_4:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_5:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_6:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_7:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_8:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_9:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_10:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_11:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b6;
	}
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b7;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l5;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_12:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_13:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_14:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_15:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_16:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_17:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_18:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_19:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_20:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b8;
	}
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1059008;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_21:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b9;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b10;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p3;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_22:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_23:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_24:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_25:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_26:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_27:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_28:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 29, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_29:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 30, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_30:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b11;
	}
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b12;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l5;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 31, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_31:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 32, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_32:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 33, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_33:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 34, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_34:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 35, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_35:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 36, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_36:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 37, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_37:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 38, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_38:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 39, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_39:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b13;
	}
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b1:
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = l6;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062140+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 80:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 40, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 11;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_40:
*sp -= 4;
			break;
		case 79:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 41, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 139;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_41:
*sp -= 4;
			break;
		case 38:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 42, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 187;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_42:
*sp -= 4;
			break;
		case 77:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 43, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 86;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_43:
*sp -= 4;
			break;
		case 76:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 44, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 125;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_44:
*sp -= 4;
			break;
		case 75:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 45, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 137;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_45:
*sp -= 4;
			break;
		case 74:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 46, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 124;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_46:
*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b19;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062132+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b20;
			break;
		case 1:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b19;
			break;
		case 2:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b22;
			break;
		case 3:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b21;
			break;
		default:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b23;
			break;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b23:
	i32_0 = 1057296;
	i32_1 = 40;
	i32_2 = 1058020;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 47, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_47:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b22:
	i32_0 = 1;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b21:
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+126+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 0;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+1057582+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+118+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 0;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+1057576+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 112;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b26;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 48, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 135;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_48:
	*sp += 2;
	*sp -= 2;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b25;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1058256+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	p0 = i32_0;
	local_cache[0] = 1;
	i64_0 = l7;
	i32_0 = (int)(i64_0);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b25;
	}
	i32_0 = 3;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l8;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b24;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_1;
	local_cache[16] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 49, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_49:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 50, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_50:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 51, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_51:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 52, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_52:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 53, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_53:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 54, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_54:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 55, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_55:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 56, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_56:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 57, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_57:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b27;
	}
	i32_0 = l10;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b28;
	}
	i32_0 = 3;
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 2;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = __func_func_strlen_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b32;
	}
	i32_0 = l9;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b18;
	}
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = l9;
	i32_1 = l8;
	i32_0 = __func_func___rust_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b17;
	}
	i32_0 = l10;
	i32_1 = p0;
	i32_2 = l9;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b31;
			break;
		case 1:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b30;
			break;
		case 2:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b30;
			break;
		case 3:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b33;
			break;
		default:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b30;
			break;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1819047270;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = p0;
	i32_2 = l9;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b29;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 48;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+1062132+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 12;
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l5;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = p1;
	i32_3 = 12;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	p1 = i32_2;
	local_cache[2] = 1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 80:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 58, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 11;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_58:
*sp -= 4;
			break;
		case 79:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 59, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 139;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_59:
*sp -= 4;
			break;
		case 38:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 60, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 187;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_60:
*sp -= 4;
			break;
		case 77:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 61, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 86;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_61:
*sp -= 4;
			break;
		case 76:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 62, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 125;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_62:
*sp -= 4;
			break;
		case 75:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 63, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 137;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_63:
*sp -= 4;
			break;
		case 74:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 64, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 124;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_64:
*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = -4493808902380553279;
	i64_0 = (ulong)(i64_0) ^ (ulong)(i64_1);
	i32_0 = l5;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_1 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_2 = -163230743173927068;
	i64_1 = (ulong)(i64_1) ^ (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i32_0 = !(i64_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b16;
	}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = p1;
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_2) {
		case 80:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 65, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 11;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_65:
*sp -= 4;
			break;
		case 79:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 66, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 139;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_66:
*sp -= 4;
			break;
		case 38:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 67, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 187;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_67:
*sp -= 4;
			break;
		case 77:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 68, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 86;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_68:
*sp -= 4;
			break;
		case 76:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 69, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 125;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_69:
*sp -= 4;
			break;
		case 75:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 70, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 137;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_70:
*sp -= 4;
			break;
		case 74:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 71, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 124;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_71:
*sp -= 4;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1058616;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l5;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_1 = -3988785156179279576;
	i64_0 = (ulong)(i64_0) ^ (ulong)(i64_1);
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_1 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i64_2 = 6146099213658827405;
	i64_1 = (ulong)(i64_1) ^ (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i32_0 = !(i64_0);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b14;
	}
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b15;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b18:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 72, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_72:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = l9;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 73, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_73:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b38;
	}
	i32_0 = 0;
	i32_1 = -1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062172+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b39;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = 24;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b36;
	}
	i32_0 = p3;
	i64_0 = 4294967297;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_l0_loop:
	i64_0 = l7;
	i64_1 = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l11 = i64_0;
	local_cache[22] = 1;
	i32_0 = !(i64_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b35;
	}
	i32_0 = 0;
	i64_0 = l11;
	i32_1 = 0;
	i64_1 = (read_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i64_1;
	local_cache[24] = 1;
	i64_2 = l12;
	i64_3 = l7;
	i32_1 = (ulong)(i64_2) == (ulong)(i64_3);
	l6 = i32_1;
	local_cache[12] = 1;
	(i32_1 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l12;
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_l0) */
	i32_0 = 0;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+1062172+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p3;
	i64_0 = l11;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b37;
	}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1057784;
	i32_1 = 16;
	i32_2 = l5;
	i32_3 = 96;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1057800;
	i32_4 = 1058432;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 74, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_74:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b41;
	}
	i32_0 = 9;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 1058628;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b40;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 92;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 22;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 84;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 52;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 64;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i64_0 = 3;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1058664;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 72;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 96;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 75, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_75:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b43;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b42;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b44;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b42;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 76, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_76:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 77, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_77:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 78, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_78:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 79, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_79:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 80, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_80:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 81, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_81:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 82, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_82:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 83, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_83:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 84, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_84:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b45;
	}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b42;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b46;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b42;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 85, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_85:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 86, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_86:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 87, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_87:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 88, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_88:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 89, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_89:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 90, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_90:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 91, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_91:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 92, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_92:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 93, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_93:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b47;
	}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b51;
			break;
		case 1:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b50;
			break;
		case 2:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b49;
			break;
		default:
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b51;
			break;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 94, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 122;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_94:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b52;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p2;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 95, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_95:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 96, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_96:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 97, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_97:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 98, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_98:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 99, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_99:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 100, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_100:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 101, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_101:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 102, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_102:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 103, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_103:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b53;
	}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 104, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 122;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_104:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b54;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p2;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 105, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_105:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 106, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_106:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 107, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_107:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 108, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_108:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 109, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_109:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 110, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_110:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 111, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_111:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 112, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_112:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 113, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_113:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b55;
	}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062076+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062076+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}
	i32_0 = l5;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1058776;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 114, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_114:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	p2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b56;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b57;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p2;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 115, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_115:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 116, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_116:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 117, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_117:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 118, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_118:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 119, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_119:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 120, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_120:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 121, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_121:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 122, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_122:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 123, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_123:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b58;
	}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b59;
	}
	i32_0 = l6;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48;
	}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p2;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 124, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_124:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 125, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_125:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 126, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_126:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 127, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_127:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 128, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_128:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 129, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_129:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 130, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_130:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 131, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_131:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 132, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_132:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b60;
	}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p3;
	i32_1 = p3;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_1;
	local_cache[12] = 1;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b61;
	}
	i32_0 = p3;
	__func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062140+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062140+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062164+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b34;
	}
	i32_0 = l5;
	i32_1 = 124;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1059064;
	write_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 96;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l5;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 133, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 27;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_133:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = l5;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 134, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 174;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_134:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b36:
	i32_0 = 8;
	i32_1 = 24;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 135, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_135:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b35:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 136, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 183;
	*is_calling = 1;
	return;
	__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_call_return_stub_136:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	__func_func_rust_panic_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l4 = 0;
	uint l2 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p1;
	i32_2 = l4;
	i32_3 = p1;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 8;
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b3;
	}
	i32_0 = l2;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l4;
	i32_2 = p1;
	i32_3 = l2;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b4;
	}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b1;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ptr39drop_in_place$LT$stdpathPathBuf$GT$17hcd41e3e78ccde51eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ptr39drop_in_place$LT$stdpathPathBuf$GT$17hcd41e3e78ccde51eE_b0;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN4core3ptr39drop_in_place$LT$stdpathPathBuf$GT$17hcd41e3e78ccde51eE_b0:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking13assert_failed17hfb0bb2c5a0cdf99aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p2 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking13assert_failed17hfb0bb2c5a0cdf99aE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1052004;
	i32_2 = l3;
	i32_3 = 4;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1052004;
	i32_4 = l3;
	i32_5 = 8;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 1049488;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 1;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking13assert_failed17hfb0bb2c5a0cdf99aE_call_return_stub_0:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[13] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l6 = 0;
	uint p4 = 0;
	uint p2 = 0;
	uint p5 = 0;
	uint p3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 112;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 1052020;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_b0;
	}
	i32_0 = l6;
	i32_1 = 76;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+92+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 1052080;
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = p4;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 4;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 84;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 15;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 76;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+92+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 1052116;
	write_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l3 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_9;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057972;
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b2;
	}
	i32_0 = p0;
	i32_1 = 1057960;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b0;

__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b0;

__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 4;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b3;
	}
	i32_0 = p2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p0;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_1;
	local_cache[4] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_1:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_2:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_3:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_4:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_5:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_6:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_7:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_8:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_call_return_stub_9:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b4;
	}
	i32_0 = p1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std7process5abort17hd45c1523f6588d30E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func_rust_panic(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p3 = 0;
	uint p2 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b1;
	}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b0;
	}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b6;
	}
	i32_0 = p3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b7;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b5;
	}
	i32_0 = 1;
	i32_1 = 0;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b4;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b7:
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b8;
	}
	i32_0 = 1;
	i32_1 = 0;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b2;
	}
	i32_0 = p1;
	i32_1 = p3;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b3;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b8:
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = __func_func_realloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b4;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b6:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b5;
	}
	i32_0 = 1;
	i32_1 = 0;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b4;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b5:
	i32_0 = p2;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b4:
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b2;
	}

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b3:
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b2:
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b1:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E_b0:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std9panicking11panic_count17is_zero_slow_path17h88f026da919a15b3E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 18;
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062160+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-0+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l1 = 0;
	uint p0 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b0;
	}
	i32_0 = p0;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = l1;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b0;
	}
	i32_0 = l1;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b0:
	i32_0 = p0;
	i32_1 = -1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b1;
	}
	i32_0 = p0;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l1 = i32_1;
	local_cache[2] = 1;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b1;
	}
	i32_0 = p0;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE_b1:
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint l2 = 0;
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062128+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b3;
	}
	i32_0 = l2;
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b0;
			break;
		case 1:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b2;
			break;
		default:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b0;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+1062128+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b1;
	}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 4294967296;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 0;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+1062128+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b1:
	i32_0 = 1057184;
	i32_1 = 43;
	i32_2 = 1058096;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_call_return_stub_0:
*sp -= 6;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1060028;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1058080;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[75] = { 0 };
	uint l11 = 0;
	uint p1 = 0;
	uint l9 = 0;
	uint l34 = 0;
	uint l5 = 0;
	uint l15 = 0;
	uint l36 = 0;
	uint l10 = 0;
	uint l31 = 0;
	uint l30 = 0;
	uint l29 = 0;
	uint l22 = 0;
	uint l27 = 0;
	uint l37 = 0;
	uint l18 = 0;
	uint l19 = 0;
	uint l14 = 0;
	uint l33 = 0;
	uint l8 = 0;
	uint l4 = 0;
	uint l26 = 0;
	uint l3 = 0;
	uint l7 = 0;
	uint p2 = 0;
	uint l16 = 0;
	uint l25 = 0;
	uint l35 = 0;
	uint l17 = 0;
	uint l20 = 0;
	uint l32 = 0;
	uint p0 = 0;
	uint l12 = 0;
	uint l6 = 0;
	uint l24 = 0;
	uint l21 = 0;
	uint l28 = 0;
	uint l13 = 0;
	uint l23 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_b0;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_l0_loop:
	i32_0 = l8;
	i32_1 = l9;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l10;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l8;
	i32_2 = l9;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l10;
	i32_2 = 30;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l10;
	i32_3 = 19;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l10;
	i32_3 = 10;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l6;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l6;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l6;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l4;
	i32_3 = l5;
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l4;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p1;
	i32_2 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_2;
	local_cache[4] = 1;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = p2;
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = 8;
	i32_3 = (uint)(i32_3) << (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = p2;
	i32_4 = 8;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = p2;
	i32_5 = 24;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	l12 = i32_2;
	local_cache[24] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1116352408;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l9;
	i32_3 = l10;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l9;
	i32_3 = l10;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = p1;
	i32_2 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l14 = i32_2;
	local_cache[28] = 1;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = l14;
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = 8;
	i32_3 = (uint)(i32_3) << (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = l14;
	i32_4 = 8;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = l14;
	i32_5 = 24;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	l15 = i32_2;
	local_cache[30] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l13;
	i32_3 = l7;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l16 = i32_2;
	local_cache[32] = 1;
	i32_3 = l5;
	i32_4 = l6;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l5;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l16;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l16;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l16;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1899447441;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l17 = i32_1;
	local_cache[34] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l10;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l10;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = p1;
	i32_2 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_2;
	local_cache[26] = 1;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = l13;
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = 8;
	i32_3 = (uint)(i32_3) << (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = l13;
	i32_4 = 8;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = l13;
	i32_5 = 24;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	l18 = i32_2;
	local_cache[36] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l17;
	i32_3 = l8;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l19 = i32_2;
	local_cache[38] = 1;
	i32_3 = l16;
	i32_4 = l6;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l6;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1245643825;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = p1;
	i32_2 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l17 = i32_2;
	local_cache[34] = 1;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = l17;
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = 8;
	i32_3 = (uint)(i32_3) << (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = l17;
	i32_4 = 8;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = l17;
	i32_5 = 24;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	l21 = i32_2;
	local_cache[42] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = l9;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l20 = i32_2;
	local_cache[40] = 1;
	i32_3 = l19;
	i32_4 = l16;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -373957723;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l22 = i32_1;
	local_cache[44] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i32_2 = p1;
	i32_2 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l23 = i32_2;
	local_cache[46] = 1;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = l23;
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = 8;
	i32_3 = (uint)(i32_3) << (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_3 = l23;
	i32_4 = 8;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_4 = 65280;
	i32_3 = (uint)(i32_3) & (uint)(i32_4);
	i32_4 = l23;
	i32_5 = 24;
	i32_4 = (uint)(i32_4) >> (uint)(i32_5 & 31);
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	l24 = i32_2;
	local_cache[48] = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = l10;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l23 = i32_2;
	local_cache[46] = 1;
	i32_3 = l20;
	i32_4 = l19;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 961987163;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l26 = i32_1;
	local_cache[52] = 1;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l19 = i32_2;
	local_cache[38] = 1;
	i32_3 = l23;
	i32_4 = l20;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l20;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1508970993;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l20 = i32_2;
	local_cache[40] = 1;
	i32_3 = l19;
	i32_4 = l23;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l23;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1841331548;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l23 = i32_2;
	local_cache[46] = 1;
	i32_3 = l20;
	i32_4 = l19;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1424204075;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+32+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l19 = i32_2;
	local_cache[38] = 1;
	i32_3 = l23;
	i32_4 = l20;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l20;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -670586216;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+36+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l30 = i32_1;
	local_cache[60] = 1;
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l20 = i32_2;
	local_cache[40] = 1;
	i32_3 = l19;
	i32_4 = l23;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l23;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 310598401;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+40+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l31 = i32_1;
	local_cache[62] = 1;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l23 = i32_2;
	local_cache[46] = 1;
	i32_3 = l20;
	i32_4 = l19;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 607225278;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l22;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	i32_3 = l23;
	i32_4 = l20;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l20;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1426881987;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+48+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l19;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l19;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l33 = i32_1;
	local_cache[66] = 1;
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l25 = i32_2;
	local_cache[50] = 1;
	i32_3 = l22;
	i32_4 = l23;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l23;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1925078388;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+52+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l19;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l19;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l34 = i32_1;
	local_cache[68] = 1;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l35 = i32_2;
	local_cache[70] = 1;
	i32_3 = l25;
	i32_4 = l22;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -2132889090;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+56+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l19;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l19;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l19;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l36 = i32_2;
	local_cache[72] = 1;
	i32_3 = l35;
	i32_4 = l25;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l25;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1680079193;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l23 = i32_1;
	local_cache[46] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_1 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+60+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l20;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l20;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l20;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l37 = i32_2;
	local_cache[74] = 1;
	i32_3 = l36;
	i32_4 = l35;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l35;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l37;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l37;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1046744716;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l22 = i32_1;
	local_cache[44] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l15;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l23 = i32_1;
	local_cache[46] = 1;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l12 = i32_2;
	local_cache[24] = 1;
	i32_3 = l37;
	i32_4 = l36;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l36;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l12;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l12;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -459576895;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l18;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l18;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l15 = i32_2;
	local_cache[30] = 1;
	i32_3 = l12;
	i32_4 = l37;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l37;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l15;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l15;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -272742522;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l35 = i32_1;
	local_cache[70] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l21;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l18 = i32_2;
	local_cache[36] = 1;
	i32_3 = l15;
	i32_4 = l12;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l12;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l18;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l18;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 264347078;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l24;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l24;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l33;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l35 = i32_1;
	local_cache[70] = 1;
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l21 = i32_2;
	local_cache[42] = 1;
	i32_3 = l18;
	i32_4 = l15;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l15;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l21;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l21;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 604807628;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l37 = i32_1;
	local_cache[74] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l26;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l26;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l34;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l24 = i32_2;
	local_cache[48] = 1;
	i32_3 = l21;
	i32_4 = l18;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l18;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l24;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l24;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 770255983;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l27;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l27;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l26 = i32_2;
	local_cache[52] = 1;
	i32_3 = l24;
	i32_4 = l21;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l21;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l26;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l26;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1249150122;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l15 = i32_1;
	local_cache[30] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l28;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l28;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l27 = i32_2;
	local_cache[54] = 1;
	i32_3 = l26;
	i32_4 = l24;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l24;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l27;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l27;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1555081692;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l18 = i32_1;
	local_cache[36] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l29;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l29;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l29;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l37;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l37;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l15 = i32_1;
	local_cache[30] = 1;
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l28 = i32_2;
	local_cache[56] = 1;
	i32_3 = l27;
	i32_4 = l26;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l26;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l28;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l28;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1996064986;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l30;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l30;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l30;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l12;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l12;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l18 = i32_1;
	local_cache[36] = 1;
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l28;
	i32_4 = l27;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l27;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1740746414;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l24 = i32_1;
	local_cache[48] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l31;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l31;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l31;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l15;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l15;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l28;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l28;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1473132947;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l26 = i32_1;
	local_cache[52] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l32;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l32;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l32;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l18;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l18;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l24 = i32_1;
	local_cache[48] = 1;
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1341970488;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l27 = i32_1;
	local_cache[54] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l33;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l33;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l33;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l21;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l21;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l26 = i32_1;
	local_cache[52] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1084653625;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l34;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l34;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l34;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l33;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l24;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l24;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -958395405;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l19;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l34;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l26;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l26;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -710438585;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l20;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l20;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l27;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l27;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 113926993;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l23;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l23;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l23;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l28;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l28;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 338241895;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l22;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l22;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l22;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l23 = i32_1;
	local_cache[46] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 666307205;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l25;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l25;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l25;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 773529912;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l35;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l35;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l35;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1294757372;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l36;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l36;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l36;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l35 = i32_1;
	local_cache[70] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1396182291;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l37;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l37;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1695183700;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l12;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l12;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1986661051;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l15;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -2117940946;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l18;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l18;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l37;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l37;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l15 = i32_1;
	local_cache[30] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1838011259;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l21;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l12;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l12;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l18 = i32_1;
	local_cache[36] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1564481375;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l24;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l24;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l15;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l15;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1474664885;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l26;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l26;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l18;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l18;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l24 = i32_1;
	local_cache[48] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1035236496;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l27;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l27;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l21;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l21;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l26 = i32_1;
	local_cache[52] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -949202525;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l28;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l28;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l24;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l24;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l27 = i32_1;
	local_cache[54] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -778901479;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l19;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l26;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l26;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l28 = i32_1;
	local_cache[56] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -694614492;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l20;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l20;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l27;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l27;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l30 = i32_2;
	local_cache[60] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -200395387;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l23;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l23;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l23;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l28;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l28;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l31 = i32_2;
	local_cache[62] = 1;
	i32_3 = l30;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 275423344;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l22;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l22;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l22;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l19;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l19;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l23 = i32_1;
	local_cache[46] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l29 = i32_2;
	local_cache[58] = 1;
	i32_3 = l31;
	i32_4 = l30;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l30;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l29;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l29;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 430227734;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l33 = i32_1;
	local_cache[66] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l25;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l25;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l25;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l32 = i32_1;
	local_cache[64] = 1;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l33;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	i32_3 = l29;
	i32_4 = l31;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l31;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 506948616;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l33 = i32_1;
	local_cache[66] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l35;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l35;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l35;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l30 = i32_1;
	local_cache[60] = 1;
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l33;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l25 = i32_2;
	local_cache[50] = 1;
	i32_3 = l22;
	i32_4 = l29;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l29;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 659060556;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l33 = i32_1;
	local_cache[66] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l36;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l36;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l36;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l32;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l32;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l31 = i32_1;
	local_cache[62] = 1;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l33;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l35 = i32_2;
	local_cache[70] = 1;
	i32_3 = l25;
	i32_4 = l22;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 883997877;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l37;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l37;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l30;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l30;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	i32_3 = l35;
	i32_4 = l25;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l25;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 958139571;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l12;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l12;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l31;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l31;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l25 = i32_2;
	local_cache[50] = 1;
	i32_3 = l22;
	i32_4 = l35;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l35;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1322822218;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l15;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l20;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l35 = i32_2;
	local_cache[70] = 1;
	i32_3 = l25;
	i32_4 = l22;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1537002063;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l18;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l18;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l37;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l37;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l15 = i32_1;
	local_cache[30] = 1;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	i32_3 = l35;
	i32_4 = l25;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l25;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1747873779;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l21;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l12;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l12;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l18 = i32_1;
	local_cache[36] = 1;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l25 = i32_2;
	local_cache[50] = 1;
	i32_3 = l22;
	i32_4 = l35;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l35;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1955562222;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l14;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l14;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l24;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l24;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l21;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l15;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l15;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l35 = i32_2;
	local_cache[70] = 1;
	i32_3 = l25;
	i32_4 = l22;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 2024104815;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l13;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l14;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l26;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l26;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l31;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l18;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l18;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l24 = i32_1;
	local_cache[48] = 1;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l22 = i32_2;
	local_cache[44] = 1;
	i32_3 = l35;
	i32_4 = l25;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l25;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l22;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l22;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l22;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -2067236844;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l29 = i32_1;
	local_cache[58] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l17;
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l13;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l27;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l27;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l21;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l21;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l29;
	i32_3 = l16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l25 = i32_2;
	local_cache[50] = 1;
	i32_3 = l22;
	i32_4 = l35;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l35;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l25;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l25;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1933114872;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l16;
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l17;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l28;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l28;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l27;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l24;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l24;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l24;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l37 = i32_1;
	local_cache[74] = 1;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = p2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l35 = i32_2;
	local_cache[70] = 1;
	i32_3 = l25;
	i32_4 = l22;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l22;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l35;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l35;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1866530822;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l21 = i32_1;
	local_cache[42] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = p2;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = p2;
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l16;
	i32_3 = l17;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 25;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l19;
	i32_3 = 14;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_3 = 3;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l36 = i32_1;
	local_cache[72] = 1;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l21;
	i32_3 = l14;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l14 = i32_2;
	local_cache[28] = 1;
	i32_3 = l35;
	i32_4 = l25;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l25;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l14;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l14;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l14;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1538233109;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l12 = i32_1;
	local_cache[24] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_1 = 30;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l22;
	i32_2 = 19;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l22;
	i32_2 = 10;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l22;
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p2;
	i32_3 = l16;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = l20;
	i32_3 = 25;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l20;
	i32_4 = 14;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l20;
	i32_4 = 3;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l15;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l37;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l37;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l37;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l12;
	i32_3 = l13;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l13 = i32_2;
	local_cache[26] = 1;
	i32_3 = l14;
	i32_4 = l35;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l35;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l13;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l13;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l13;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -1090935817;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l25 = i32_1;
	local_cache[50] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l19 = i32_0;
	local_cache[38] = 1;
	i32_1 = l22;
	i32_2 = p2;
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = l22;
	i32_2 = p2;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 30;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l19;
	i32_3 = 19;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_2 = l19;
	i32_3 = 10;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_1 = i32_1 ^ i32_2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i32_2 = l23;
	i32_3 = 25;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l23;
	i32_4 = 14;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l23;
	i32_4 = 3;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l18;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l36;
	i32_3 = 15;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l36;
	i32_4 = 13;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l36;
	i32_4 = 10;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l25;
	i32_3 = l17;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l17 = i32_2;
	local_cache[34] = 1;
	i32_3 = l13;
	i32_4 = l14;
	i32_3 = i32_3 ^ i32_4;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l14;
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l17;
	i32_3 = 26;
	i32_2 = rotate(i32_2, i32_3 & 31);
	i32_3 = l17;
	i32_4 = 21;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l17;
	i32_4 = 7;
	i32_3 = rotate(i32_3, i32_4 & 31);
	i32_2 = i32_2 ^ i32_3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = -965641998;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l19;
	i32_1 = l9;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l16;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l22;
	i32_1 = l8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l17;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p2;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l13;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l14;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l11;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_l0_loop;
	}
	/* END (loop: __func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_l0) */

__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_b0:
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l10;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l2 = 0;
	uint l4 = 0;
	ulong l3 = 0;
	uint p0 = 0;
	uint l5 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	ulong i64_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 36;
	i32_0 = p0;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i64_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 104;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 64;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b1;
	}
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b0;
	}
	i32_0 = l4;
	i32_1 = 64;
	i32_2 = 1057088;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 149;
	*is_calling = 1;
	return;
	__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 1;
	__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 128;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = l4;
	i32_3 = 63;
	i32_2 = i32_2 ^ i32_3;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -57;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b3;
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 1;
	__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 65;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b2;
	}
	i32_0 = l2;
	i32_1 = 0;
	i32_2 = l4;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 96;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l3;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l3;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l3;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l3;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l3;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l3;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l3;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l3;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 1;
	__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_1;
	local_cache[4] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l2;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l2;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p0;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p0;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p0;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 64;
	i32_2 = 1057104;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l3 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_2;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = p0;
	i32_1 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p2;
	i64_1 = (ulong)(i32_1);
	i64_2 = 3;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (long)(i64_0) + (long)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 64;
	i32_1 = p0;
	i32_2 = 104;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b1;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b2;
	}
	i32_0 = l4;
	i32_1 = 65;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b0;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = l5;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1;
	__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p2;
	i32_1 = l5;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = 6;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = p2;
	i32_3 = -64;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = p2;
	i32_3 = 63;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	p2 = i32_2;
	local_cache[4] = 1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b4;
	}
	i32_0 = l5;
	i32_1 = 64;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b3;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = 1057136;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 64;
	i32_2 = 1057136;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 64;
	i32_2 = 1057120;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core6option13expect_failed17h8f72e66e0b3163c7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint l0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core6option13expect_failed17h8f72e66e0b3163c7E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 38;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1058112;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1057680;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 13;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1058184;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core6option13expect_failed17h8f72e66e0b3163c7E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint l2 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b1;
	}
	i32_0 = l3;
	i32_1 = p1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b1;
	}
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l0_loop:
	i32_0 = p1;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b0;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l2 = i32_1;
	local_cache[4] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l0_loop;
	}
	/* END (loop: __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l0) */
	i32_0 = l3;
	l2 = i32_0;
	local_cache[4] = 1;

__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b1:
	i32_0 = p1;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = l3;
	i32_2 = -16843009;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b2;
	}
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = l2;
	i32_4 = 4;
	i32_3 = (uint)(i32_3) | (uint)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_2;
	local_cache[6] = 1;
	i32_3 = -1;
	i32_2 = i32_2 ^ i32_3;
	i32_3 = l3;
	i32_4 = -16843009;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = -2139062144;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l2 = i32_0;
	local_cache[4] = 1;

__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b2:
__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l1_loop:
	i32_0 = p1;
	i32_1 = l2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b0;
	}
	i32_0 = l2;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l1_loop;
	}
	/* END (loop: __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_l1) */
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b0:
	i32_0 = l2;
	i32_1 = 14;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b3;
	}
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE_b3:
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 15;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p0 = 0;
	uint p2 = 0;
	uint l4 = 0;
	uint p1 = 0;
	uint p3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b1;
	}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b0;
	}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b6;
	}
	i32_0 = p3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b7;
	}
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b8;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b3;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b8:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b7:
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b9;
	}
	i32_0 = 1;
	i32_1 = 0;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b2;
	}
	i32_0 = p1;
	i32_1 = p3;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b3;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b9:
	i32_0 = p3;
	i32_1 = p2;
	i32_0 = __func_func_realloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b4;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b6:
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b10;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b3;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b10:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b5:
	i32_0 = p2;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b4:
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b2;
	}

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b3:
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b2:
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b1:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E_b0:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	__func_func_abort_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[15] = { 0 };
	uint l2 = 0;
	uint p0 = 0;
	uint l7 = 0;
	uint l6 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint l1 = 0;
	uint l5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_hypercall_return_stub_0;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_17;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062093+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b10;
			break;
		case 1:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b9;
			break;
		case 2:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b8;
			break;
		case 3:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b1;
			break;
		default:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b10;
			break;
	}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+1062093+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b11;
	}
	i32_0 = l1;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+35+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062128+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b12;
	}
	i32_0 = l1;
	i32_1 = 1062096;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 34;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_0:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+35+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b2;
	}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062096+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1062176;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b15;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062124+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 1;
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = 0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+1062124+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b2;
	}
	i32_0 = 0;
	i32_1 = 1062176;
	write_u32_aligned((ulong)((global char*)heap_u32+1062096+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b14;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b15:
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b13;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062100+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062104+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b7;
	}
	i32_0 = 0;
	i32_1 = -1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062120+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b3;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062116+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b3;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062108+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = 0;
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = l3;
	i32_2 = p0;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l4;
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = l1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 1;
	i32_3 = l1;
	i32_4 = 36;
	i32_3 = (int)(i32_3) + (int)(i32_4);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+16+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+16+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+16+4), (ulong)stack_u32, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+16+6), (ulong)stack_u32, i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 0;
	fd_write_helper(stack_u32, heap_u32, hypercall_buffer, sp, warp_idx, thread_idx, read_idx, scratch_space, i32_3, i32_2, i32_1, i32_0, hcall_size);
	*hypercall_continuation = 0;
	return;
__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+16+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+16+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_2 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+16+4), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_3 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+16+6), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	write_u32((ulong)((global char*)heap_u32+(int)(i32_3)), (ulong)(heap_u32), hcall_ret_val, warp_idx, read_idx, thread_idx, scratch_space);
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b21;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062120+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b20;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062120+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b20;
			break;
		case 1:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 2:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 3:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 4:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 5:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 6:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 7:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 8:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 9:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 10:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 11:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 12:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 13:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 14:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 15:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 16:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 17:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 18:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
		case 19:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b17;
			break;
		default:
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22;
			break;
	}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b18;
	}
	i32_0 = 2;
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 1057668;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b4;
	}
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b16;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b4;
	}
	i32_0 = l4;
	i32_1 = l6;
	i32_2 = l5;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b5;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = p0;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b6;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 141;
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_l0) */

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1057412;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 172;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_3:
*sp -= 0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1057184;
	i32_1 = 43;
	i32_2 = 1058064;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 24;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_4:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1059964;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057452;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_5:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1060028;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1057276;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1057452;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_6:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1057784;
	i32_1 = 16;
	i32_2 = l1;
	i32_3 = 40;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1057800;
	i32_4 = 1057844;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_7:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b0;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b3;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062108+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l2;
	i32_2 = p0;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l3;
	i32_3 = p0;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	l5 = i32_2;
	local_cache[10] = 1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 4;
	l2 = i32_0;
	local_cache[4] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+1062116+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b23;
	}
	i32_0 = l2;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b3;
	}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l2 = i32_0;
	local_cache[4] = 1;
	i32_1 = l7;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p0 = i32_1;
	local_cache[0] = 1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	switch(i32_1) {
		case 33:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 203;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_8:
*sp -= 2;
			break;
		case 25:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 59;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_9:
*sp -= 2;
			break;
		case 64:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 69;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_10:
*sp -= 2;
			break;
		case 23:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_11:
*sp -= 2;
			break;
		case 31:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 184;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_12:
*sp -= 2;
			break;
		case 70:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 173;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_13:
*sp -= 2;
			break;
		case 78:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 22;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_14:
*sp -= 2;
			break;
		case 37:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 61;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_15:
*sp -= 2;
			break;
		case 66:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 85;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_16:
*sp -= 2;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b24;
	}
	i32_0 = l2;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062112+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b25;
	}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062108+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+1062112+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062108+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062104+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+1062104+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+1062100+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p0 = i32_1;
	local_cache[0] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062100+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062120+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b2;
	}
	i32_0 = 0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+1062124+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062096+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b2:
	i32_0 = 0;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+1062093+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 1057412;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE_call_return_stub_17:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 1;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[105] = { 0 };
	uint l38 = 0;
	uint l43 = 0;
	uint l25 = 0;
	uint l27 = 0;
	uint l13 = 0;
	uint l51 = 0;
	uint l22 = 0;
	uint l47 = 0;
	uint p0 = 0;
	uint l21 = 0;
	uint l10 = 0;
	uint p1 = 0;
	uint p3 = 0;
	uint l37 = 0;
	uint l39 = 0;
	uint l18 = 0;
	uint p2 = 0;
	uint l29 = 0;
	uint l46 = 0;
	uint l11 = 0;
	uint l16 = 0;
	uint l52 = 0;
	uint l40 = 0;
	uint l31 = 0;
	uint l44 = 0;
	uint l34 = 0;
	uint l6 = 0;
	uint l24 = 0;
	uint l36 = 0;
	uint l35 = 0;
	uint l42 = 0;
	uint l50 = 0;
	uint l19 = 0;
	uint l41 = 0;
	uint l45 = 0;
	uint l30 = 0;
	uint l20 = 0;
	uint l49 = 0;
	uint l15 = 0;
	uint l23 = 0;
	uint l12 = 0;
	uint l48 = 0;
	uint l8 = 0;
	uint l9 = 0;
	uint l4 = 0;
	uint l32 = 0;
	uint l26 = 0;
	uint l5 = 0;
	uint l28 = 0;
	uint l33 = 0;
	uint l17 = 0;
	uint l7 = 0;
	uint l14 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_2;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 128;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = -64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 63;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b2;
	}
	i32_0 = l4;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p0;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l5;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l5;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l5;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_1 = l5;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l5;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l12 = i32_0;
	local_cache[24] = 1;
	i32_1 = l5;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = 0;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[86]) l43 = read_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[102]) l51 = read_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[94]) l47 = read_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[92]) l46 = read_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[104]) l52 = read_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[88]) l44 = read_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[100]) l50 = read_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[90]) l45 = read_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[98]) l49 = read_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[96]) l48 = read_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l0_loop:
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 64;
	i32_2 = p1;
	i32_3 = 64;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b4;
	}
	i32_0 = l15;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = l15;
	i32_1 = 126;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l1_loop:
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l18 = i32_0;
	local_cache[36] = 1;
	i32_1 = p0;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l19 = i32_1;
	local_cache[38] = 1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l4;
	i32_3 = l5;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l20 = i32_2;
	local_cache[40] = 1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l18;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l20;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l17;
	i32_1 = l5;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l1) */
	i32_0 = l16;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b3;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b4:
	i32_0 = l4;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l4;
	i32_3 = l5;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b3:
	i32_0 = p1;
	i32_1 = l15;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 4;
	l21 = i32_0;
	local_cache[42] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l22 = i32_0;
	local_cache[44] = 1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l23 = i32_0;
	local_cache[46] = 1;
	l18 = i32_0;
	local_cache[36] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+80+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l24 = i32_0;
	local_cache[48] = 1;
	l25 = i32_0;
	local_cache[50] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+96+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l26 = i32_0;
	local_cache[52] = 1;
	l27 = i32_0;
	local_cache[54] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+84+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l28 = i32_0;
	local_cache[56] = 1;
	l19 = i32_0;
	local_cache[38] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+68+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l29 = i32_0;
	local_cache[58] = 1;
	l20 = i32_0;
	local_cache[40] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+100+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l30 = i32_0;
	local_cache[60] = 1;
	l31 = i32_0;
	local_cache[62] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+116+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l32 = i32_0;
	local_cache[64] = 1;
	l33 = i32_0;
	local_cache[66] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+104+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l34 = i32_0;
	local_cache[68] = 1;
	l17 = i32_0;
	local_cache[34] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+88+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l35 = i32_0;
	local_cache[70] = 1;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l36 = i32_0;
	local_cache[72] = 1;
	l37 = i32_0;
	local_cache[74] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l38 = i32_0;
	local_cache[76] = 1;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+124+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l40 = i32_0;
	local_cache[80] = 1;
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+108+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l42 = i32_0;
	local_cache[84] = 1;
	l43 = i32_0;
	local_cache[86] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+76+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l44 = i32_0;
	local_cache[88] = 1;
	l45 = i32_0;
	local_cache[90] = 1;
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+92+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l46 = i32_0;
	local_cache[92] = 1;
	l47 = i32_0;
	local_cache[94] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l2_loop:
	i32_0 = l43;
	i32_1 = l41;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 7;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l45;
	i32_0 = i32_0 ^ i32_1;
	l45 = i32_0;
	local_cache[90] = 1;
	i32_1 = l41;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 9;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l47;
	i32_0 = i32_0 ^ i32_1;
	l48 = i32_0;
	local_cache[96] = 1;
	i32_1 = l45;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l43;
	i32_0 = i32_0 ^ i32_1;
	l49 = i32_0;
	local_cache[98] = 1;
	i32_1 = l48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l41;
	i32_0 = i32_0 ^ i32_1;
	l41 = i32_0;
	local_cache[82] = 1;
	i32_1 = l16;
	i32_2 = l17;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 7;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l37;
	i32_1 = i32_1 ^ i32_2;
	l43 = i32_1;
	local_cache[86] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 7;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l18;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 7;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l25;
	i32_1 = i32_1 ^ i32_2;
	l25 = i32_1;
	local_cache[50] = 1;
	i32_2 = l5;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 9;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l27;
	i32_1 = i32_1 ^ i32_2;
	l50 = i32_1;
	local_cache[100] = 1;
	i32_2 = l25;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 13;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l18;
	i32_1 = i32_1 ^ i32_2;
	l51 = i32_1;
	local_cache[102] = 1;
	i32_0 = i32_0 ^ i32_1;
	l18 = i32_0;
	local_cache[36] = 1;
	i32_1 = l41;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 9;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l20;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 7;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l31;
	i32_1 = i32_1 ^ i32_2;
	l47 = i32_1;
	local_cache[94] = 1;
	i32_2 = l19;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 9;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l33;
	i32_1 = i32_1 ^ i32_2;
	l52 = i32_1;
	local_cache[104] = 1;
	i32_0 = i32_0 ^ i32_1;
	l33 = i32_0;
	local_cache[66] = 1;
	i32_1 = l18;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l43;
	i32_0 = i32_0 ^ i32_1;
	l37 = i32_0;
	local_cache[74] = 1;
	i32_1 = l33;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l41;
	i32_0 = i32_0 ^ i32_1;
	l41 = i32_0;
	local_cache[82] = 1;
	i32_0 = l43;
	i32_1 = l43;
	i32_2 = l17;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 9;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l39;
	i32_1 = i32_1 ^ i32_2;
	l39 = i32_1;
	local_cache[78] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_0 = i32_0 ^ i32_1;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = l39;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_0 = i32_0 ^ i32_1;
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = l47;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 7;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l49;
	i32_0 = i32_0 ^ i32_1;
	l43 = i32_0;
	local_cache[86] = 1;
	i32_1 = l17;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 9;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l50;
	i32_0 = i32_0 ^ i32_1;
	l27 = i32_0;
	local_cache[54] = 1;
	i32_1 = l43;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l47;
	i32_0 = i32_0 ^ i32_1;
	l31 = i32_0;
	local_cache[62] = 1;
	i32_1 = l27;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l17;
	i32_0 = i32_0 ^ i32_1;
	l17 = i32_0;
	local_cache[34] = 1;
	i32_0 = l52;
	i32_1 = l52;
	i32_2 = l47;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 13;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l20;
	i32_1 = i32_1 ^ i32_2;
	l20 = i32_1;
	local_cache[40] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l19;
	i32_0 = i32_0 ^ i32_1;
	l19 = i32_0;
	local_cache[38] = 1;
	i32_1 = l25;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 7;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l16;
	i32_0 = i32_0 ^ i32_1;
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = l19;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 9;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l48;
	i32_0 = i32_0 ^ i32_1;
	l47 = i32_0;
	local_cache[94] = 1;
	i32_1 = l16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l25;
	i32_0 = i32_0 ^ i32_1;
	l25 = i32_0;
	local_cache[50] = 1;
	i32_1 = l47;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l19;
	i32_0 = i32_0 ^ i32_1;
	l19 = i32_0;
	local_cache[38] = 1;
	i32_0 = l45;
	i32_1 = l51;
	i32_2 = l50;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 18;
	i32_1 = rotate(i32_1, i32_2 & 31);
	i32_2 = l5;
	i32_1 = i32_1 ^ i32_2;
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 7;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l20;
	i32_0 = i32_0 ^ i32_1;
	l20 = i32_0;
	local_cache[40] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 9;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l39;
	i32_0 = i32_0 ^ i32_1;
	l39 = i32_0;
	local_cache[78] = 1;
	i32_1 = l20;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 13;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l45;
	i32_0 = i32_0 ^ i32_1;
	l45 = i32_0;
	local_cache[90] = 1;
	i32_1 = l39;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 18;
	i32_0 = rotate(i32_0, i32_1 & 31);
	i32_1 = l5;
	i32_0 = i32_0 ^ i32_1;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l21;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l21 = i32_0;
	local_cache[42] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l2_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[102]) write_u32_aligned((ulong)(stack_u32+94+sfp_ptr), (ulong)stack_u32, l51, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[102] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[104]) write_u32_aligned((ulong)(stack_u32+96+sfp_ptr), (ulong)stack_u32, l52, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[104] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[100]) write_u32_aligned((ulong)(stack_u32+92+sfp_ptr), (ulong)stack_u32, l50, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[100] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[98]) write_u32_aligned((ulong)(stack_u32+90+sfp_ptr), (ulong)stack_u32, l49, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[98] = 0;
	if (local_cache[96]) write_u32_aligned((ulong)(stack_u32+88+sfp_ptr), (ulong)stack_u32, l48, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[96] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l2) */
	i32_0 = l4;
	i32_1 = l41;
	i32_2 = l40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+60+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l37;
	i32_2 = l36;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l33;
	i32_2 = l32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l18;
	i32_2 = l23;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l43;
	i32_2 = l42;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l17;
	i32_2 = l34;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l31;
	i32_2 = l30;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l27;
	i32_2 = l26;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l47;
	i32_2 = l46;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l16;
	i32_2 = l35;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l19;
	i32_2 = l28;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l25;
	i32_2 = l24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l45;
	i32_2 = l44;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l39;
	i32_2 = l38;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l20;
	i32_2 = l29;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l5;
	i32_2 = l22;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = 5;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = -64;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 0;
	i32_2 = l14;
	i32_3 = 1;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = l13;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l18 = i32_0;
	local_cache[36] = 1;
	i32_0 = l5;
	i32_1 = -65;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b1;
	}
	i32_0 = l18;
	i32_1 = p3;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b0;
	}
	i32_0 = l14;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = p0;
	i32_1 = l15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = p2;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l4;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l9;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l10;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l11;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[86]) write_u32_aligned((ulong)(stack_u32+78+sfp_ptr), (ulong)stack_u32, l43, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[86] = 0;
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[94]) write_u32_aligned((ulong)(stack_u32+86+sfp_ptr), (ulong)stack_u32, l47, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[94] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[92]) write_u32_aligned((ulong)(stack_u32+84+sfp_ptr), (ulong)stack_u32, l46, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[92] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[88]) write_u32_aligned((ulong)(stack_u32+80+sfp_ptr), (ulong)stack_u32, l44, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[88] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+76+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+74+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[90]) write_u32_aligned((ulong)(stack_u32+82+sfp_ptr), (ulong)stack_u32, l45, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[90] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_l0) */
	i32_0 = l4;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p1;
	i32_2 = 1056612;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 188;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l18;
	i32_2 = 1056628;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l18;
	i32_1 = p3;
	i32_2 = 1056628;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[85] = { 0 };
	uint l25 = 0;
	uint l11 = 0;
	uint l16 = 0;
	uint p1 = 0;
	uint l7 = 0;
	ulong l9 = 0;
	uint l39 = 0;
	uint l27 = 0;
	uint l21 = 0;
	uint l24 = 0;
	uint l22 = 0;
	uint l40 = 0;
	uint l41 = 0;
	uint l23 = 0;
	uint l37 = 0;
	uint l36 = 0;
	uint l17 = 0;
	uint l28 = 0;
	uint l6 = 0;
	uint l32 = 0;
	uint l34 = 0;
	ulong l8 = 0;
	uint l15 = 0;
	uint p5 = 0;
	uint p3 = 0;
	ulong l10 = 0;
	uint p4 = 0;
	uint p0 = 0;
	uint l20 = 0;
	uint l35 = 0;
	uint l18 = 0;
	uint l19 = 0;
	uint l30 = 0;
	uint l42 = 0;
	uint l29 = 0;
	uint l13 = 0;
	uint l38 = 0;
	uint l26 = 0;
	uint l33 = 0;
	ulong l12 = 0;
	uint l31 = 0;
	uint p2 = 0;
	uint l14 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_9;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-10+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p5 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p4 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-12+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 1088;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1057176+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i64_0;
	local_cache[16] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 80;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1057168+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i64_0;
	local_cache[18] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1057160+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i64_0;
	local_cache[20] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 904;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 912;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 920;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 928;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 936;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 944;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 952;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 960;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 872;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l10;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 880;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l9;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 888;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l8;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1057152+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i64_0;
	local_cache[24] = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+752+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l12;
	write_u64_aligned((ulong)((global char*)heap_u32+864+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 968;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 896;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 96;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = 76;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 3906369333256140342;
	write_u64_aligned((ulong)((global char*)heap_u32+688+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 6655295901103053916;
	write_u64_aligned((ulong)((global char*)heap_u32+512+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 864;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 65;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b1;
	}
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 96;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 88;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 80;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l10;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l9;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = l8;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+1016+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1080+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+1008+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l12;
	write_u64_aligned((ulong)((global char*)heap_u32+976+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p0;
	i32_2 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 304;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 976;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 112;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+176+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 304;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 163;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+176+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l0_loop:
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l6;
	i32_3 = 112;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = l7;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l16 = i32_2;
	local_cache[32] = 1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	l17 = i32_2;
	local_cache[34] = 1;
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l17;
	i32_2 = l15;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l16;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_2;
	local_cache[2] = 1;
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l15;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = p1;
	i32_2 = l15;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l7;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b0;
	}
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b2;
	}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l18 = i32_0;
	local_cache[36] = 1;
	i32_0 = p1;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l19 = i32_0;
	local_cache[38] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l1_loop:
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = p0;
	i32_3 = l7;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l16 = i32_2;
	local_cache[32] = 1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	l17 = i32_2;
	local_cache[34] = 1;
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l17;
	i32_2 = l15;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l16;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_2;
	local_cache[2] = 1;
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l15;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = p1;
	i32_2 = l15;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l19;
	i32_1 = l7;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l7 = i32_1;
	local_cache[14] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l1) */
	i32_0 = l18;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b0;
	}
	i32_0 = p0;
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = p1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = p0;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_2;
	local_cache[2] = 1;
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = p1;
	i32_2 = l7;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = l6;
	i32_2 = 688;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 64;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_2:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l6;
	i32_2 = 512;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 64;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 688;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 96;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l20 = i32_0;
	local_cache[40] = 1;
	i32_1 = l6;
	i32_2 = 688;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 112;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l21 = i32_0;
	local_cache[42] = 1;
	i32_1 = l6;
	i32_2 = 808;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_1 = l6;
	i32_2 = 816;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l23 = i32_0;
	local_cache[46] = 1;
	i32_1 = l6;
	i32_2 = 824;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l24 = i32_0;
	local_cache[48] = 1;
	i32_1 = l6;
	i32_2 = 832;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l25 = i32_0;
	local_cache[50] = 1;
	i32_1 = l6;
	i32_2 = 840;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l26 = i32_0;
	local_cache[52] = 1;
	i32_1 = l6;
	i32_2 = 848;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 868;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 876;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 884;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 892;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+792+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+112+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+860+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+72+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+784+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+856+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l27 = i32_0;
	local_cache[54] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l28 = i32_0;
	local_cache[56] = 1;
	i32_1 = l11;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l29 = i32_0;
	local_cache[58] = 1;
	i32_1 = l11;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l30 = i32_0;
	local_cache[60] = 1;
	i32_1 = l11;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l31 = i32_0;
	local_cache[62] = 1;
	i32_1 = l11;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l32 = i32_0;
	local_cache[64] = 1;
	i32_1 = l11;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l33 = i32_0;
	local_cache[66] = 1;
	i32_1 = l11;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l34 = i32_0;
	local_cache[68] = 1;
	i32_1 = l11;
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l11;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[50]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l25, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[50] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[54]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l27, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[54] = 0;
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[48]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l24, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[48] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[56]) write_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, l28, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[56] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[64]) write_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, l32, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[64] = 0;
	if (local_cache[68]) write_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, l34, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[68] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[60]) write_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, l30, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[60] = 0;
	if (local_cache[58]) write_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, l29, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[58] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[52]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l26, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[52] = 0;
	if (local_cache[66]) write_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, l33, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[66] = 0;
	if (local_cache[24]) write_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[62]) write_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, l31, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[62] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b3;
	}
	i32_0 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+896+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i64_0;
	local_cache[20] = 1;
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+968+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l35 = i32_0;
	local_cache[70] = 1;
	i32_0 = l6;
	i32_1 = 304;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l36 = i32_0;
	local_cache[72] = 1;
	i32_0 = l6;
	i32_1 = 304;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l37 = i32_0;
	local_cache[74] = 1;
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l19 = i32_0;
	local_cache[38] = 1;
	i32_0 = l6;
	i32_1 = 72;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l38 = i32_0;
	local_cache[76] = 1;
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l39 = i32_0;
	local_cache[78] = 1;
	i32_0 = l6;
	i32_1 = 904;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p0 = i32_0;
	local_cache[0] = 1;
	i32_0 = l6;
	i32_1 = 176;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l40 = i32_0;
	local_cache[80] = 1;
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l6;
	i32_1 = 792;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = 0;
	l41 = i32_0;
	local_cache[82] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p4;
	i32_1 = 0;
	i32_2 = p5;
	i32_3 = 32;
	i32_4 = p5;
	i32_5 = 32;
	i32_4 = (uint)(i32_4) < (uint)(i32_5);
	(i32_4 != 0) ? (i32_2 = i32_2) : (i32_2 = i32_3);
	l18 = i32_2;
	local_cache[36] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l26;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l25;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l24;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l23;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l22;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l13;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+112+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = l40;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l40;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l34;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l33;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l32;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_1 = l31;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = l30;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l29;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l42 = i32_0;
	local_cache[84] = 1;
	i32_1 = l28;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l39;
	i32_1 = l38;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l39;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l38;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l39;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l38;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l39;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l38;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 688;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 176;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 56;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l27;
	write_u32_aligned((ulong)((global char*)heap_u32+856+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l9;
	write_u64_aligned((ulong)((global char*)heap_u32+784+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+176+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+688+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l35;
	write_u32_aligned((ulong)((global char*)heap_u32+968+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l10;
	write_u64_aligned((ulong)((global char*)heap_u32+896+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = p2;
	i32_2 = p3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_5:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l41;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l41 = i32_1;
	local_cache[82] = 1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l41;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l41;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l41;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+304+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l14;
	i32_1 = l6;
	i32_2 = 304;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_6:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 304;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 688;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 208;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+896+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i64_0;
	local_cache[16] = 1;
	i32_0 = l19;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l17;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l11;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l42;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l19;
	i32_1 = p0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l37;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l37;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+512+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+968+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+616+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = l8;
	write_u64_aligned((ulong)((global char*)heap_u32+544+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l36;
	i32_2 = 112;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 656;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 656;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 656;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l15 = i32_0;
	local_cache[30] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+656+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 656;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 163;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_7:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 624;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 624;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 624;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+656+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+624+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 512;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 624;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 8;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_8:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 512;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 112;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l7;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l15;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+656+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 976;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = 656;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 163;
	*is_calling = 1;
	return;
	__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_call_return_stub_9:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 272;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 272;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = 272;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l15;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l6;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+656+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+272+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l18;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l18;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b4;
	}
	i32_0 = l18;
	i32_1 = 60;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l3_loop:
	i32_0 = p4;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l7;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l6;
	i32_3 = 272;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = p1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l15 = i32_2;
	local_cache[30] = 1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l7;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = l17;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l15;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l7;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l17 = i32_0;
	local_cache[34] = 1;
	i32_1 = l17;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l15;
	i32_3 = 2;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l7;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l7;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l15;
	i32_3 = 3;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l11;
	i32_1 = p1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l3) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b5;
	}
	i32_0 = p4;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 272;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l4_loop:
	i32_0 = l7;
	i32_1 = l7;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = p1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l7;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l16;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l4) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[50]) l25 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[78]) l39 = read_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[54]) l27 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[48]) l24 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[80]) l40 = read_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[82]) l41 = read_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[74]) l37 = read_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[72]) l36 = read_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[56]) l28 = read_u32_aligned((ulong)(stack_u32+44+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[64]) l32 = read_u32_aligned((ulong)(stack_u32+52+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[68]) l34 = read_u32_aligned((ulong)(stack_u32+56+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) p4 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[70]) l35 = read_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[60]) l30 = read_u32_aligned((ulong)(stack_u32+48+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[84]) l42 = read_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[58]) l29 = read_u32_aligned((ulong)(stack_u32+46+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[76]) l38 = read_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[52]) l26 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[66]) l33 = read_u32_aligned((ulong)(stack_u32+54+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[62]) l31 = read_u32_aligned((ulong)(stack_u32+50+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p4;
	i32_1 = l18;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p5;
	i32_1 = l18;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 167;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-10+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[16]) write_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[84]) write_u32_aligned((ulong)(stack_u32+72+sfp_ptr), (ulong)stack_u32, l42, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[84] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) p5 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[78]) write_u32_aligned((ulong)(stack_u32+66+sfp_ptr), (ulong)stack_u32, l39, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[78] = 0;
	if (local_cache[80]) write_u32_aligned((ulong)(stack_u32+68+sfp_ptr), (ulong)stack_u32, l40, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[80] = 0;
	if (local_cache[82]) write_u32_aligned((ulong)(stack_u32+70+sfp_ptr), (ulong)stack_u32, l41, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[82] = 0;
	if (local_cache[74]) write_u32_aligned((ulong)(stack_u32+62+sfp_ptr), (ulong)stack_u32, l37, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[74] = 0;
	if (local_cache[72]) write_u32_aligned((ulong)(stack_u32+60+sfp_ptr), (ulong)stack_u32, l36, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[72] = 0;
	if (local_cache[20]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+-12+sfp_ptr), (ulong)stack_u32, p0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	if (local_cache[70]) write_u32_aligned((ulong)(stack_u32+58+sfp_ptr), (ulong)stack_u32, l35, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[70] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[76]) write_u32_aligned((ulong)(stack_u32+64+sfp_ptr), (ulong)stack_u32, l38, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[76] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u64_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u64_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 1088;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[47] = { 0 };
	uint l21 = 0;
	uint l23 = 0;
	uint l9 = 0;
	uint l11 = 0;
	uint l5 = 0;
	uint l14 = 0;
	uint l4 = 0;
	uint l18 = 0;
	uint l20 = 0;
	ulong l15 = 0;
	uint l10 = 0;
	uint l7 = 0;
	uint l22 = 0;
	uint l3 = 0;
	uint l19 = 0;
	uint l16 = 0;
	uint l17 = 0;
	uint l13 = 0;
	uint l2 = 0;
	uint l12 = 0;
	uint l8 = 0;
	uint p1 = 0;
	uint l6 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_14;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 32;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 288;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 4;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l3;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b1;
	}
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_0 = 4;
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = 0;
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l3;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b1;
	}
	i32_0 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l15 = i64_0;
	local_cache[30] = 1;
	i32_0 = l9;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l10;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l11;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 128;
	i32_1 = 1;
	i32_0 = __func_func_calloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l16 = i32_0;
	local_cache[32] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b7;
	}
	i32_0 = l14;
	i64_0 = l15;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_1 = (int)(i64_0);
	l17 = i32_1;
	local_cache[34] = 1;
	i32_2 = l14;
	i32_3 = l17;
	i32_4 = l16;
	i32_5 = 128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 167;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_1:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 131072;
	i32_1 = 1;
	i32_0 = __func_func_calloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l18 = i32_0;
	local_cache[36] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b6;
	}
	i32_0 = 128;
	i32_1 = 1;
	i32_0 = __func_func_calloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l19 = i32_0;
	local_cache[38] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b2;
	}
	i32_0 = 131072;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l18;
	l20 = i32_0;
	local_cache[40] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 128;
	i32_2 = p1;
	i32_3 = 128;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 127;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b5;
	}
	i32_0 = l20;
	i32_1 = l16;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l20;
	i32_1 = l4;
	i32_2 = l16;
	i32_3 = 128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 159;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_3:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l20;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l20 = i32_0;
	local_cache[40] = 1;
	i32_0 = p1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 166;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l21 = i32_0;
	local_cache[42] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l16;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+64+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1023;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 7;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 128;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b4;
	}
	i32_0 = l21;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l21 = i32_0;
	local_cache[42] = 1;
	i32_0 = l18;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l22 = i32_0;
	local_cache[44] = 1;
	i32_0 = 0;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l3_loop:
	i32_0 = l19;
	i32_1 = p1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l22;
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l16;
	i32_3 = p1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l23 = i32_2;
	local_cache[46] = 1;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_2 = l23;
	i32_3 = 1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = i32_1 ^ i32_2;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 128;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l3_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l3) */
	i32_0 = l19;
	i32_1 = 128;
	i32_2 = l16;
	i32_3 = 128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 159;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_5:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l21;
	i32_1 = 1024;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 166;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = l17;
	i32_2 = l16;
	i32_3 = 128;
	i32_4 = l2;
	i32_5 = 16;
	i32_4 = (int)(i32_4) + (int)(i32_5);
	i32_5 = 32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_5, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 167;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_6:
*sp -= 12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l19;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l18;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l16;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l21 = i32_0;
	local_cache[42] = 1;
	i32_1 = l11;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l10;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l9;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l20 = i32_0;
	local_cache[40] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l23 = i32_0;
	local_cache[46] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l16 = i32_0;
	local_cache[32] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l19 = i32_0;
	local_cache[38] = 1;
	i64_0 = 0;
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+200+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l20;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l23;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l16;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l8;
	i32_1 = 56;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 32;
	write_u8((ulong)((global char*)heap_u32+113+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+128+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 1;
	write_u64_aligned((ulong)((global char*)heap_u32+120+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 0;
	i32_2 = 86;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 200;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = 30;
	l23 = i32_0;
	local_cache[46] = 1;
	i32_0 = l8;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[44]) l22 = read_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l4_loop:
	i32_0 = p1;
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l16 = i32_1;
	local_cache[32] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 25;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l19 = i32_1;
	local_cache[38] = 1;
	i32_2 = 63;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 25;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l22 = i32_1;
	local_cache[44] = 1;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = l16;
	i32_3 = 4;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = 48;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 25;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l19;
	i32_2 = 6;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = l22;
	i32_3 = 2;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = 60;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 25;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = l20;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l4;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l23;
	i32_1 = -3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l23 = i32_0;
	local_cache[46] = 1;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l4_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[44]) write_u32_aligned((ulong)(stack_u32+40+sfp_ptr), (ulong)stack_u32, l22, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[44] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l4) */
	i32_0 = l2;
	i32_1 = 24;
	i32_2 = l2;
	i32_2 = (uchar)(read_u8((ulong)((global char*)heap_u32+80+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_2;
	local_cache[8] = 1;
	i32_3 = 2;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = 60;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	p1 = i32_2;
	local_cache[2] = 1;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 6;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = p1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 48;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+242+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+79+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	l20 = i32_1;
	local_cache[40] = 1;
	i32_2 = 2;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_2 = 25;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+240+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i32_2 = 4;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = l20;
	i32_3 = 4;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_3 = 48;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	p1 = i32_1;
	local_cache[2] = 1;
	i32_2 = 25;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 6;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 51;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 181;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 61;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 241;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 62;
	i32_3 = p1;
	i32_2 = (int)(i32_2) - (int)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 3;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 65;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+241+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 120;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 200;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 43;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 87;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_7:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b3;
	}
	i32_0 = l21;
	i32_1 = l2;
	i32_2 = 120;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+120+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+200+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b8;
	}
	i32_0 = l2;
	i32_1 = l13;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 97;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_8:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_0;
	local_cache[24] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l12;
	i32_1 = l13;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+200+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l21;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l13;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i64_0 = l15;
	i32_0 = (int)(i64_0);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b9;
	}
	i32_0 = l14;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[42]) l21 = read_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[46]) l23 = read_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[36]) l18 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[40]) l20 = read_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[38]) l19 = read_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[34]) l17 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l7;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 166;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[42]) write_u32_aligned((ulong)(stack_u32+38+sfp_ptr), (ulong)stack_u32, l21, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[42] = 0;
	if (local_cache[46]) write_u32_aligned((ulong)(stack_u32+42+sfp_ptr), (ulong)stack_u32, l23, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[46] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[36]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l18, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[36] = 0;
	if (local_cache[40]) write_u32_aligned((ulong)(stack_u32+36+sfp_ptr), (ulong)stack_u32, l20, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[40] = 0;
	if (local_cache[38]) write_u32_aligned((ulong)(stack_u32+34+sfp_ptr), (ulong)stack_u32, l19, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[38] = 0;
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	if (local_cache[34]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l17, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[34] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[30]) write_u64_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l0) */
	i32_0 = 1;
	i32_1 = 128;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_9:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b6:
	i32_0 = 1;
	i32_1 = 131072;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_10:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 128;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 26;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_11:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	i32_2 = 1056580;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 53;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_12:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1048744;
	i32_1 = 55;
	i32_2 = l2;
	i32_3 = 200;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1048800;
	i32_4 = 1048892;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_13:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = 128;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_call_return_stub_14:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l7;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 12;
	i32_0 = (uint)(i32_0) / (uint)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l5;
	i32_1 = l7;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l5_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b10;
	}
	i32_0 = l7;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b10:
	i32_0 = l7;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l5_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_l5) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b11;
	}
	i32_0 = l3;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 288;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[21] = { 0 };
	uint l6 = 0;
	uint p1 = 0;
	uint l8 = 0;
	uint l10 = 0;
	uint p0 = 0;
	uint l5 = 0;
	ulong l7 = 0;
	uint l2 = 0;
	uint l9 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	ulong i64_4 = 0;
	float f32_0 = 0.0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_25;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 40;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b86;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b84;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b81;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b79;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b79;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b78;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b76;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b74;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b72;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b70;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b68;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b66;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b64;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b62;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b60;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b32;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b36;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b34;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b39;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b28;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b26;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b30;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b17;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b19;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b22;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b12;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b14;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b16;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 32:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 33:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 34:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 35:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58;
			break;
		case 36:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b50;
			break;
		case 37:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b87;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b86;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b82;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b85;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_1 = 255;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_0:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b83;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_0 = (char)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_1:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b12;
	}
	i32_0 = l6;
	i32_1 = -96;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b20;
	}
	i32_0 = l6;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b37;
	}
	i32_0 = 4;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -192;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b81;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b50;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b79;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b80;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b27;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b25;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b29;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b57;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b55;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b53;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b61;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b59;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b77;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b75;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b73;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b71;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b69;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b67;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b65;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b63;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b35;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b33;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b38;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b18;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b21;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b13;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b15;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b81;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_2:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b80:
	i32_0 = 3;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 3;
	i32_1 = (int)(i32_1) == (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+41+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_3:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b49;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (ulong)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_4:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b48;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_1 = 65535;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_5:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b47;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_6:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b46;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_7:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b45;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_8:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b44;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_0 = (short)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_9:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b43;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (int)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_10:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b42;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_11:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b41;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	{
		uint temp = i32_1;
		___private_memcpy_nonmmu(&f32_0, &temp, sizeof(float));
	}
	f64_0 = (double)(f32_0);
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_12:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b40;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_13:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b88;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b56;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b54;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b5;
			break;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b11;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b9;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b51;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b10;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 35;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9218;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b89;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b90;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_14:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b91;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b2;
	}
	i32_0 = l5;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b92;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b93;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_15:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b94;
	}
	i32_0 = l6;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b4;
	}
	i32_0 = l5;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b8;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b8;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b95;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 4096;
	i32_2 = l4;
	i32_3 = 4096;
	i32_2 = (uint)(i32_2) < (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b97;
	}
	i32_0 = 4;
	l10 = i32_0;
	local_cache[20] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b96;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = l5;
	i32_1 = 12;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b7;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l10;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b101;
	}
	i32_0 = l10;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 101;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_17:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b99;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b102;
	}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) >> (ulong)(i64_1 & 63);
	i32_0 = (int)(i64_0);
	l9 = i32_0;
	local_cache[18] = 1;
	i64_0 = l7;
	i32_0 = (int)(i64_0);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b103;
	}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 97;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_18:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l10;
	i32_1 = l3;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 182;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = 9;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b98;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+43+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+41+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b104;
	}
	i32_0 = l10;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_l1_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b105;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b105:
	i32_0 = l4;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l3;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b98;
	}
	i32_0 = l10;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l5;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 10;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b6;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b12;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b6;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b106;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b106:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 11;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_19:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 33;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_20:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 34;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 4;
	i32_1 = l3;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_21:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b109;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b108;
	}
	i32_0 = l9;
	i32_1 = l5;
	i32_2 = l3;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b107;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b109:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b108:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b107:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_22:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b112;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b111;
	}
	i32_0 = l6;
	i32_1 = l8;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b110;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b112:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b111:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l8;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b110:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = l3;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b113;
	}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 5;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_23:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b113:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049100;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_24:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b114;
	}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b114:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_call_return_stub_25:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[19] = { 0 };
	ulong l7 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint l2 = 0;
	uint p0 = 0;
	uint l9 = 0;
	uint l3 = 0;
	uint l8 = 0;
	uint l4 = 0;
	uint l6 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	ulong i64_4 = 0;
	float f32_0 = 0.0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_24;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 40;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b86;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b84;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b81;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b79;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b79;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b78;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b76;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b74;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b72;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b70;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b68;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b66;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b64;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b62;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b60;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b32;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b36;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b34;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b39;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b28;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b26;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b30;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b18;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b20;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b22;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b13;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b15;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b17;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 32:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 33:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 34:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 35:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58;
			break;
		case 36:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b50;
			break;
		case 37:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b87;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b86;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b82;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b85;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_1 = 255;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_0:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b83;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_0 = (char)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_1:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b13;
	}
	i32_0 = l6;
	i32_1 = -96;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b18;
	}
	i32_0 = l6;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b37;
	}
	i32_0 = 4;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -192;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b81;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b50;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b79;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b80;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b27;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b25;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b29;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b57;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b55;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b53;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b61;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b59;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b77;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b75;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b73;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b71;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b69;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b67;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b65;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b63;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b35;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b33;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b38;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b19;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b21;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b14;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b16;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b81;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_2:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b80:
	i32_0 = 3;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 3;
	i32_1 = (int)(i32_1) == (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+17+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_3:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b49;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (ulong)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_4:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b48;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_1 = 65535;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_5:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b47;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_6:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b46;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_7:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b45;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_8:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b44;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_0 = (short)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_9:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b43;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (int)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_10:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b42;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_11:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b41;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	{
		uint temp = i32_1;
		___private_memcpy_nonmmu(&f32_0, &temp, sizeof(float));
	}
	f64_0 = (double)(f32_0);
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_12:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b40;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_13:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b88;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b56;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b54;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b7;
			break;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b12;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b10;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b51;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b11;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 35;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9218;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b31;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b89;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b90;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_14:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b91;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b4;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b24;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b23;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b92;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b93;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_15:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b94;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b6;
	}
	i32_0 = l6;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b9;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b18;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b9;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b95;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 10;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_16:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b8;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b13;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b8;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b96;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 11;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_17:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 33;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 1049084;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_18:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 34;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b97;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b98;
	}
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l3;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l5;
	i32_2 = l3;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 176;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_19:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l5;
	i32_2 = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 176;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_20:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b101;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b100;
	}
	i32_0 = l5;
	i32_1 = l9;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b99;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l9;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l5;
	i32_2 = l3;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b102;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b104;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b103;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b1;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p1;
	i32_1 = l5;
	i32_0 = __func_func___rust_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = p1;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = l4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 176;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_21:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b105;
	}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b105:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_22:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_23:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E_call_return_stub_24:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[19] = { 0 };
	uint l8 = 0;
	uint l9 = 0;
	uint l2 = 0;
	uint l5 = 0;
	ulong l7 = 0;
	uint p0 = 0;
	uint l4 = 0;
	uint l6 = 0;
	uint p1 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	ulong i64_4 = 0;
	float f32_0 = 0.0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_17;
			case 18:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_18;
			case 19:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_19;
			case 20:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_20;
			case 21:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_21;
			case 22:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_22;
			case 23:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_23;
			case 24:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_24;
			case 25:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_25;
			case 26:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_26;
			case 27:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_27;
			case 28:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_28;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 40;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b92;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b90;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b87;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b85;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b85;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b84;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b82;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b80;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b78;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b76;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b74;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b72;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b70;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b68;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b66;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b38;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b42;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b40;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b45;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b34;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b32;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b36;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b23;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b25;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b28;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b17;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b19;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b22;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 32:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 33:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 34:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 35:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64;
			break;
		case 36:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b56;
			break;
		case 37:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b93;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b92;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b88;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b91;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_1 = 255;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_0:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b89;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_0 = (char)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_1:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b20;
	}
	i32_0 = l6;
	i32_1 = -96;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b26;
	}
	i32_0 = l6;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b43;
	}
	i32_0 = 4;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -192;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b87;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b56;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b85;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b86;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b33;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b31;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b35;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b63;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b61;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b59;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b67;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b65;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b83;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b81;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b79;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b77;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b75;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b73;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b71;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b69;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b41;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b39;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b44;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b24;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b27;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b18;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b21;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b87;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_2:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b86:
	i32_0 = 3;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 3;
	i32_1 = (int)(i32_1) == (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+41+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_3:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b55;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (ulong)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_4:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b54;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_1 = 65535;
	i64_0 = (ulong)(i64_0) & (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_5:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b80:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b53;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_6:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b52;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_7:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b51;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_8:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b50;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_0 = (short)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_9:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b49;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (int)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_10:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b48;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_11:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b47;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	{
		uint temp = i32_1;
		___private_memcpy_nonmmu(&f32_0, &temp, sizeof(float));
	}
	f64_0 = (double)(f32_0);
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_12:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b46;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_13:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b94;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b62;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b60;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b10;
			break;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b16;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b14;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b57;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b15;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 35;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9218;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b37;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b38;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b38;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b37;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b38;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b37;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b95;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b96;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_14:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b97;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b2;
	}
	i32_0 = l5;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b98;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b99;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_15:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b100;
	}
	i32_0 = l6;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l9;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b4;
	}
	i32_0 = l5;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b13;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b23;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b23;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b13;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b101;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b103;
	}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 182;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_16:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b12;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b102;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 157;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_17:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b5;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b11;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b11;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b104;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b8;
	}
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 19, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 153;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_19:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+41+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b108;
	}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+42+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+26+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b106;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b108:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b109;
	}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 20, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_20:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b107;
	}
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 17;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b109:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b110;
	}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 21, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 103;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_21:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b105;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b110:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 22, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 182;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_22:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b111;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l4;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 18, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 17;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b111:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+43+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+27+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+41+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b107:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+41+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b106:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b105:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b112;
	}
	i32_0 = l9;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_l1_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b113;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b113:
	i32_0 = l3;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l5;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b112:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6;
	}
	i32_0 = l9;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 33;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 23, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_23:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 34;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+43+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+27+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+41+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+48+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b5;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b7;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 40;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 24, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 158;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_24:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l2;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+43+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+41+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b7;
	}
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned_checked((ulong)((global char*)heap_u32+25+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+27+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 36;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+24+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b116;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b115;
	}
	i32_0 = l9;
	i32_1 = l5;
	i32_2 = l3;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b114;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b116:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b115:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b114:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 25, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_25:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b119;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b118;
	}
	i32_0 = l6;
	i32_1 = l8;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b117;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b119:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b118:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l8;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b117:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l6;
	i32_2 = l3;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b120;
	}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 5;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 26, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_26:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b120:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 56;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 27, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_27:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b121;
	}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b121:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i64_0 = l7;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 28, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 133;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_call_return_stub_28:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[19] = { 0 };
	uint l9 = 0;
	uint l3 = 0;
	uint l6 = 0;
	ulong l7 = 0;
	uint l5 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint l8 = 0;
	uint l4 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	ulong i64_4 = 0;
	float f32_0 = 0.0;
	double f64_0 = 0.0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_13;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 40;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b84;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b82;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b79;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b77;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b77;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b76;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b74;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b72;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b70;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b68;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b66;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b64;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b62;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b60;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b58;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b30;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b34;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b32;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b37;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b26;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b24;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b28;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b16;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b18;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b20;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b11;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b13;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b15;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 32:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 33:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 34:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 35:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56;
			break;
		case 36:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b48;
			break;
		case 37:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b85;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b84;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b80;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b83;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 0;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b81;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l4;
	i64_0 = (ulong)(i32_1);
	i64_0 = (char)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_0:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = -112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b11;
	}
	i32_0 = l6;
	i32_1 = -96;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b16;
	}
	i32_0 = l6;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b35;
	}
	i32_0 = 4;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -192;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b79;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b48;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b77;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b78;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b25;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b23;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b27;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b55;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b53;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b51;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b59;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b57;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b75;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b73;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b71;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b69;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b67;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b65;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b63;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b61;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b33;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b31;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b36;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b17;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b19;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b12;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b14;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b79;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b80:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 7;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_1:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b78:
	i32_0 = 3;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 255;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 3;
	i32_1 = (int)(i32_1) == (int)(i32_2);
	write_u8((ulong)((global char*)heap_u32+9+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_2:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b47;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 0;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b46;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 0;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b45;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = p1;
	i32_2 = 0;
	i32_1 = (uint)(i32_1) != (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b44;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i64_0 = l7;
	i64_1 = 0;
	i32_1 = (ulong)(i64_0) != (ulong)(i64_1);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b68:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b67:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b43;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_3:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b66:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b65:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b42;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (ulong)(i32_1);
	i64_0 = (short)(i64_0);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_4:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b41;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i64_0 = (int)(i32_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_5:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b40;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 2;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_6:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b39;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = p1;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = p1;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = p1;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = p1;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	{
		uint temp = i32_1;
		___private_memcpy_nonmmu(&f32_0, &temp, sizeof(float));
	}
	f64_0 = (double)(f32_0);
	{
		ulong temp = 0;
		___private_memcpy_nonmmu(&temp, &f64_0, sizeof(double));
		write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), temp, warp_idx, read_idx, thread_idx, scratch_space);
	}
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_7:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b38;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i64_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_1 = 3;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i64_0 = l7;
	i64_1 = 56;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = l7;
	i64_2 = 65280;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 40;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 16711680;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = 24;
	i64_1 = (ulong)(i64_1) << (i64_2 & 63);
	i64_2 = l7;
	i64_3 = 4278190080;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = 8;
	i64_2 = (ulong)(i64_2) << (i64_3 & 63);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l7;
	i64_2 = 8;
	i64_1 = (ulong)(i64_1) >> (ulong)(i64_2 & 63);
	i64_2 = 4278190080;
	i64_1 = (ulong)(i64_1) & (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 24;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 16711680;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_2 = l7;
	i64_3 = 40;
	i64_2 = (ulong)(i64_2) >> (ulong)(i64_3 & 63);
	i64_3 = 65280;
	i64_2 = (ulong)(i64_2) & (ulong)(i64_3);
	i64_3 = l7;
	i64_4 = 56;
	i64_3 = (ulong)(i64_3) >> (ulong)(i64_4 & 63);
	i64_2 = (ulong)(i64_2) | (ulong)(i64_3);
	i64_1 = (ulong)(i64_1) | (ulong)(i64_2);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_8:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b86;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b54;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b52;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b5;
			break;
	}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b10;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b8;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b49;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b9;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 35;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9218;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b29;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b87;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b88;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_9:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b89;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b2;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b21;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b21;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b21;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b90;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b91;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_10:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b92;
	}
	i32_0 = l9;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b4;
	}
	i32_0 = l5;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b7;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b16;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b7;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b93;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 10;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_11:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b6;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b11;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b6;
	}
	i32_0 = p1;
	i32_1 = l5;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b94;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 11;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_12:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 33;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l2;
	i32_3 = 24;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049132;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 54;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_call_return_stub_13:
*sp -= 8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 34;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b95;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b96;
	}
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = l3;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l6;
	i32_2 = l3;
	__func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l5;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 265;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b99;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l9 = i32_0;
	local_cache[18] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b101;
	}
	i32_0 = l5;
	i32_1 = l9;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = l4;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b100;
	}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b98;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l9;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = 1;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b98;
	}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l4;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 105;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 110;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 112;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 117;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 116;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 95;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 118;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+7+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 101;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
	}
	i32_0 = l5;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 99;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = 1049152;
	i32_2 = 9;
	i32_0 = __func_func_memcmp_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_1 = 0;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN6scrypt4main17h13ff390b51655dbfE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[33] = { 0 };
	uint l1 = 0;
	uint l6 = 0;
	uint l12 = 0;
	uint l4 = 0;
	uint l11 = 0;
	uint l14 = 0;
	uint l13 = 0;
	uint l10 = 0;
	uint l3 = 0;
	uint l5 = 0;
	uint l9 = 0;
	uint l15 = 0;
	uint l0 = 0;
	uint l16 = 0;
	uint l7 = 0;
	uint l2 = 0;
	uint l8 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
		switch (*hypercall_continuation) {
			case 0:
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_0;
				break;
			case 1:
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_1;
				break;
			case 2:
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_2;
				break;
			case 3:
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_3;
				break;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_7;
			case 8:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_8;
			case 9:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_9;
			case 10:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_10;
			case 11:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_11;
			case 12:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_12;
			case 13:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_13;
			case 14:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_14;
			case 15:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_15;
			case 16:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_16;
			case 17:
				*sfp -= 1;
				goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_17;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 30;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 524296;
	i32_1 = 1;
	i32_0 = __func_func_calloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b0;
	}
	i32_0 = l0;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 524296;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 9999;
	*hypercall_continuation = 0;
	return;
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

    if (hcall_ret_val > hcall_size) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	___private_memcpy_cpu2gpu((ulong)((ulong)((global char *)hypercall_buffer + (hcall_size*warp_idx))), (ulong)(hypercall_buffer), (ulong)((global char *)heap_u32+i32_0), (ulong)(heap_u32), (ulong)(hcall_ret_val), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = hcall_ret_val;
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b1;
	}
	i32_0 = 0;
	i32_1 = 0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 10000;

    if ((i32_1 + 4) > hcall_size) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	___private_memcpy_gpu2cpu((ulong)((global char *)heap_u32+i32_0), (ulong)(heap_u32), (ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+4)), (ulong)(hypercall_buffer), (ulong)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))) = i32_1;
	*hypercall_continuation = 1;
	return;
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 55;
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 524297;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b5;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = 128;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b4;
	}
	i32_0 = l0;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l0;
	i64_0 = 128;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1024;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 17;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_1:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b6;
	}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b3;
	}
	i32_0 = l0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 166;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_2:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b7;
	}
	i32_0 = l7;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_l1_loop:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b8;
	}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b8:
	i32_0 = l4;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l6;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt4main17h13ff390b51655dbfE_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b2;
	}
	i32_0 = l7;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 524296;
	i32_2 = 1048656;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 177;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_3:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b4:
	i32_0 = 1;
	i32_1 = 128;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_4:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l0;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1057590;
	i32_1 = 43;
	i32_2 = l0;
	i32_3 = 16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1048672;
	i32_4 = 1048688;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_5:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 128;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l9 = i32_0;
	local_cache[18] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b11;
	}
	i32_0 = l9;
	i32_1 = 145;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b13;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b14;
	}
	i32_0 = l9;
	i32_1 = 221;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l9;
	i32_1 = l6;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l6;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l6;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l6;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 6;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 220;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l9;
	i32_1 = l6;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l6;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u16_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 4;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l6;
	i32_2 = 15;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 144;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b10;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = l6;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = 128;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l7;
	l11 = i32_0;
	local_cache[22] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l12 = i32_0;
	local_cache[24] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l11;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = 32;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b29;
	}
	i32_0 = l4;
	i32_1 = 256;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b28;
	}
	i32_0 = l4;
	i32_1 = 65536;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b25;
	}
	i32_0 = l5;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b19;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l5;
	i32_2 = l13;
	i32_3 = l5;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 8;
	i32_2 = l5;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b27;
	}
	i32_0 = 0;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b26;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b18;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l5;
	i32_2 = l13;
	i32_3 = l5;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 8;
	i32_2 = l5;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b31;
	}
	i32_0 = 0;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b30;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l13;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l14;
	i32_2 = l5;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b32;
	}
	i32_0 = l13;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b18;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l13;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b18;
	}
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l13;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_7:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b34;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l13;
	i32_2 = l5;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 8;
	i32_2 = l5;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b36;
	}
	i32_0 = 0;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b35;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l14;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l15;
	i32_2 = l5;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b33;
	}
	i32_0 = l14;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 217;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b21;
	}
	i32_0 = l13;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l13;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = l5;
	i32_2 = l14;
	i32_3 = l5;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 8;
	i32_2 = l5;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_0 = l13;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b24;
	}
	i32_0 = 0;
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b23;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b22;
	}
	i32_0 = l14;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l14;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 8, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_8:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l14;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l13;
	i32_2 = l5;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b37;
	}
	i32_0 = l13;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l13;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b19;
	}
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l13;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 9, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_9:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b20;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l5;
	i32_2 = l13;
	i32_3 = l5;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = 8;
	i32_2 = l5;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b39;
	}
	i32_0 = 0;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b38;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l14;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l13;
	i32_2 = l5;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b40;
	}
	i32_0 = l13;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b20;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l13;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b20;
	}
	i32_0 = l13;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l13;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 10, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_10:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l13;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l15;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l14;
	i32_2 = l5;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b41;
	}
	i32_0 = l14;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b21;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l13;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l14;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b21;
	}
	i32_0 = l14;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l14;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 11, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_11:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 217;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 2;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 218;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b42;
	}
	i32_0 = l13;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = l13;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l14;
	i32_2 = l15;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 8;
	i32_2 = l14;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b44;
	}
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b43;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l16;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l15;
	i32_2 = l14;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b45;
	}
	i32_0 = l14;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l15;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b42;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l15;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b42;
	}
	i32_0 = l15;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l15;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 12, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_12:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l4;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 3;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 219;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l13 = i32_1;
	local_cache[26] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b46;
	}
	i32_0 = l13;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = l13;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l15 = i32_0;
	local_cache[30] = 1;
	i32_1 = l14;
	i32_2 = l15;
	i32_3 = l14;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = 8;
	i32_2 = l14;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b48;
	}
	i32_0 = 0;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b47;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l16 = i32_0;
	local_cache[32] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[32]) write_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, l16, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[32] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l16;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l15;
	i32_2 = l14;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b49;
	}
	i32_0 = l14;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l15;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b46;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l15;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b46;
	}
	i32_0 = l15;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l15;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 13, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_13:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[32]) l16 = read_u32_aligned((ulong)(stack_u32+32+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l13;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 24;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_2 = l4;
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = 8;
	i32_2 = (uint)(i32_2) << (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_2 = l4;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_3 = 65280;
	i32_2 = (uint)(i32_2) & (uint)(i32_3);
	i32_3 = l4;
	i32_4 = 24;
	i32_3 = (uint)(i32_3) >> (uint)(i32_4 & 31);
	i32_2 = (uint)(i32_2) | (uint)(i32_3);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 5;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = 31;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = -96;
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	l13 = i32_0;
	local_cache[26] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l3;
	i32_2 = l13;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b15;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l14 = i32_0;
	local_cache[28] = 1;
	i32_1 = l13;
	i32_2 = l14;
	i32_3 = l13;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = 8;
	i32_2 = l13;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l13 = i32_0;
	local_cache[26] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b51;
	}
	i32_0 = 0;
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b50;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l9;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l15 = i32_0;
	local_cache[30] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[30]) write_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, l15, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[30] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = l15;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l14;
	i32_2 = l13;
	i32_3 = l0;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l14 = i32_0;
	local_cache[28] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b52;
	}
	i32_0 = l13;
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l14;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b15;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l14;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b15;
	}
	i32_0 = l14;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16;
	}
	i32_0 = l14;
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 14, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_14:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[28]) l14 = read_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[26]) l13 = read_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[30]) l15 = read_u32_aligned((ulong)(stack_u32+30+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[28]) write_u32_aligned((ulong)(stack_u32+28+sfp_ptr), (ulong)stack_u32, l14, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[28] = 0;
	if (local_cache[26]) write_u32_aligned((ulong)(stack_u32+26+sfp_ptr), (ulong)stack_u32, l13, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[26] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b16:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 15, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_15:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 2;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[24]) l12 = read_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[22]) l11 = read_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[20]) l10 = read_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l12;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l11;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l11 = i32_0;
	local_cache[22] = 1;
	i32_1 = l10;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 55;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[24]) write_u32_aligned((ulong)(stack_u32+24+sfp_ptr), (ulong)stack_u32, l12, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[24] = 0;
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt4main17h13ff390b51655dbfE_l2) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = l3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 10000;

    if ((i32_1 + 4) > hcall_size) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	___private_memcpy_gpu2cpu((ulong)((global char *)heap_u32+i32_0), (ulong)(heap_u32), (ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+4)), (ulong)(hypercall_buffer), (ulong)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))) = i32_1;
	*hypercall_continuation = 2;
	return;
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = l5;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 55;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN6scrypt4main17h13ff390b51655dbfE_b9;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[22]) write_u32_aligned((ulong)(stack_u32+22+sfp_ptr), (ulong)stack_u32, l11, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[22] = 0;
	if (local_cache[20]) write_u32_aligned((ulong)(stack_u32+20+sfp_ptr), (ulong)stack_u32, l10, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[20] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b11:
	i32_0 = 1;
	i32_1 = 128;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 16, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_16:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 3;
	return;

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	i32_1 = 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 10000;

    if ((i32_1 + 4) > hcall_size) {
        	*((volatile unsigned long *)0x6) = 0x6;

    }
	___private_memcpy_gpu2cpu((ulong)((global char *)heap_u32+i32_0), (ulong)(heap_u32), (ulong)((ulong)((global char *)hypercall_buffer+(hcall_size*warp_idx)+4)), (ulong)(hypercall_buffer), (ulong)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	*((global uint*)((global char*)hypercall_buffer+(hcall_size*warp_idx))) = i32_1;
	*hypercall_continuation = 3;
	return;
__func_func__ZN6scrypt4main17h13ff390b51655dbfE_hypercall_return_stub_3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+0), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = read_u32_aligned((ulong)(stack_u32+sfp_ptr+34+2), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+18+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l9;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 55;
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+16+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN6scrypt4main17h13ff390b51655dbfE_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN6scrypt4main17h13ff390b51655dbfE_b0:
	i32_0 = 8;
	i32_1 = 524296;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 17, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN6scrypt4main17h13ff390b51655dbfE_call_return_stub_17:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 4;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[17] = { 0 };
	uint l8 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint l2 = 0;
	uint l7 = 0;
	uint p1 = 0;
	uint p0 = 0;
	uint l6 = 0;
	uint l5 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_7;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_1 = 37;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b93;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b92;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b91;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b90;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b90;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b89;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b87;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b85;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b83;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b81;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b79;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b77;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b75;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b73;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b71;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b40;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b44;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b42;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b47;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b36;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b34;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b38;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b25;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b27;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b30;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b19;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b21;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b24;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 32:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 33:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 34:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 35:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69;
			break;
		case 36:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b58;
			break;
		case 37:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b94;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b93;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b94:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b95;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_1;
	local_cache[10] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b93;
	}
	i32_0 = l5;
	i32_1 = -33;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b92;
	}
	i32_0 = l5;
	i32_1 = -112;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b22;
	}
	i32_0 = l5;
	i32_1 = -96;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b28;
	}
	i32_0 = l5;
	i32_1 = -64;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b45;
	}
	i32_0 = l5;
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -192;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b91;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b58;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b90;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b90;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b35;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b33;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b37;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b63;
			break;
		case 8:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b61;
			break;
		case 9:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b59;
			break;
		case 10:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b72;
			break;
		case 11:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b70;
			break;
		case 12:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b88;
			break;
		case 13:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b86;
			break;
		case 14:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b84;
			break;
		case 15:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b82;
			break;
		case 16:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b80;
			break;
		case 17:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b78;
			break;
		case 18:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b76;
			break;
		case 19:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b74;
			break;
		case 20:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b18;
			break;
		case 21:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b68;
			break;
		case 22:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b67;
			break;
		case 23:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b66;
			break;
		case 24:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b65;
			break;
		case 25:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b43;
			break;
		case 26:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b41;
			break;
		case 27:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b46;
			break;
		case 28:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b26;
			break;
		case 29:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b29;
			break;
		case 30:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b20;
			break;
		case 31:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b23;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b91;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b95:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b93:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b92:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b91:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b90:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b89:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b88:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b57;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b87:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b86:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b56;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b85:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b84:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b55;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b83:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b82:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b54;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b81:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b80:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b53;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b79:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b78:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b52;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b77:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b76:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b51;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b75:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b74:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b50;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b73:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b72:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b49;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b71:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b70:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 7;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b48;
	}
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b69:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 2;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l5;
	i32_1 = -28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
			break;
		case 1:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b68;
			break;
		case 2:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b67;
			break;
		case 3:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b66;
			break;
		case 4:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b65;
			break;
		case 5:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b64;
			break;
		case 6:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b62;
			break;
		case 7:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b60;
			break;
		default:
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b5;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b68:
	i32_0 = 2;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b67:
	i32_0 = 4;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b66:
	i32_0 = 8;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b65:
	i32_0 = 16;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b64:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b63:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b16;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b62:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b61:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b14;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b60:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b59:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b96;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b96:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 35;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b58:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 9218;
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b57:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b56:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b55:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b54:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b53:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b52:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b51:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b50:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b49:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b48:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b47:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b46:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b39;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b40;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b45:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b40;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b44:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b43:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b39;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b40;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b42:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b41:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b39;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b40:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b97;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b97:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b98;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b98:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b99;
	}
	i32_0 = l7;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l6 = i32_1;
	local_cache[12] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b99:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b2;
	}
	i32_0 = l6;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b39:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b38:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b37:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b31;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b36:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b35:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b31;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b32;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b34:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b33:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b31;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b32:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b100;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b100:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l3;
	i32_2 = l4;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b101;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l4;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_1:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b101:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l5;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b102;
	}
	i32_0 = l7;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l6;
	i32_1 = l5;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l5 = i32_1;
	local_cache[10] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b102:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b4;
	}
	i32_0 = l5;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b3;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b31:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b30:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b29:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b13;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b25;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b28:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b25;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b27:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b26:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b13;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b25:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b103;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b103:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b105;
	}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_3:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b106;
	}
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+18+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+17+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b104;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b106:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b105:
	i32_0 = 9;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b104:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l5;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b24:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b23:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b12;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 24;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = 8;
	i32_1 = (uint)(i32_1) << (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_2 = 65280;
	i32_1 = (uint)(i32_1) & (uint)(i32_2);
	i32_2 = l3;
	i32_3 = 24;
	i32_2 = (uint)(i32_2) >> (uint)(i32_3 & 31);
	i32_1 = (uint)(i32_1) | (uint)(i32_2);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b22:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 15;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b21:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b12;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = 2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_0 = ((uint)(read_u16_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 8;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (uint)(i32_1) >> (uint)(i32_2 & 31);
	i32_0 = (uint)(i32_0) | (uint)(i32_1);
	i32_1 = 65535;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b107;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b107:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b109;
	}
__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_5:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b112;
	}
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+18+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b111;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b112:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_6:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 9;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b110;
	}
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+18+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b111:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+17+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+6+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+22+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b108;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b110:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 56;
	*is_calling = 0;
	return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b109:
	i32_0 = 9;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = 0;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b108:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+22+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b18:
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b15;
	}
	i32_0 = p0;
	i32_1 = 8;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 33;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b9;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = -1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b113;
	}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b113:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = l6;
	i32_2 = l3;
	i32_1 = (int)(i32_1) - (int)(i32_2);
	l8 = i32_1;
	local_cache[16] = 1;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b114;
	}
	i32_0 = p1;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l3;
	i32_2 = l8;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_call_return_stub_7:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b114:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_1 = 2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b115;
	}
	i32_0 = l7;
	i32_1 = 0;
	i32_2 = l8;
	i32_3 = -1;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	l3 = i32_2;
	local_cache[6] = 1;
	___private_bulk_memfill((i32_0), (ulong)(heap_u32), i32_1, (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = l3;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l4 = i32_1;
	local_cache[8] = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b11;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b115:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b11;
	}
	i32_0 = l4;
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	i64_1 = 32;
	i64_0 = (ulong)(i64_0) << (i64_1 & 63);
	i64_1 = 2;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 34;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b12:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	i64_0 = (ulong)(i32_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l6;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b9;
	}
	i32_0 = l3;
	i32_1 = l6;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b8;
	}
	i32_0 = l5;
	i32_1 = l4;
	i32_2 = l6;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b9:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+16+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l4;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 9;
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned_checked((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l2;
	i32_1 = ((uint)(read_u16_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space)));
	write_u16_aligned((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (short)(i32_1), warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = p1;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l2;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+20+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned_checked((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	write_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l7;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l5;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = l3;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b118;
	}
	i32_0 = l4;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b117;
	}
	i32_0 = l6;
	i32_1 = l7;
	i32_2 = l3;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b116;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b118:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b117:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l7;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b116:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l5;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b121;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l4;
	i32_1 = 1;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b120;
	}
	i32_0 = l5;
	i32_1 = l6;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b119;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b121:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1048732;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	goto __func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0;

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b120:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l6;
	i32_1 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx));
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = 1;
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b119:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l5;
	i32_2 = l4;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = p1;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);

__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint l4 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint p2 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_2;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
	__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_fastcall(i32_0, i32_1, i32_2, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b3;
	}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p2 = i32_0;
	local_cache[4] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b5;
	}
	i32_0 = 1;
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b1;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b7;
	}
	i32_0 = l5;
	i32_1 = p2;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p2;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = l4;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l3;
	i32_3 = 40;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 205;
	*is_calling = 1;
	return;
	__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE_call_return_stub_2:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint p0 = 0;
	uint l2 = 0;
	uint p1 = 0;
	uint l5 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p1;
	i32_2 = l4;
	i32_3 = p1;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 4;
	i32_2 = p1;
	i32_3 = 4;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) * (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 178956971;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b3;
	}
	i32_0 = l2;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l3;
	i32_2 = 12;
	i32_1 = (int)(i32_1) * (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = l5;
	i32_2 = l4;
	i32_3 = l2;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b4;
	}
	i32_0 = p0;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b0;
	}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b1;
	}
	i32_0 = l3;
	i32_1 = l2;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[19] = { 0 };
	uint p1 = 0;
	uint l6 = 0;
	uint l2 = 0;
	uint l3 = 0;
	uint l9 = 0;
	uint l5 = 0;
	uint l4 = 0;
	uint l7 = 0;
	uint p0 = 0;
	uint l8 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_4;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p1;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	switch(i32_0) {
		case 0:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b15;
			break;
		case 1:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b14;
			break;
		default:
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b13;
			break;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b15:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b9;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 1057276;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b14:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b6;
	}
	i32_0 = l5;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b12;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b13:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l5;
	i32_1 = 4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b11;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b12:
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = 0;
	l9 = i32_0;
	local_cache[18] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b11:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l5;
	i32_1 = -4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	l9 = i32_0;
	local_cache[18] = 1;
	l5 = i32_0;
	local_cache[10] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l0_loop:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l6;
	i32_2 = -8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_2 = l6;
	i32_3 = -16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_2 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_2)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_3 = l6;
	i32_4 = -24;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_3 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_3)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_4 = l7;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l5;
	i32_1 = -4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l0) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[18]) write_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, l9, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[18] = 0;
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b10:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[18]) l9 = read_u32_aligned((ulong)(stack_u32+14+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l8;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b16;
	}
	i32_0 = l9;
	i32_1 = 3;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	i32_1 = l4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l1_loop:
	i32_0 = l6;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l7;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l6;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = l8;
	i32_1 = -1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l8 = i32_0;
	local_cache[16] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l1_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_l1) */
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b16:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b17;
	}
	i32_0 = l7;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b9;
	}
	i32_0 = l7;
	i32_1 = 16;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	i32_1 = l4;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = !(i32_1);
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b9;
	}
	i32_0 = l7;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b17:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	if (i32_0 != 0) {
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b8;
	}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b9:
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b8:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b3;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = l7;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b2;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b7:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l2;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	i64_0 = (read_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u64_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1049248;
	i32_2 = l2;
	i32_3 = 16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 178;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_0:
	*sp += 2;
	*sp -= 6;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b1;
	}
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
	i32_0 = l2;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b6:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l7 = i32_0;
	local_cache[14] = 1;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b18;
	}
	i32_0 = 1;
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = 0;
	l7 = i32_0;
	local_cache[14] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b5;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	if (local_cache[14]) write_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l7, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[14] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b18:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = -1;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b3;
	}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_1 = l5;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b20;
	}
	i32_0 = l5;
	i32_1 = l7;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b19;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b20:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l7;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l6 = i32_0;
	local_cache[12] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[12]) write_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l6, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[12] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b19:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b0;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[10]) write_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l6;
	i32_1 = l8;
	i32_2 = l7;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l7;
	l8 = i32_0;
	local_cache[16] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[16]) write_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, l8, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[16] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[12]) l6 = read_u32_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[16]) l8 = read_u32_aligned((ulong)(stack_u32+12+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_1 = l6;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 6;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l7;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l8;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b3:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1;
	i32_1 = l7;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_2:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1049344;
	i32_1 = 51;
	i32_2 = l2;
	i32_3 = 40;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1049396;
	i32_4 = 1049436;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_3:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l5;
	i32_1 = l7;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E_call_return_stub_4:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u32_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[14]) l7 = read_u32_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint l4 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint p2 = 0;
	uint l3 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_call_return_stub_1;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 26;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 32;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = p1;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b1;
	}
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
	i32_1 = 1;
	i32_0 = (uint)(i32_0) << (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_1 = p2;
	i32_2 = l4;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = 8;
	i32_2 = p2;
	i32_3 = 8;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	p2 = i32_0;
	local_cache[4] = 1;
	i32_1 = -1;
	i32_0 = i32_0 ^ i32_1;
	i32_1 = 31;
	i32_0 = (uint)(i32_0) >> (uint)(i32_1 & 31);
	l4 = i32_0;
	local_cache[8] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b3;
	}
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b2;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b3:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b2:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = l4;
	i32_2 = p2;
	i32_3 = l3;
	i32_4 = 16;
	i32_3 = (int)(i32_3) + (int)(i32_4);
	__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_fastcall(i32_0, i32_1, i32_2, i32_3, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	p1 = i32_0;
	local_cache[2] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b4;
	}
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b0;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b4:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p1;
	i32_1 = -2147483647;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b0;
	}
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b1;
	}
	i32_0 = p1;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, p1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, p2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b1:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 175;
	*is_calling = 1;
	return;
	__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_call_return_stub_1:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___main_void(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	ulong l3 = 0;
	ulong l4 = 0;
	uint l2 = 0;
	uint l0 = 0;
	ulong l5 = 0;
	uint l1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	uint i32_4 = 0;
	uint i32_5 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	ulong i64_2 = 0;
	ulong i64_3 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_0;
			case 1:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_1;
			case 2:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_2;
			case 3:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_3;
			case 4:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_4;
			case 5:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_5;
			case 6:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_6;
			case 7:
				*sfp -= 1;
				goto __func_func___main_void_call_return_stub_7;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 36;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l0 = i32_0;
	local_cache[0] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 5;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l1 = i32_0;
	local_cache[2] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___main_void_b4;
	}
	i32_0 = l1;
	i32_1 = 0;
	write_u8((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l1;
	i32_1 = 1852399981;
	write_u32_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = 24;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	l2 = i32_0;
	local_cache[4] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___main_void_b3;
	}
	i32_0 = l2;
	i32_1 = 5;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i64_0 = 4294967297;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i64_0 = (read_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i64_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[10]) l5 = read_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
__func_func___main_void_l0_loop:
	i64_0 = l3;
	i64_1 = 1;
	i64_0 = (long)(i64_0) + (long)(i64_1);
	l4 = i64_0;
	local_cache[8] = 1;
	i32_0 = !(i64_0);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___main_void_b2;
	}
	i32_0 = 0;
	i64_0 = l4;
	i32_1 = 0;
	i64_1 = (read_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i64_1;
	local_cache[10] = 1;
	i64_2 = l5;
	i64_3 = l3;
	i32_1 = (ulong)(i64_2) == (ulong)(i64_3);
	l1 = i32_1;
	local_cache[2] = 1;
	(i32_1 != 0) ? (i64_0 = i64_0) : (i64_0 = i64_1);
	write_u64_aligned((ulong)((global char*)heap_u32+1062152+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i64_0 = l5;
	l3 = i64_0;
	local_cache[6] = 1;
	i32_0 = l1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func___main_void_l0_loop;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[8]) write_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	if (local_cache[10]) write_u64_aligned((ulong)(stack_u32+10+sfp_ptr), (ulong)stack_u32, l5, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[10] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* END (loop: __func_func___main_void_l0) */
	i32_0 = l2;
	i64_0 = l4;
	write_u64_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___main_void_b1;
	}
	i32_0 = 0;
	i32_1 = -1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062172+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func___main_void_b0;
	}
	i32_0 = 0;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+1062172+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+1062168+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 14;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 92;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_0:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062093+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 3;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___main_void_b5;
	}
	i32_0 = l0;
	i32_1 = 1;
	write_u8((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = l0;
	i32_1 = 16;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 1, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 141;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_1:
*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func___main_void_b5:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u64_aligned((ulong)(stack_u32+8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-0+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u64_aligned((ulong)(stack_u32+6+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+4+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+2+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func___main_void_b4:
	i32_0 = 1;
	i32_1 = 5;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 2, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_2:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___main_void_b3:
	i32_0 = 8;
	i32_1 = 24;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 3, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 191;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_3:
*sp -= 4;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___main_void_b2:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 4, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 183;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_4:
*sp -= 0;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___main_void_b1:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 1057784;
	i32_1 = 16;
	i32_2 = l0;
	i32_3 = 40;
	i32_2 = (int)(i32_2) + (int)(i32_3);
	i32_3 = 1057800;
	i32_4 = 1058520;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_3, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_4, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 5, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 74;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_5:
*sp -= 10;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func___main_void_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 0;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 1058512;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = l0;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = l0;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	i32_2 = l0;
	i32_3 = 16;
	i32_2 = (int)(i32_2) + (int)(i32_3);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 6, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 27;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_6:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = l0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 7, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 174;
	*is_calling = 1;
	return;
	__func_func___main_void_call_return_stub_7:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-0+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, (uint)(-1), warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5serde2de5Error12invalid_type17h5da9aaf7a05df57fE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[9] = { 0 };
	uint p0 = 0;
	uint p2 = 0;
	uint p1 = 0;
	uint p3 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5serde2de5Error12invalid_type17h5da9aaf7a05df57fE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 1048936;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l4;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l4;
	i32_1 = l4;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l4;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[8]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l4, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[8] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 5;
	*is_calling = 1;
	return;
	__func_func__ZN5serde2de5Error12invalid_type17h5da9aaf7a05df57fE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-8+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) p3 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[8]) l4 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l4;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p2 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = p0;
	i32_1 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_1)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE_b0;
	}
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 117;
	*is_calling = 1;
	return;
	__func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE_call_return_stub_0:
*sp -= 6;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l3 = i32_0;
	local_cache[6] = 1;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = p0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p1;
	i32_2 = p2;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = p2;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = 0;
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5serde2de5Error13invalid_value17hdb72928eb263acffE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p2 = 0;
	uint p0 = 0;
	uint l3 = 0;
	uint p1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5serde2de5Error13invalid_value17hdb72928eb263acffE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1049084;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 1048968;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l3;
	i32_1 = l3;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l3;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[6]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l3, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[6] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 5;
	*is_calling = 1;
	return;
	__func_func__ZN5serde2de5Error13invalid_value17hdb72928eb263acffE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) p2 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-6+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[6]) l3 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l3;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core5slice29_$LT$impl$u20$$u5b$T$u5d$$GT$15copy_from_slice17len_mismatch_fail17hd5547bc51ad2954cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[5] = { 0 };
	uint p0 = 0;
	uint p1 = 0;
	uint l2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN4core5slice29_$LT$impl$u20$$u5b$T$u5d$$GT$15copy_from_slice17len_mismatch_fail17hd5547bc51ad2954cE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l2 = i32_0;
	local_cache[4] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = p0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 32;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 1052860;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+36+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 32;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = l2;
	i32_2 = 4;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l2;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1056596;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[4]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l2, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[4] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 46;
	*is_calling = 1;
	return;
	__func_func__ZN4core5slice29_$LT$impl$u20$$u5b$T$u5d$$GT$15copy_from_slice17len_mismatch_fail17hd5547bc51ad2954cE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-4+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) p1 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[4]) l2 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5serde2de5Error13missing_field17hd41885b2d2e67f91E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5serde2de5Error13missing_field17hd41885b2d2e67f91E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 9;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049152;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049000;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 5;
	*is_calling = 1;
	return;
	__func_func__ZN5serde2de5Error13missing_field17hd41885b2d2e67f91E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5serde2de5Error14invalid_length17h013955f8bd1fd7a7E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint l1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5serde2de5Error14invalid_length17h013955f8bd1fd7a7E_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 64;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049232;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049224;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 24;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 2;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 12;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+28+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049032;
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 3;
	write_u32_aligned((ulong)((global char*)heap_u32+52+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 48;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+32+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+56+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 12;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+48+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l1;
	i32_2 = 24;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 5;
	*is_calling = 1;
	return;
	__func_func__ZN5serde2de5Error14invalid_length17h013955f8bd1fd7a7E_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 64;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5serde2de5Error15duplicate_field17h4b28bcf61e77388bE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p0 = 0;
	uint l1 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	ulong i64_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN5serde2de5Error15duplicate_field17h4b28bcf61e77388bE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 24;
	i32_0 = read_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), warp_idx, read_idx, thread_idx, scratch_space);
	i32_1 = 48;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l1 = i32_0;
	local_cache[2] = 1;
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 9;
	write_u32_aligned((ulong)((global char*)heap_u32+12+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049152;
	write_u32_aligned((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 28;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i64_0 = 1;
	write_u64_aligned_checked((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 2;
	write_u32_aligned((ulong)((global char*)heap_u32+20+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 1049068;
	write_u32_aligned((ulong)((global char*)heap_u32+16+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = 4;
	write_u32_aligned((ulong)((global char*)heap_u32+44+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 40;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+24+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l1;
	i32_1 = l1;
	i32_2 = 8;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	write_u32_aligned((ulong)((global char*)heap_u32+40+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = l1;
	i32_2 = 16;
	i32_1 = (int)(i32_1) + (int)(i32_2);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[2]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l1, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[2] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 5;
	*is_calling = 1;
	return;
	__func_func__ZN5serde2de5Error15duplicate_field17h4b28bcf61e77388bE_call_return_stub_0:
*sp -= 4;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[2]) l1 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l1;
	i32_1 = 48;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	write_u32((ulong)((global char*)globals_buffer+0), (ulong)(globals_buffer), i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN3std10sys_common9backtrace28__rust_begin_short_backtrace17h2eb31db3727dee1aE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint p0 = 0;
	uint i32_0 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__ZN3std10sys_common9backtrace28__rust_begin_short_backtrace17h2eb31db3727dee1aE_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 18;
	i32_0 = p0;
	switch(i32_0) {
		case 14:
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 55;
	*is_calling = 1;
	return;
	__func_func__ZN3std10sys_common9backtrace28__rust_begin_short_backtrace17h2eb31db3727dee1aE_call_return_stub_0:
*sp -= 0;
			break;
		default:
				*((volatile unsigned long *)0x3) = 0x3;

			return;
	}
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) p0 = read_u32_aligned((ulong)(stack_u32+-2+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[11] = { 0 };
	uint p2 = 0;
	uint l5 = 0;
	uint p0 = 0;
	uint p3 = 0;
	uint p1 = 0;
	uint l4 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p2 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-8+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p3 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 22;
	i32_0 = p1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b2;
	}
	i32_0 = p2;
	i32_1 = -1;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b1;
	}
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b7;
	}
	i32_0 = p3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l4 = i32_0;
	local_cache[8] = 1;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b8;
	}
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b9;
	}
	i32_0 = p1;
	p3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b9:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b6;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b8:
	i32_0 = p3;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b10;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b3;
	}
	i32_0 = p3;
	i32_1 = l5;
	i32_2 = l4;
	___private_bulk_memcpy((i32_1), (ulong)(heap_u32), (i32_0), (ulong)(heap_u32), (ulong)heap_base, i32_2, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = l5;
	__func_func_free_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b4;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b10:
	i32_0 = l5;
	i32_1 = p2;
	i32_0 = __func_func_realloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b7:
	i32_0 = p2;
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b11;
	}
	i32_0 = p1;
	p3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b11:
	i32_0 = 0;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1062092+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b6;
	}
	i32_0 = p1;
	i32_1 = p2;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b6:
	i32_0 = p2;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	p3 = i32_0;
	local_cache[6] = 1;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b5:
	i32_0 = p3;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b3;
	}

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b4:
	i32_0 = p0;
	i32_1 = p3;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b3:
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b0;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b2:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	goto __func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b0;

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b1:
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);

__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E_b0:
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func___rust_alloc(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[3] = { 0 };
	uint p1 = 0;
	uint p0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	*sp += 20;
	i32_0 = p1;
	i32_1 = p0;
	i32_0 = (uint)(i32_0) <= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func___rust_alloc_b0;
	}
	i32_0 = p1;
	i32_1 = p0;
	i32_0 = __func_func_aligned_alloc_fastcall(i32_0, i32_1, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func___rust_alloc_b0:
	i32_0 = p0;
	i32_0 = __func_func_malloc_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	/* function unwind */
	write_u32_aligned((ulong)(stack_u32-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, i32_0, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[7] = { 0 };
	uint p1 = 0;
	uint l3 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
	i32_0 = 1;
	l3 = i32_0;
	local_cache[6] = 1;
	i32_0 = p2;
	i32_1 = 9;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 105;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 110;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+2+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 112;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+3+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 117;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 116;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+5+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 95;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+6+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 118;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+7+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 101;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0;
	}
	i32_0 = p1;
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+8+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = 99;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;

__func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE_b0:
	i32_0 = p0;
	i32_1 = 9;
	write_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	i32_0 = p0;
	i32_1 = l3;
	write_u8((ulong)((global char*)heap_u32+1+(int)(i32_0)), (ulong)(heap_u32), (char)(i32_1), warp_idx, read_idx);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[21] = { 0 };
	uint l5 = 0;
	uint p0 = 0;
	uint p2 = 0;
	uint l10 = 0;
	uint l3 = 0;
	uint l4 = 0;
	uint l6 = 0;
	ulong l9 = 0;
	uint p1 = 0;
	uint l7 = 0;
	ulong l8 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	uint i32_2 = 0;
	uint i32_3 = 0;
	ulong i64_0 = 0;
	ulong i64_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
		p0 = read_u32_aligned((ulong)(stack_u32+-6+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p2 = read_u32_aligned((ulong)(stack_u32+-2+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
		p1 = read_u32_aligned((ulong)(stack_u32+-4+read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space)), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u64_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (ulong)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 28;
	i32_0 = p2;
	i32_0 = !(i32_0);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b0;
	}
	i32_0 = 0;
	i32_1 = p2;
	i32_2 = -7;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_2 = l3;
	i32_3 = p2;
	i32_2 = (uint)(i32_2) > (uint)(i32_3);
	(i32_2 != 0) ? (i32_0 = i32_0) : (i32_0 = i32_1);
	l4 = i32_0;
	local_cache[8] = 1;
	i32_0 = p1;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = -4;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = p1;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	l5 = i32_0;
	local_cache[10] = 1;
	i32_0 = 0;
	l3 = i32_0;
	local_cache[6] = 1;
__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l0_loop:
	i32_0 = p1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (char)(i32_0);
	l7 = i32_0;
	local_cache[14] = 1;
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b3;
	}
	i32_0 = l5;
	i32_1 = l3;
	i32_0 = (int)(i32_0) - (int)(i32_1);
	i32_1 = 3;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b4;
	}
	i32_0 = l3;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b2;
	}
__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l1_loop:
	i32_0 = p1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b2;
	}
	i32_0 = l6;
	i32_1 = 4;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	i32_1 = -2139062144;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b2;
	}
	i32_0 = l3;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	i32_1 = l4;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b2;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l1_loop;
	/* END (loop: __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l1) */

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b4:
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b1;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b3:
	i64_0 = 1099511627776;
	l8 = i64_0;
	local_cache[16] = 1;
	i64_0 = 4294967296;
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = l6;
	i32_1 = 1052884;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = (uchar)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx));
	i32_1 = -2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b16;
			break;
		case 1:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b15;
			break;
		case 2:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b14;
			break;
		default:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;
			break;
	}

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b16:
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b13;
	}
	i64_0 = 0;
	l8 = i64_0;
	local_cache[16] = 1;
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b15:
	i64_0 = 0;
	l8 = i64_0;
	local_cache[16] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b12;
	}
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b14:
	i64_0 = 0;
	l8 = i64_0;
	local_cache[16] = 1;
	i32_0 = l3;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l10 = i32_0;
	local_cache[20] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b11;
	}
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b13:
	i64_0 = 1099511627776;
	l8 = i64_0;
	local_cache[16] = 1;
	i64_0 = 4294967296;
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = p1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b5;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b12:
	i32_0 = p1;
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l6;
	i32_1 = -224;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b19;
			break;
		case 1:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 2:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 3:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 4:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 5:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 6:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 7:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 8:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 9:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 10:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 11:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 12:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
		case 13:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b18;
			break;
		default:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17;
			break;
	}

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b19:
	i32_0 = l10;
	i32_1 = -32;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -96;
	i32_0 = (int)(i32_0) == (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b9;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b18:
	i32_0 = l10;
	i32_1 = -97;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b9;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b17:
	i32_0 = l7;
	i32_1 = 31;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 12;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b20;
	}
	i32_0 = l7;
	i32_1 = -2;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = -18;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}
	i32_0 = l10;
	i32_1 = -64;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b9;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b20:
	i32_0 = l10;
	i32_1 = -64;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b9;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b11:
	i32_0 = p1;
	i32_1 = l10;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	l10 = i32_0;
	local_cache[20] = 1;
	i32_0 = l6;
	i32_1 = -240;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	switch(i32_0) {
		case 0:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b23;
			break;
		case 1:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b24;
			break;
		case 2:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b24;
			break;
		case 3:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b24;
			break;
		case 4:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b22;
			break;
		default:
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b24;
			break;
	}

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b24:
	i32_0 = l7;
	i32_1 = 15;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 2;
	i32_0 = (uint)(i32_0) > (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}
	i32_0 = l10;
	i32_1 = -64;
	i32_0 = (int)(i32_0) >= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b21;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b23:
	i32_0 = l10;
	i32_1 = 112;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = 255;
	i32_0 = (uint)(i32_0) & (uint)(i32_1);
	i32_1 = 48;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b21;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b22:
	i32_0 = l10;
	i32_1 = -113;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10;
	}

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b21:
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b25;
	}
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b25:
	i32_0 = p1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) > (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b8;
	}
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = l3;
	i32_1 = 3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;
	}
	i32_0 = p1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b5;
	}
	i64_0 = 3298534883328;
	l8 = i64_0;
	local_cache[16] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b7;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b10:
	i64_0 = 1099511627776;
	l8 = i64_0;
	local_cache[16] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b7;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b9:
	i64_0 = 0;
	l9 = i64_0;
	local_cache[18] = 1;
	i32_0 = l3;
	i32_1 = 2;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l6 = i32_0;
	local_cache[12] = 1;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6;
	}
	i32_0 = p1;
	i32_1 = l6;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = -65;
	i32_0 = (int)(i32_0) <= (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b5;
	}

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b8:
	i64_0 = 2199023255552;
	l8 = i64_0;
	local_cache[16] = 1;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b7:
	i64_0 = 4294967296;
	l9 = i64_0;
	local_cache[18] = 1;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b6:
	i32_0 = p0;
	i64_0 = l8;
	i32_1 = l3;
	i64_1 = (ulong)(i32_1);
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	i64_1 = l9;
	i64_0 = (ulong)(i64_0) | (ulong)(i64_1);
	write_u64_aligned_checked((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i64_0, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b5:
	i32_0 = l6;
	i32_1 = 1;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	l3 = i32_0;
	local_cache[6] = 1;
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b1;

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b2:
	i32_0 = l3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) >= (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b1;
	}
__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l2_loop:
	i32_0 = p1;
	i32_1 = l3;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_0 = convert_int((char)(read_u8((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx)));
	i32_1 = 0;
	i32_0 = (int)(i32_0) < (int)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b1;
	}
	i32_0 = p2;
	i32_1 = l3;
	i32_2 = 1;
	i32_1 = (int)(i32_1) + (int)(i32_2);
	l3 = i32_1;
	local_cache[6] = 1;
	i32_0 = (uint)(i32_0) != (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l2_loop;
	}
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b0;
	/* END (loop: __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l2) */

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b1:
	i32_0 = l3;
	i32_1 = p2;
	i32_0 = (uint)(i32_0) < (uint)(i32_1);
	if (i32_0 != 0) {
	goto __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l0_loop;
	}
	/* END (loop: __func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_l0) */

__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E_b0:
	i32_0 = p0;
	i32_1 = p1;
	write_u32_aligned((ulong)((global char*)heap_u32+4+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 8;
	i32_0 = (int)(i32_0) + (int)(i32_1);
	i32_1 = p2;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	i32_0 = p0;
	i32_1 = 0;
	write_u32_aligned((ulong)((global char*)heap_u32+0+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}

__attribute__((always_inline)) void __func_func__start(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	uint l0 = 0;
	uint i32_0 = 0;
	uint i32_1 = 0;
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
		switch (read_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), warp_idx, read_idx, thread_idx, scratch_space)) {
			case 0:
				*sfp -= 1;
				goto __func_func__start_call_return_stub_0;
			default:
					*((volatile unsigned long *)0x0) = 0x0;

		}
	} else {
	}
	write_u32_aligned((ulong)(stack_u32+*sp), (ulong)(stack_u32), (uint)0, warp_idx, read_idx, thread_idx, scratch_space);
	*sp += 2;
	*sp += 20;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = 0;
	i32_0 = (read_u32_aligned((ulong)((global char*)heap_u32+1062088+(int)(i32_0)), (ulong)(heap_u32), warp_idx, read_idx, thread_idx, scratch_space));
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__start_b1;
	}
	i32_0 = 0;
	i32_1 = 1;
	write_u32_aligned((ulong)((global char*)heap_u32+1062088+(int)(i32_0)), (ulong)(heap_u32), i32_1, warp_idx, read_idx, thread_idx, scratch_space);
	__func_func___wasm_call_ctors_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	*sfp += 1;
	write_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), *sp, warp_idx, read_idx, thread_idx, scratch_space);
	write_u64_aligned((ulong)(call_stack+*sfp), (ulong)(call_stack), 0, warp_idx, read_idx, thread_idx, scratch_space);
	write_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), (uint)*entry_point, warp_idx, read_idx, thread_idx, scratch_space);
	*entry_point = 25;
	*is_calling = 1;
	return;
	__func_func__start_call_return_stub_0:
	*sp += 2;
	*sp -= 0;
	i32_0 = read_u32_aligned((ulong)(stack_u32+*sp-2), (ulong)(stack_u32), warp_idx, read_idx, thread_idx, scratch_space);
	*sp -= 2;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	l0 = i32_0;
	local_cache[0] = 1;
	__func_func___wasm_call_dtors_fastcall(heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	i32_0 = l0;
	if (i32_0 != 0) {
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	goto __func_func__start_b0;
	}
	/* function unwind */
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (local_cache[0]) write_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, l0, warp_idx, read_idx, thread_idx, scratch_space);
	local_cache[0] = 0;
	ulong end = get_clock();
	*overhead_tracker += end - start;
}

__func_func__start_b1:
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;

__func_func__start_b0:
{
	ulong start = get_clock();
	uint sfp_ptr = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)stack_frames, warp_idx, read_idx, thread_idx, scratch_space);
	if (!local_cache[0]) l0 = read_u32_aligned((ulong)(stack_u32+0+sfp_ptr), (ulong)stack_u32, warp_idx, read_idx, thread_idx, scratch_space);
	ulong end = get_clock();
	*overhead_tracker += end - start;
}
	i32_0 = l0;
	__func_func___wasi_proc_exit_fastcall(i32_0, heap_u32, current_mem_size, max_mem_size, globals_buffer, warp_idx, thread_idx, read_idx, overhead_tracker, scratch_space);
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
	/* function unwind */
	*hypercall_number = 1;
	*hypercall_continuation = 0;
	return;
}

__attribute__((always_inline)) void __func_func___wasm_call_ctors(global uint   *stack_u32,
    global ulong  *stack_u64,
    global uint   *heap_u32,
    global ulong  *heap_u64,
    global uint   *hypercall_buffer,
    global uint   *globals_buffer,
    global uint   *stack_frames,
    global ulong  *sp,
    global ulong  *sfp,
    global ulong  *call_stack,
    global ulong  *call_return_stack,
    global int    *hypercall_number,
    global uint   *hypercall_continuation,
    global uint   *current_mem_size,
    global uint   *max_mem_size,
    global uchar  *is_calling,
    uint  warp_idx,
    uint  thread_idx,
    uint  read_idx,
    local uchar *scratch_space,
    uint   hcall_size,
    global uint   *entry_point,
    global ulong  *overhead_tracker,
    uint hcall_ret_val) {
	bool local_cache[1] = { 0 };
	global uint *heap_base = (global uint*)((global uchar*)heap_u32 + (warp_idx*1));
	global uint *stack_base = (global uint*)((global uchar*)stack_u32 + (warp_idx*1));
	if (*hypercall_number == -1) {
		*hypercall_number = -2;
	}
	if (!*is_calling) {
	} else {
	}
	*sp += 16;
	/* function unwind */
	*entry_point = read_u32_aligned((ulong)(call_return_stack+*sfp), (ulong)(call_return_stack), warp_idx, read_idx, thread_idx, scratch_space);
	*sp = read_u32_aligned((ulong)(stack_frames+*sfp), (ulong)(stack_frames), warp_idx, read_idx, thread_idx, scratch_space);
	*is_calling = 0;
	return;
}
__kernel  void wasm_entry(__global uint   *stack_u32_global,
	__global ulong  *stack_u64_global,
	__global uint   *heap_u32_global,
	__global ulong  *heap_u64_global,
	__global uint   *hypercall_buffer_global,
	__global uint   *globals_buffer_global,
	__global uint   *stack_frames_global,
	__global ulong  *sp_global,
	__global ulong  *sfp_global,
	__global ulong  *call_stack_global,
	__global ulong  *call_return_stack_global,
	__global int    *hypercall_number_global,
	__global uint   *hypercall_continuation_global,
	__global uint   *current_mem_size_global,
	__global uint   *max_mem_size_global,
	__global uchar  *is_calling_global,
	__global uint   *entry_point_global,
	__global uint   *hcall_ret_val_global,
	__global uint   *hcall_size_global,
	__global ulong  *overhead_tracker_global) {
	uint warp_idx = get_global_id(0);
	uint thread_idx = get_local_id(0);
	uint read_idx = 0;
	local ulong2 scratch_space[0];
	global uint  *stack_u32    = (global uint*)stack_u32_global;
	global ulong *stack_u64    = (global ulong*)stack_u32;
	global uint  *heap_u32     = (global uint *)heap_u32_global;
	global ulong *heap_u64     = (global ulong *)heap_u32;
	global uint  *hypercall_buffer = (global uint *)hypercall_buffer_global;
	global uint  *globals_buffer = (global uint *)globals_buffer_global;
	global uint  *stack_frames = (global uint*)stack_frames_global;
	global ulong *sp           = (global ulong *)sp_global+(get_global_id(0));
	global ulong *sfp          = (global ulong*)(sfp_global+(get_global_id(0)));
	global ulong *call_stack   = (global ulong*)call_stack_global;
	global ulong *call_return_stack   = (global ulong*)call_return_stack_global;
	global int *hypercall_number = (global int *)hypercall_number_global+(get_global_id(0));
	global uint *hypercall_continuation = (global uint *)hypercall_continuation_global+(get_global_id(0));
	global uint *current_mem_size = (global uint *)current_mem_size_global+(get_global_id(0));
	global uint *max_mem_size = (global uint *)max_mem_size_global+(get_global_id(0));
	global uchar *is_calling = (global uchar *)is_calling_global+(get_global_id(0));
	global uint  *entry_point   = (global uint*)entry_point_global+get_global_id(0);
	global uint  *hcall_ret_val = (global uint*)hcall_ret_val_global+get_global_id(0);
	global ulong *overhead_tracker = (global ulong*)overhead_tracker_global+get_global_id(0);

	global uint  *hcall_size = (global uint*)hcall_size_global+get_global_id(0);
	do {
	switch (*entry_point) {
		case 201:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h628701fbe6b33d3fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 205:
			__func_func__ZN5serde2de5Error13invalid_value17hdb72928eb263acffE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 124:
			__func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17hbee2961531151bddE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 150:
			__func_func__ZN4sha26sha25611compress25617hc02034fc797ebea9E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 135:
			__func_func_getenv(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 204:
			__func_func__ZN4core3fmt9Formatter19pad_formatted_parts17h40411c58924e307fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 4:
			__func_func__ZN4core3fmt5Write10write_char17he379bb53c9daf0b9E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 118:
			__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$corefmtDebug$GT$3fmt17h01483c4799cc548cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 117:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17h1aaed89bfa87da50E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 125:
			__func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h4653026584ff3204E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 31:
			__func_func__ZN5alloc7raw_vec11finish_grow17ha00e26d713442442E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 148:
			__func_func__ZN4core3fmt8builders11DebugStruct5field17h83f20f9cee1d2b6fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 167:
			__func_func__ZN6pbkdf26pbkdf217h62c6dbc86183a35fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 22:
			__func_func__ZN4core3ptr70drop_in_place$LT$stdpanickingbegin_panic_handlerPanicPayload$GT$17hd62d624acfbbc3d7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 66:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hbb8a3f4cac88eab5E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 188:
			__func_func__ZN4core5slice5index26slice_start_index_len_fail17h0d54849012697d98E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 128:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17hf1f0c648386167e3E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 189:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h95bfb4d5d740b326E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 194:
			__func_func_strerror_r(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 3:
			__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u64$GT$3fmt17hc6d34ca91759d841E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 46:
			__func_func__ZN4core9panicking9panic_fmt17h826facefad16f5a7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 1:
			__func_func__ZN4core9panicking19assert_failed_inner17he4b24762864588bfE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 47:
			__func_func_getcwd(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 76:
			__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h62acf5180fa3f829E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 120:
			__func_func__ZN148_$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__FieldVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h6d404fc3c207158cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 169:
			__func_func__ZN4core3fmt5float52_$LT$impl$u20$corefmtDisplay$u20$for$u20$f64$GT$3fmt17h09aec3b112c7dd39E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 130:
			__func_func__ZN64_$LT$corestrerrorUtf8Error$u20$as$u20$corefmtDebug$GT$3fmt17hcea524ead953dc7bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 144:
			__func_func_dummy(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 154:
			__func_func__ZN4core3fmt9Formatter21write_formatted_parts17h4d323ea2d360b1fbE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 111:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h36473c0450a6f995E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 115:
			__func_func__ZN4core3str19slice_error_fail_rt17h4eacd2e829253641E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 153:
			__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h562f42c197b10c7fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 88:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h751c0741d29bc5ffE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 198:
			__func_func__ZN47_$LT$$RF$str$u20$as$u20$serdedeExpected$GT$3fmt17h047a2d1f29481c3aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 29:
			__func_func_dlmalloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 33:
			__func_func__ZN43_$LT$char$u20$as$u20$corefmtDisplay$GT$3fmt17hae0073a216e2b7ffE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 45:
			__func_func__ZN3std5alloc24default_alloc_error_hook17ha3291554c6d119e3E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 90:
			__func_func__ZN3std9panicking11panic_count17is_zero_slow_path17h88f026da919a15b3E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 142:
			__func_func__ZN4core3fmt5Write10write_char17h64c6c20879db5d63E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 199:
			__func_func__ZN4core3str16slice_error_fail17h910c703df873ef46E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 121:
			__func_func__ZN4core9panicking13assert_failed17hfb0bb2c5a0cdf99aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 81:
			__func_func___wasi_proc_exit(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 18:
			__func_func___rust_alloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 36:
			__func_func__ZN4core3str8converts9from_utf817h0c702c416c8bc7f4E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 9:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h54e5431924cf55b2E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 60:
			__func_func__ZN40_$LT$str$u20$as$u20$corefmtDebug$GT$3fmt17hdf3195cd12cad802E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 38:
			__func_func_rust_begin_unwind(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 82:
			__func_func___rg_oom(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 122:
			__func_func__ZN3std10sys_common9backtrace5print17h3f7333e2fc80655dE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 68:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hac957ce827fb6e33E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 140:
			__func_func___wasilibc_ensure_environ(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 106:
			__func_func_strdup(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 114:
			__func_func__ZN4core3ops8function6FnOnce9call_once17h6f4abb2291c2f20eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 61:
			__func_func__ZN4core3ptr29drop_in_place$LT$$LP$$RP$$GT$17hb98729e73ea57a1cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 41:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17hd4adee8d1a391429E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 158:
			__func_func__ZN5serde2de5Error13missing_field17hd41885b2d2e67f91E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 195:
			__func_func__ZN71_$LT$coreopsrangeRange$LT$Idx$GT$$u20$as$u20$corefmtDebug$GT$3fmt17h734d79daa4b4517eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 190:
			__func_func__ZN4core3fmt8builders10DebugTuple5field17h54df303e0fa79f0cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 146:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3726bedafbdb8637E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 69:
			__func_func__ZN4core3ptr25drop_in_place$LT$bool$GT$17h8b00e9de3af4761aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 172:
			__func_func__ZN4core6option13expect_failed17h8f72e66e0b3163c7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 0:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3af1190cc5fc504bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 134:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h0077ecf4ef1af0ddE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 168:
			__func_func__ZN4core4char7methods22_$LT$impl$u20$char$GT$16escape_debug_ext17h528ac37fe213ef7fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 57:
			__func_func__ZN4core3ffi5c_str4CStr19from_bytes_with_nul17h0f81087cbdb306deE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 131:
			__func_func___wasi_environ_get(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 182:
			__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc25bc2e40f825b91E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 98:
			__func_func__ZN43_$LT$bool$u20$as$u20$corefmtDisplay$GT$3fmt17h517c110f608bb8f2E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 43:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h9b33e863e98a54a9E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 78:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7a118ed4f4fd1b61E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 83:
			__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$i64$GT$3fmt17hed20ad7e0e66252bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 91:
			__func_func__ZN68_$LT$corefmtbuildersPadAdapter$u20$as$u20$corefmtWrite$GT$9write_str17hf382a5879dfb1e7eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 126:
			__func_func_dispose_chunk(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 64:
			__func_func_dlfree(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 65:
			__func_func__ZN73_$LT$corepanicpanic_infoPanicInfo$u20$as$u20$corefmtDisplay$GT$3fmt17hbe995edf73a99996E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 15:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hcaf0862805a36131E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 75:
			__func_func__ZN4core3fmt5float32float_to_decimal_common_shortest17h7f1ef71e2481243aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 19:
			__func_func_strerror(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 20:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h8871d9d7c5578d78E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 119:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h3fc94b77ededba77E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 10:
			__func_func__ZN4core3num7flt2dec8strategy5grisu16format_exact_opt14possibly_round17h9abea1f263f6fa20E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 32:
			__func_func__ZN4core3fmt5float29float_to_decimal_common_exact17h5932e19ef0ec7202E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 92:
			__func_func__ZN3std10sys_common9backtrace28__rust_begin_short_backtrace17h2eb31db3727dee1aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 147:
			__func_func_strcpy(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 95:
			__func_func__ZN4core3fmt9Formatter12pad_integral17h0a725a60906c4eb7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 107:
			__func_func__ZN4core3num6bignum8Big32x408mul_pow217h763164e27f463ce1E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 123:
			__func_func__ZN4core9panicking13assert_failed17h88aeb5e475543e29E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 52:
			__func_func___lctrans(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 113:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h43b10d22ac27745bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 16:
			__func_func___wasm_call_dtors(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 159:
			__func_func__ZN6scrypt5romix16scrypt_block_mix17ha9e6111ca0d92e6eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 162:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hb2a202be938949c6E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 165:
			__func_func_rust_panic(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 145:
			__func_func___stpcpy(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 178:
			__func_func__ZN4core3fmt5write17h80c8117f546444b5E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 183:
			__func_func__ZN3std6thread8ThreadId3new9exhausted17h35806fdda5b22e83E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 85:
			__func_func__ZN4core3ptr39drop_in_place$LT$stdpathPathBuf$GT$17hcd41e3e78ccde51eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 17:
			__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hc083ef6c15b35f92E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 27:
			__func_func__ZN3std2io5Write9write_fmt17he644c9ec16dca596E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 160:
			__func_func___rust_alloc_error_handler(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 184:
			__func_func__ZN4core3ptr27drop_in_place$LT$$RF$i8$GT$17h101cdb19fde65453E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 186:
			__func_func__ZN5alloc7raw_vec11finish_grow17h5538b12d95552e36E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 202:
			__func_func__ZN62_$LT$stdioerrorErrorKind$u20$as$u20$corefmtDebug$GT$3fmt17hde80f6dc55c60c35E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 108:
			__func_func__ZN4core3num6bignum8Big32x4010mul_digits17h9087abb37f6de926E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 40:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h76913d7c9fce1378E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 175:
			__func_func__ZN5alloc7raw_vec17capacity_overflow17ha2fa7309cb777b97E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 54:
			__func_func__ZN5serde2de5Error12invalid_type17h5da9aaf7a05df57fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 203:
			__func_func__ZN4core3ptr100drop_in_place$LT$$RF$mut$u20$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17hc678b1c1755486caE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 12:
			__func_func__ZN4core3fmt5Write9write_fmt17h7008031b2f3a175fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 93:
			__func_func__ZN4core3fmt3num3imp52_$LT$impl$u20$corefmtDisplay$u20$for$u20$u32$GT$3fmt17h4fbd4b654b964086E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 101:
			__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17hdbd0e2daba8bb891E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 156:
			__func_func_strlen(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 192:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hd6b33ab562f09db7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 11:
			__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17h01c47134cac61165E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 67:
			__func_func_memset(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 35:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfd10ca601c4951bdE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 26:
			__func_func__ZN4core5slice29_$LT$impl$u20$$u5b$T$u5d$$GT$15copy_from_slice17len_mismatch_fail17hd5547bc51ad2954cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 53:
			__func_func__ZN4core5slice5index22slice_index_order_fail17h679e58da08ea621aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 56:
			__func_func__ZN100_$LT$$RF$mut$u20$rmp_serdedecodeDeserializer$LT$R$C$C$GT$$u20$as$u20$serdedeDeserializer$GT$15deserialize_any17h45c6e851f44b9ed4E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 112:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17h7c22f686d2d0e8d8E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 127:
			__func_func_internal_memalign(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 163:
			__func_func__ZN72_$LT$sha2sha256Sha256$u20$as$u20$digestfixedFixedOutputDirty$GT$19finalize_into_dirty17h563df1210a5950c5E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 170:
			__func_func_calloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 193:
			__func_func___wasi_environ_sizes_get(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 77:
			__func_func__ZN3std10sys_common9backtrace26__rust_end_short_backtrace17hd312084468c4357cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 73:
			__func_func___wasm_call_ctors(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 23:
			__func_func__ZN4core3fmt9Formatter12pad_integral12write_prefix17h75035d5f44a85a07E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 103:
			__func_func__ZN5serde2de5Error15duplicate_field17h4b28bcf61e77388bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 185:
			__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17h6ea6b0e170de4b96E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 200:
			__func_func__ZN4core7unicode9printable5check17hfde46cfd3774c42cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 191:
			__func_func__ZN5alloc5alloc18handle_alloc_error17hac4f7515a97bd968E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 132:
			__func_func_sbrk(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 6:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h5fdaa25030732199E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 34:
			__func_func__ZN3std3sys4wasi4once4Once4call17h43619e2953d53b25E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 109:
			__func_func__ZN3std3sys4wasi14abort_internal17h1f6b37acb101778eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 58:
			__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17hc34169e9e47ddfc5E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 151:
			__func_func__ZN5alloc4sync12Arc$LT$T$GT$9drop_slow17h247e604f5584e6abE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 37:
			__func_func__ZN59_$LT$corefmtArguments$u20$as$u20$corefmtDisplay$GT$3fmt17h341ff6928aa3d36bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 102:
			__func_func_malloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 152:
			__func_func__start(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 166:
			__func_func__ZN6scrypt13hash_password17h676cce8b54df47e1E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 116:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h7da6954ba46cfd82E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 155:
			__func_func_hfunc207_dummy_(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 59:
			__func_func__ZN4core3ptr125drop_in_place$LT$scrypt_$LT$impl$u20$serdedeDeserialize$u20$for$u20$scryptFuncInput$GT$deserialize__Visitor$GT$17he5ce94fe758aed08E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 14:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h2e77a8293739dbd5E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 149:
			__func_func__ZN4core9panicking18panic_bounds_check17h543a833f43a239ecE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 141:
			__func_func__ZN3std3sys4wasi4once4Once4call17hee18ac680eb799ccE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 25:
			__func_func___main_void(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 173:
			__func_func__ZN4core3ptr88drop_in_place$LT$stdioWritewrite_fmtAdapter$LT$allocvecVec$LT$u8$GT$$GT$$GT$17he92acc4b62fae97eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 197:
			__func_func_strncmp(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 129:
			__func_func__ZN5alloc5alloc18handle_alloc_error8rt_error17hb51ed5ed7a7011fbE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 7:
			__func_func_realloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 104:
			__func_func__ZN63_$LT$corecellBorrowMutError$u20$as$u20$corefmtDebug$GT$3fmt17hbe726ced2502b98bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 49:
			__func_func__ZN4core3num7flt2dec17digits_to_dec_str17h2d3a25365b51fc1cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 79:
			__func_func__ZN60_$LT$serdedeUnexpected$u20$as$u20$corefmtDisplay$GT$3fmt17h82ef7a67b36f9a0cE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 50:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_fmt17hed3fe2abb51394d6E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 138:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$10write_char17h2301b060ccf78942E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 196:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hf720a13b210da41eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 96:
			__func_func__ZN3std9panicking19begin_panic_handler28_$u7b$$u7b$closure$u7d$$u7d$17h685c1054195e4d4bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 44:
			__func_func_memcmp(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 21:
			__func_func__Exit(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 48:
			__func_func__ZN91_$LT$stdsys_commonbacktrace_printDisplayBacktrace$u20$as$u20$corefmtDisplay$GT$3fmt17hea32b2f7b995831dE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 139:
			__func_func__ZN90_$LT$stdpanickingbegin_panic_handlerPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$8take_box17h888193ef09bb7434E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 171:
			__func_func__ZN4core3fmt3num3imp7fmt_u6417h2c887a692950a213E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 63:
			__func_func__ZN4core3fmt5Write9write_fmt17h457cd451a20d6529E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 206:
			__func_func__ZN80_$LT$stdioWritewrite_fmtAdapter$LT$T$GT$$u20$as$u20$corefmtWrite$GT$9write_str17h96fe6309f626e056E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 94:
			__func_func__ZN50_$LT$$RF$mut$u20$W$u20$as$u20$corefmtWrite$GT$9write_str17h995b5cafeb0e411dE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 89:
			__func_func__ZN3std7process5abort17hd45c1523f6588d30E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 8:
			__func_func__ZN4sha26sha2569Engine2566update17hcb501717ee07d7caE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 70:
			__func_func__ZN3std9panicking20rust_panic_with_hook17h59179097e3fe00d4E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 179:
			__func_func_free(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 51:
			__func_func__ZN5alloc7raw_vec11finish_grow17hefa6f421f56e91e4E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 72:
			__func_func_abort(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 136:
			__func_func___strchrnul(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 174:
			__func_func__ZN4core3ptr81drop_in_place$LT$coreresultResult$LT$$LP$$RP$$C$stdioerrorError$GT$$GT$17h90619d11b6168bf9E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 133:
			__func_func__ZN4core3ptr45drop_in_place$LT$rmp_serdedecodeError$GT$17heda07002e9e3594fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 5:
			__func_func__ZN61_$LT$rmp_serdedecodeError$u20$as$u20$serdedeError$GT$6custom17h766c962349abb814E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 30:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h40c63a61646a6aaaE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 84:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17h3a6550c49951b1d9E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 100:
			__func_func__ZN3std5alloc8rust_oom17hb466c6b0b424784eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 13:
			__func_func__ZN4core3num7flt2dec8strategy6dragon9mul_pow1017hd1e2eab3f75d8efaE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 24:
			__func_func__ZN4core9panicking5panic17h2f7f1e15b374dfd2E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 39:
			__func_func__ZN41_$LT$T$u20$as$u20$serdedeExpected$GT$3fmt17he39b71c70196e9daE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 55:
			__func_func__ZN6scrypt4main17h13ff390b51655dbfE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 71:
			__func_func_aligned_alloc(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 137:
			__func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17h644e479311ce68f2E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 97:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h281de823e8c965f2E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 143:
			__func_func_memcpy(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 86:
			__func_func__ZN93_$LT$stdpanickingbegin_panic_handlerStrPanicPayload$u20$as$u20$corepanicBoxMeUp$GT$3get17he8cc0efc923178bfE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 161:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17hfe5c98792cefb76aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 42:
			__func_func__ZN53_$LT$corefmtError$u20$as$u20$corefmtDebug$GT$3fmt17h662a9c5948206fbeE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 164:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$7reserve21do_reserve_and_handle17hb2fb6114277a9b02E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 177:
			__func_func__ZN4core5slice5index24slice_end_index_len_fail17h392bb1693dec020aE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 74:
			__func_func__ZN4core6result13unwrap_failed17hf48c8310675f070eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 62:
			__func_func__ZN42_$LT$$RF$T$u20$as$u20$corefmtDebug$GT$3fmt17had2cd37302ee0a0fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 157:
			__func_func__ZN5serde2de5Error14invalid_length17h013955f8bd1fd7a7E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 2:
			__func_func__ZN44_$LT$$RF$T$u20$as$u20$corefmtDisplay$GT$3fmt17h6c8cb4c347fceb98E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 87:
			__func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtWrite$GT$9write_str17h6650363dd105de2bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 99:
			__func_func__ZN5alloc7raw_vec19RawVec$LT$T$C$A$GT$16reserve_for_push17h6d14ba36063c726fE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 28:
			__func_func__ZN41_$LT$char$u20$as$u20$corefmtDebug$GT$3fmt17h886fcd1ab700ce75E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 176:
			__func_func__ZN70_$LT$serdedeimplsStringVisitor$u20$as$u20$serdedeVisitor$GT$11visit_bytes17h081f969c81afc1bfE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 105:
			__func_func___wasilibc_initialize_environ(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 110:
			__func_func__ZN4core3fmt9Formatter3pad17hff4ffeb08667be0eE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 80:
			__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$i32$GT$3fmt17he6b973e5dce5ac91E331(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 180:
			__func_func__ZN58_$LT$allocstringString$u20$as$u20$corefmtDebug$GT$3fmt17h381ed2cb32560180E332(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 181:
			__func_func__ZN4core3fmt3num50_$LT$impl$u20$corefmtDebug$u20$for$u20$u32$GT$3fmt17h7c698cc16fb44439E(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		case 187:
			__func_func__ZN36_$LT$T$u20$as$u20$coreanyAny$GT$7type_id17h9296ce6d0b4dad2bE(stack_u32, stack_u64, heap_u32, heap_u64, hypercall_buffer, globals_buffer, stack_frames, sp, sfp, call_stack, call_return_stack, hypercall_number, hypercall_continuation, current_mem_size, max_mem_size, is_calling, warp_idx, thread_idx, read_idx, scratch_space, *hcall_size, entry_point, overhead_tracker, *hcall_ret_val);
			break;
		default:
			return;
	}
	} while (*sfp != 0 && *hypercall_number == -2);
}
